=== modified file 'drizzled/authentication.cc'
--- drizzled/authentication.cc	2008-08-15 15:01:59 +0000
+++ drizzled/authentication.cc	2008-08-18 04:35:40 +0000
@@ -1,5 +1,6 @@
 #include <drizzled/server_includes.h>
 #include <drizzled/authentication.h>
+#include <libdrizzle/gettext.h>
 
 static bool are_plugins_loaded= false;
 
@@ -42,7 +43,7 @@
   {
     if (plugin->plugin->init(authen))
     {
-      sql_print_error("Plugin '%s' init function returned error.",
+      sql_print_error(_("Plugin '%s' init function returned error."),
                       plugin->name.str);
       goto err;
     }

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2008-08-14 00:25:41 +0000
+++ drizzled/drizzled.cc	2008-08-15 19:50:07 +0000
@@ -869,7 +869,6 @@
   if (print_message && server_start_time)
     sql_print_information(_(ER(ER_SHUTDOWN_COMPLETE)),my_progname);
   thread_scheduler.end();
-  finish_client_errs();
   /* Returns NULL on globerrs, we don't want to try to free that */
   //void *freeme=
   (void *)my_error_unregister(ER_ERROR_FIRST, ER_ERROR_LAST);
@@ -2154,7 +2153,6 @@
   unireg_init(opt_specialflag); /* Set up extern variabels */
   if (init_errmessage())	/* Read error messages from file */
     return 1;
-  init_client_errs();
   lex_init();
   if (item_create_init())
     return 1;

=== modified file 'drizzled/handler.cc'
--- drizzled/handler.cc	2008-08-16 22:34:15 +0000
+++ drizzled/handler.cc	2008-08-18 04:35:40 +0000
@@ -359,7 +359,7 @@
   {
     if (plugin->plugin->init(hton))
     {
-      sql_print_error("Plugin '%s' init function returned error.",
+      sql_print_error(_("Plugin '%s' init function returned error."),
                       plugin->name.str);
       goto err;
     }
@@ -387,12 +387,12 @@
 
         if (idx == (int) DB_TYPE_DEFAULT)
         {
-          sql_print_warning("Too many storage engines!");
+          sql_print_warning(_("Too many storage engines!"));
           return(1);
         }
         if (hton->db_type != DB_TYPE_UNKNOWN)
-          sql_print_warning("Storage engine '%s' has conflicting typecode. "
-                            "Assigning value %d.", plugin->plugin->name, idx);
+          sql_print_warning(_("Storage engine '%s' has conflicting typecode. "
+                            "Assigning value %d."), plugin->plugin->name, idx);
         hton->db_type= (enum legacy_db_type) idx;
       }
       installed_htons[hton->db_type]= hton;
@@ -1275,7 +1275,7 @@
   {
     while ((got= hton->recover(hton, info->list, info->len)) > 0 )
     {
-      sql_print_information("Found %d prepared transaction(s) in %s",
+      sql_print_information(_("Found %d prepared transaction(s) in %s"),
                             got, ha_resolve_storage_engine_name(hton));
       for (int i=0; i < got; i ++)
       {
@@ -1327,7 +1327,7 @@
     return(0);
 
   if (info.commit_list)
-    sql_print_information("Starting crash recovery...");
+    sql_print_information(_("Starting crash recovery..."));
 
 
 #ifndef WILL_BE_DELETED_LATER
@@ -1359,21 +1359,21 @@
 
   my_free((uchar*)info.list, MYF(0));
   if (info.found_foreign_xids)
-    sql_print_warning("Found %d prepared XA transactions", 
+    sql_print_warning(_("Found %d prepared XA transactions"), 
                       info.found_foreign_xids);
   if (info.dry_run && info.found_my_xids)
   {
-    sql_print_error("Found %d prepared transactions! It means that mysqld was "
-                    "not shut down properly last time and critical recovery "
-                    "information (last binlog or %s file) was manually deleted "
-                    "after a crash. You have to start mysqld with "
-                    "--tc-heuristic-recover switch to commit or rollback "
-                    "pending transactions.",
+    sql_print_error(_("Found %d prepared transactions! It means that drizzled "
+                    "was not shut down properly last time and critical "
+                    "recovery information (last binlog or %s file) was "
+                    "manually deleted after a crash. You have to start "
+                    "drizzled with the --tc-heuristic-recover switch to "
+                    "commit or rollback pending transactions."),
                     info.found_my_xids, opt_tc_log_file);
     return(1);
   }
   if (info.commit_list)
-    sql_print_information("Crash recovery finished.");
+    sql_print_information(_("Crash recovery finished."));
   return(0);
 }
 

=== modified file 'drizzled/log.cc'
--- drizzled/log.cc	2008-08-16 22:34:15 +0000
+++ drizzled/log.cc	2008-08-18 04:35:40 +0000
@@ -34,6 +34,7 @@
 
 #include <drizzled/plugin.h>
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 /* max size of the log message */
 #define MAX_LOG_BUFFER_SIZE 1024
@@ -1068,14 +1069,15 @@
 
   if (my_b_read(log, (uchar*) magic, sizeof(magic)))
   {
-    *errmsg = "I/O error reading the header from the binary log";
+    *errmsg = _("I/O error reading the header from the binary log");
     sql_print_error("%s, errno=%d, io cache code=%d", *errmsg, my_errno,
 		    log->error);
     return 1;
   }
   if (memcmp(magic, BINLOG_MAGIC, sizeof(magic)))
   {
-    *errmsg = "Binlog has bad magic number;  It's not a binary log file that can be used by this version of MySQL";
+    *errmsg = _("Binlog has bad magic number;  It's not a binary log file "
+		"that can be used by this version of Drizzle");
     return 1;
   }
   return 0;
@@ -1089,17 +1091,17 @@
   if ((file = my_open(log_file_name, O_RDONLY | O_BINARY | O_SHARE, 
                       MYF(MY_WME))) < 0)
   {
-    sql_print_error("Failed to open log (file '%s', errno %d)",
+    sql_print_error(_("Failed to open log (file '%s', errno %d)"),
                     log_file_name, my_errno);
-    *errmsg = "Could not open log file";
+    *errmsg = _("Could not open log file");
     goto err;
   }
   if (init_io_cache(log, file, IO_SIZE*2, READ_CACHE, 0, 0,
                     MYF(MY_WME|MY_DONT_CHECK_FILESIZE)))
   {
-    sql_print_error("Failed to create a cache on log (file '%s')",
+    sql_print_error(_("Failed to create a cache on log (file '%s')"),
                     log_file_name);
-    *errmsg = "Could not open log file";
+    *errmsg = _("Could not open log file");
     goto err;
   }
   if (check_binlog_magic(log,errmsg))
@@ -1251,10 +1253,12 @@
   return(0);
 
 err:
-  sql_print_error("Could not use %s for logging (error %d). \
-Turning logging off for the whole duration of the MySQL server process. \
-To turn it on again: fix the cause, \
-shutdown the MySQL server and restart it.", name, errno);
+  sql_print_error(_("Could not use %s for logging (error %d). "
+                    "Turning logging off for the whole duration of the "
+                    "Drizzle server process. "
+                    "To turn it on again: fix the cause, "
+                    "shutdown the Drizzle server and restart it."),
+                    name, errno);
   if (file >= 0)
     my_close(file, MYF(0));
   end_io_cache(&log_file);
@@ -1899,10 +1903,12 @@
   return(0);
 
 err:
-  sql_print_error("Could not use %s for logging (error %d). \
-Turning logging off for the whole duration of the MySQL server process. \
-To turn it on again: fix the cause, \
-shutdown the MySQL server and restart it.", name, errno);
+  sql_print_error(_("Could not use %s for logging (error %d). "
+                    "Turning logging off for the whole duration of the "
+                    "Drizzle server process. "
+                    "To turn it on again: fix the cause, "
+                    "shutdown the Drizzle server and restart it."),
+                    name, errno);
   if (file >= 0)
     my_close(file,MYF(0));
   end_io_cache(&log_file);
@@ -2166,7 +2172,7 @@
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                             ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                             linfo.log_file_name);
-        sql_print_information("Failed to delete file '%s'",
+        sql_print_information(_("Failed to delete file '%s'"),
                               linfo.log_file_name);
         my_errno= 0;
         error= 0;
@@ -2175,10 +2181,10 @@
       {
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                             ER_BINLOG_PURGE_FATAL_ERR,
-                            "a problem with deleting %s; "
+                            _("a problem with deleting %s; "
                             "consider examining correspondence "
                             "of your binlog index file "
-                            "to the actual binlog files",
+                            "to the actual binlog files"),
                             linfo.log_file_name);
         error= 1;
         goto err;
@@ -2197,7 +2203,7 @@
       push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                           ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                           index_file_name);
-      sql_print_information("Failed to delete file '%s'",
+      sql_print_information(_("Failed to delete file '%s'"),
                             index_file_name);
       my_errno= 0;
       error= 0;
@@ -2303,7 +2309,7 @@
         (error=find_next_log(&rli->linfo, 0)))))
   {
     char buff[22];
-    sql_print_error("next log error: %d  offset: %s  log: %s included: %d",
+    sql_print_error(_("next log error: %d  offset: %s  log: %s included: %d"),
                     error,
                     llstr(rli->linfo.index_file_offset,buff),
                     rli->group_relay_log_name,
@@ -2415,7 +2421,7 @@
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                             ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                             log_info.log_file_name);
-        sql_print_information("Failed to execute stat on file '%s'",
+        sql_print_information(_("Failed to execute stat() on file '%s'"),
 			      log_info.log_file_name);
         my_errno= 0;
       }
@@ -2426,10 +2432,10 @@
         */
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                             ER_BINLOG_PURGE_FATAL_ERR,
-                            "a problem with getting info on being purged %s; "
+                            _("a problem with getting info on being purged %s; "
                             "consider examining correspondence "
                             "of your binlog index file "
-                            "to the actual binlog files",
+                            "to the actual binlog files"),
                             log_info.log_file_name);
         error= LOG_INFO_FATAL;
         goto err;
@@ -2449,7 +2455,7 @@
           push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                               ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                               log_info.log_file_name);
-          sql_print_information("Failed to delete file '%s'",
+          sql_print_information(_("Failed to delete file '%s'"),
                                 log_info.log_file_name);
           my_errno= 0;
         }
@@ -2457,10 +2463,10 @@
         {
           push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                               ER_BINLOG_PURGE_FATAL_ERR,
-                              "a problem with deleting %s; "
+                              _("a problem with deleting %s; "
                               "consider examining correspondence "
                               "of your binlog index file "
-                              "to the actual binlog files",
+                              "to the actual binlog files"),
                               log_info.log_file_name);
           if (my_errno == EMFILE)
           {
@@ -2541,7 +2547,7 @@
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                             ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                             log_info.log_file_name);
-	sql_print_information("Failed to execute stat on file '%s'",
+	sql_print_information(_("Failed to execute stat() on file '%s'"),
 			      log_info.log_file_name);
         my_errno= 0;
       }
@@ -2552,10 +2558,10 @@
         */
         push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                             ER_BINLOG_PURGE_FATAL_ERR,
-                            "a problem with getting info on being purged %s; "
+                            _("a problem with getting info on being purged %s; "
                             "consider examining correspondence "
                             "of your binlog index file "
-                            "to the actual binlog files",
+                            "to the actual binlog files"),
                             log_info.log_file_name);
         error= LOG_INFO_FATAL;
         goto err;
@@ -2573,7 +2579,7 @@
           push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_WARN,
                               ER_LOG_PURGE_NO_FILE, ER(ER_LOG_PURGE_NO_FILE),
                               log_info.log_file_name);
-          sql_print_information("Failed to delete file '%s'",
+          sql_print_information(_("Failed to delete file '%s'"),
                                 log_info.log_file_name);
           my_errno= 0;
         }
@@ -2581,10 +2587,10 @@
         {
           push_warning_printf(current_thd, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                               ER_BINLOG_PURGE_FATAL_ERR,
-                              "a problem with deleting %s; "
+                              _("a problem with deleting %s; "
                               "consider examining correspondence "
                               "of your binlog index file "
-                              "to the actual binlog files",
+                              "to the actual binlog files"),
                               log_info.log_file_name);
           error= LOG_INFO_FATAL;
           goto err;
@@ -4048,11 +4054,11 @@
   {
     inited= 1;
     crashed= true;
-    sql_print_information("Recovering after a crash using %s", opt_name);
+    sql_print_information(_("Recovering after a crash using %s"), opt_name);
     if (tc_heuristic_recover)
     {
-      sql_print_error("Cannot perform automatic crash recovery when "
-                      "--tc-heuristic-recover is used");
+      sql_print_error(_("Cannot perform automatic crash recovery when "
+                      "--tc-heuristic-recover is used"));
       goto err;
     }
     file_length= my_seek(fd, 0L, MY_SEEK_END, MYF(MY_WME+MY_FAE));
@@ -4388,7 +4394,7 @@
 
   if (memcmp(data, tc_log_magic, sizeof(tc_log_magic)))
   {
-    sql_print_error("Bad magic header in tc log");
+    sql_print_error(_("Bad magic header in tc log"));
     goto err1;
   }
 
@@ -4398,9 +4404,9 @@
   */
   if (data[sizeof(tc_log_magic)] != total_ha_2pc)
   {
-    sql_print_error("Recovery failed! You must enable "
+    sql_print_error(_("Recovery failed! You must enable "
                     "exactly %d storage engines that support "
-                    "two-phase commit protocol",
+                    "two-phase commit protocol"),
                     data[sizeof(tc_log_magic)]);
     goto err1;
   }
@@ -4426,10 +4432,10 @@
 err2:
   hash_free(&xids);
 err1:
-  sql_print_error("Crash recovery failed. Either correct the problem "
+  sql_print_error(_("Crash recovery failed. Either correct the problem "
                   "(if it's, for example, out of memory error) and restart, "
-                  "or delete tc log and start mysqld with "
-                  "--tc-heuristic-recover={commit|rollback}");
+                  "or delete tc log and start drizzled with "
+                  "--tc-heuristic-recover={commit|rollback}"));
   return 1;
 }
 #endif
@@ -4456,10 +4462,10 @@
   if (!tc_heuristic_recover)
     return 0;
 
-  sql_print_information("Heuristic crash recovery mode");
+  sql_print_information(_("Heuristic crash recovery mode"));
   if (ha_recover(0))
-    sql_print_error("Heuristic crash recovery failed");
-  sql_print_information("Please restart mysqld without --tc-heuristic-recover");
+    sql_print_error(_("Heuristic crash recovery failed"));
+  sql_print_information(_("Please restart mysqld without --tc-heuristic-recover"));
   return 1;
 }
 
@@ -4503,7 +4509,7 @@
   if ((error= find_log_pos(&log_info, NullS, 1)))
   {
     if (error != LOG_INFO_EOF)
-      sql_print_error("find_log_pos() failed (error: %d)", error);
+      sql_print_error(_("find_log_pos() failed (error: %d)"), error);
     else
       error= 0;
     goto err;
@@ -4527,7 +4533,7 @@
 
     if (error !=  LOG_INFO_EOF)
     {
-      sql_print_error("find_log_pos() failed (error: %d)", error);
+      sql_print_error(_("find_log_pos() failed (error: %d)"), error);
       goto err;
     }
 
@@ -4541,7 +4547,7 @@
         ev->get_type_code() == FORMAT_DESCRIPTION_EVENT &&
         ev->flags & LOG_EVENT_BINLOG_IN_USE_F)
     {
-      sql_print_information("Recovering after a crash using %s", opt_name);
+      sql_print_information(_("Recovering after a crash using %s"), opt_name);
       error= recover(&log, (Format_description_log_event *)ev);
     }
     else
@@ -4640,10 +4646,10 @@
   free_root(&mem_root, MYF(0));
   hash_free(&xids);
 err1:
-  sql_print_error("Crash recovery failed. Either correct the problem "
+  sql_print_error(_("Crash recovery failed. Either correct the problem "
                   "(if it's, for example, out of memory error) and restart, "
                   "or delete (or rename) binary log and start mysqld with "
-                  "--tc-heuristic-recover={commit|rollback}");
+                  "--tc-heuristic-recover={commit|rollback}"));
   return 1;
 }
 

=== modified file 'drizzled/log_event.cc'
--- drizzled/log_event.cc	2008-08-16 22:34:15 +0000
+++ drizzled/log_event.cc	2008-08-18 04:35:40 +0000
@@ -30,6 +30,8 @@
 #include <mysys/base64.h>
 #include <mysys/my_bitmap.h>
 
+#include <libdrizzle/gettext.h>
+
 #define log_cs	&my_charset_latin1
 
 #define FLAGSTR(V,F) ((V)&(F)?#F" ":"")
@@ -985,8 +987,8 @@
   if (!res)
   {
     assert(error != 0);
-    sql_print_error("Error in Log_event::read_log_event(): "
-                    "'%s', data_len: %d, event_type: %d",
+    sql_print_error(_("Error in Log_event::read_log_event(): "
+                    "'%s', data_len: %d, event_type: %d"),
 		    error,data_len,head[EVENT_TYPE_OFFSET]);
     my_free(buf, MYF(MY_ALLOW_ZERO_PTR));
     /*
@@ -3688,9 +3690,9 @@
       if (thd->cuted_fields)
       {
 	/* log_pos is the position of the LOAD event in the master log */
-        sql_print_warning("Slave: load data infile on table '%s' at "
+        sql_print_warning(_("Slave: load data infile on table '%s' at "
                           "log position %s in log '%s' produced %ld "
-                          "warning(s). Default database: '%s'",
+                          "warning(s). Default database: '%s'"),
                           (char*) table_name,
                           llstr(log_pos,llbuff), RPL_LOG_NAME, 
                           (ulong) thd->cuted_fields,
@@ -4726,7 +4728,7 @@
     master_pos = rli->group_master_log_pos;
   }
   else
-    sql_print_error("Out of memory while recording slave event");
+    sql_print_error(_("Out of memory while recording slave event"));
   pthread_mutex_unlock(&rli->data_lock);
   pthread_mutex_unlock(&mi->data_lock);
   return;

=== modified file 'drizzled/rpl_rli.cc'
--- drizzled/rpl_rli.cc	2008-08-16 22:34:15 +0000
+++ drizzled/rpl_rli.cc	2008-08-18 04:35:40 +0000
@@ -20,6 +20,8 @@
 #include "sql_repl.h"  // For check_binlog_magic
 #include "rpl_utility.h"
 
+#include <libdrizzle/gettext.h>
+
 static int32_t count_relay_log_space(Relay_log_info* rli);
 
 // Defined in slave.cc
@@ -129,11 +131,11 @@
         instead require a name. But as we don't want to break many existing
         setups, we only give warning, not error.
       */
-      sql_print_warning("Neither --relay-log nor --relay-log-index were used;"
+      sql_print_warning(_("Neither --relay-log nor --relay-log-index were used;"
                         " so replication "
                         "may break when this MySQL server acts as a "
                         "slave and has his hostname changed!! Please "
-                        "use '--relay-log=%s' to avoid this problem.", ln);
+                        "use '--relay-log=%s' to avoid this problem."), ln);
       name_warning_sent= 1;
     }
     /*
@@ -146,7 +148,8 @@
                             max_binlog_size), 1))
     {
       pthread_mutex_unlock(&rli->data_lock);
-      sql_print_error("Failed in open_log() called from init_relay_log_info()");
+      sql_print_error(_("Failed in open_log() called from "
+                        "init_relay_log_info()"));
       return(1);
     }
   }
@@ -162,15 +165,15 @@
       my_close(info_fd, MYF(MY_WME));
     if ((info_fd = my_open(fname, O_CREAT|O_RDWR|O_BINARY, MYF(MY_WME))) < 0)
     {
-      sql_print_error("Failed to create a new relay log info file (\
-file '%s', errno %d)", fname, my_errno);
+      sql_print_error(_("Failed to create a new relay log info file "
+                        "( file '%s', errno %d)"), fname, my_errno);
       msg= current_thd->main_da.message();
       goto err;
     }
     if (init_io_cache(&rli->info_file, info_fd, IO_SIZE*2, READ_CACHE, 0L,0,
                       MYF(MY_WME)))
     {
-      sql_print_error("Failed to create a cache on relay log info file '%s'",
+      sql_print_error(_("Failed to create a cache on relay log info file '%s'"),
                       fname);
       msg= current_thd->main_da.message();
       goto err;
@@ -180,7 +183,7 @@
     if (init_relay_log_pos(rli,NullS,BIN_LOG_HEADER_SIZE,0 /* no data lock */,
                            &msg, 0))
     {
-      sql_print_error("Failed to open the relay log 'FIRST' (relay_log_pos 4)");
+      sql_print_error(_("Failed to open the relay log 'FIRST' (relay_log_pos 4)"));
       goto err;
     }
     rli->group_master_log_name[0]= 0;
@@ -196,15 +199,16 @@
       int32_t error=0;
       if ((info_fd = my_open(fname, O_RDWR|O_BINARY, MYF(MY_WME))) < 0)
       {
-        sql_print_error("\
-Failed to open the existing relay log info file '%s' (errno %d)",
+        sql_print_error(_("Failed to open the existing relay log info "
+                          "file '%s' (errno %d)"),
                         fname, my_errno);
         error= 1;
       }
       else if (init_io_cache(&rli->info_file, info_fd,
                              IO_SIZE*2, READ_CACHE, 0L, 0, MYF(MY_WME)))
       {
-        sql_print_error("Failed to create a cache on relay log info file '%s'",
+        sql_print_error(_("Failed to create a cache on relay log info "
+                          "file '%s'"),
                         fname);
         error= 1;
       }
@@ -246,7 +250,7 @@
                            &msg, 0))
     {
       char llbuf[22];
-      sql_print_error("Failed to open the relay log '%s' (relay_log_pos %s)",
+      sql_print_error(_("Failed to open the relay log '%s' (relay_log_pos %s)"),
                       rli->group_relay_log_name,
                       llstr(rli->group_relay_log_pos, llbuf));
       goto err;
@@ -261,10 +265,10 @@
   */
   reinit_io_cache(&rli->info_file, WRITE_CACHE,0L,0,1);
   if ((error= flush_relay_log_info(rli)))
-    sql_print_error("Failed to flush relay log info file");
+    sql_print_error(_("Failed to flush relay log info file"));
   if (count_relay_log_space(rli))
   {
-    msg="Error counting relay log space";
+    msg=_("Error counting relay log space");
     goto err;
   }
   rli->inited= 1;
@@ -288,7 +292,7 @@
   struct stat s;
   if (stat(linfo->log_file_name,&s))
   {
-    sql_print_error("log %s listed in the index, but failed to stat",
+    sql_print_error(_("log %s listed in the index, but failed to stat"),
                     linfo->log_file_name);
     return(1);
   }
@@ -303,7 +307,8 @@
   rli->log_space_total= 0;
   if (rli->relay_log.find_log_pos(&linfo, NullS, 1))
   {
-    sql_print_error("Could not find first log while counting relay log space");
+    sql_print_error(_("Could not find first log while counting relay "
+                      "log space"));
     return(1);
   }
   do
@@ -959,8 +964,8 @@
       else
       {
         /* Probably error so we aborting */
-        sql_print_error("Slave SQL thread is stopped because UNTIL "
-                        "condition is bad.");
+        sql_print_error(_("Slave SQL thread is stopped because UNTIL "
+                          "condition is bad."));
         return(true);
       }
     }

=== modified file 'drizzled/scheduler.cc'
--- drizzled/scheduler.cc	2008-08-06 18:46:02 +0000
+++ drizzled/scheduler.cc	2008-08-16 23:47:43 +0000
@@ -118,7 +118,7 @@
     
   if (!io_event)
   {
-    sql_print_error("Memory allocation error in thd_scheduler::init\n");
+    sql_print_error(_("Memory allocation error in thd_scheduler::init\n"));
     return true;
   }
   
@@ -209,13 +209,13 @@
   /* set up the pipe used to add new thds to the event pool */
   if (init_pipe(thd_add_pipe))
   {
-    sql_print_error("init_pipe(thd_add_pipe) error in libevent_init\n");
+    sql_print_error(_("init_pipe(thd_add_pipe) error in libevent_init\n"));
     return(1);
   }
   /* set up the pipe used to kill thds in the event queue */
   if (init_pipe(thd_kill_pipe))
   {
-    sql_print_error("init_pipe(thd_kill_pipe) error in libevent_init\n");
+    sql_print_error(_("init_pipe(thd_kill_pipe) error in libevent_init\n"));
     close(thd_add_pipe[0]);
     close(thd_add_pipe[1]);
     return(1);
@@ -227,7 +227,7 @@
  
  if (event_add(&thd_add_event, NULL) || event_add(&thd_kill_event, NULL))
  {
-   sql_print_error("thd_add_event event_add error in libevent_init\n");
+   sql_print_error(_("thd_add_event event_add error in libevent_init\n"));
    libevent_end();
    return(1);
    
@@ -243,7 +243,7 @@
     if ((error= pthread_create(&thread, &connection_attrib,
                                libevent_thread_proc, 0)))
     {
-      sql_print_error("Can't create completion port thread (error %d)",
+      sql_print_error(_("Can't create completion port thread (error %d)"),
                       error);
       pthread_mutex_unlock(&LOCK_thread_count);
       libevent_end();                      // Cleanup
@@ -356,7 +356,7 @@
       /* Add to libevent */
       if (event_add(thd->scheduler.io_event, NULL))
       {
-        sql_print_error("event_add error in libevent_add_thd_callback\n");
+        sql_print_error(_("event_add error in libevent_add_thd_callback\n"));
         libevent_connection_close(thd);
       } 
       else
@@ -382,7 +382,7 @@
 {
   if (thd->scheduler.init(thd))
   {
-    sql_print_error("Scheduler init error in libevent_add_new_connection\n");
+    sql_print_error(_("Scheduler init error in libevent_add_new_connection\n"));
     pthread_mutex_unlock(&LOCK_thread_count);
     libevent_connection_close(thd);
     return;
@@ -464,7 +464,7 @@
   if (init_new_connection_handler_thread())
   {
     my_thread_global_end();
-    sql_print_error("libevent_thread_proc: my_thread_init() failed\n");
+    sql_print_error(_("libevent_thread_proc: my_thread_init() failed\n"));
     exit(1);
   }
 

=== modified file 'drizzled/serialize/Makefile.am'
--- drizzled/serialize/Makefile.am	2008-08-16 15:41:14 +0000
+++ drizzled/serialize/Makefile.am	2008-08-18 04:35:40 +0000
@@ -17,7 +17,7 @@
 
 LDADD =
 
-libserialize_la_CXXFLAGS = -Wno-all -Wno-error
+libserialize_la_CXXFLAGS =
 
 noinst_LTLIBRARIES = libserialize.la
 
@@ -48,11 +48,11 @@
 
 table_reader_LDADD = $(top_builddir)/drizzled/serialize/libserialize.la -lprotobuf
 table_reader_SOURCES =  table_reader.cc
-table_reader_CXXFLAGS = -Wno-all -Wno-error
+table_reader_CXXFLAGS =
 
 table_writer_LDADD = $(top_builddir)/drizzled/serialize/libserialize.la -lprotobuf
 table_writer_SOURCES =  table_writer.cc
-table_writer_CXXFLAGS = -Wno-all -Wno-error
+table_writer_CXXFLAGS =
 
 EXTRA_DIST = schema.proto table.proto
 BUILT_SOURCES = schema.pb.cc table.pb.cc

=== modified file 'drizzled/set_var.cc'
--- drizzled/set_var.cc	2008-08-12 21:13:01 +0000
+++ drizzled/set_var.cc	2008-08-16 23:47:43 +0000
@@ -52,6 +52,7 @@
 #include <mysys/thr_alarm.h>
 #include <storage/myisam/myisam.h>
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 extern const CHARSET_INFO *character_set_filesystem;
 
@@ -901,8 +902,8 @@
   if (bit_is_set(slave_exec_mode_options, SLAVE_EXEC_MODE_STRICT) == 1 &&
       bit_is_set(slave_exec_mode_options, SLAVE_EXEC_MODE_IDEMPOTENT) == 1)
   {
-    sql_print_error("Ambiguous slave modes combination."
-                    " STRICT will be used");
+    sql_print_error(_("Ambiguous slave modes combination."
+                    " STRICT will be used"));
     bit_do_clear(slave_exec_mode_options, SLAVE_EXEC_MODE_IDEMPOTENT);
   }
   if (bit_is_set(slave_exec_mode_options, SLAVE_EXEC_MODE_IDEMPOTENT) == 0)

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2008-08-17 07:27:12 +0000
+++ drizzled/sql_base.cc	2008-08-18 04:35:40 +0000
@@ -19,6 +19,7 @@
 #include <drizzled/sql_select.h>
 #include <mysys/my_dir.h>
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 #define FLAGSTR(S,F) ((S) & (F) ? #F " " : "")
 
@@ -2526,7 +2527,7 @@
 
 #ifdef EXTRA_DEBUG
   if (table->db_stat)
-    sql_print_error("Table %s had a open data handler in reopen_table",
+    sql_print_error(_("Table %s had a open data handler in reopen_table"),
 		    table->alias);
 #endif
   memset(&table_list, 0, sizeof(TABLE_LIST));
@@ -3185,7 +3186,7 @@
        /* Give right error message */
        thd->clear_error();
        my_error(ER_NOT_KEYFILE, MYF(0), share->table_name.str, my_errno);
-       sql_print_error("Couldn't repair table: %s.%s", share->db.str,
+       sql_print_error(_("Couldn't repair table: %s.%s"), share->db.str,
                        share->table_name.str);
        if (entry->file)
  	closefrm(entry, 0);
@@ -3228,8 +3229,8 @@
           DBA on top of warning the client (which will automatically be done
           because of MYF(MY_WME) in my_malloc() above).
         */
-        sql_print_error("When opening HEAP table, could not allocate memory "
-                        "to write 'DELETE FROM `%s`.`%s`' to the binary log",
+        sql_print_error(_("When opening HEAP table, could not allocate memory "
+                          "to write 'DELETE FROM `%s`.`%s`' to the binary log"),
                         table_list->db, table_list->table_name);
         closefrm(entry, 0);
         goto err;
@@ -3958,7 +3959,7 @@
   if (!frm_only && file && file->ha_delete_table(path))
   {
     error=1;
-    sql_print_warning("Could not remove temporary table: '%s', error: %d",
+    sql_print_warning(_("Could not remove temporary table: '%s', error: %d"),
                       path, my_errno);
   }
   delete file;

=== modified file 'drizzled/sql_db.cc'
--- drizzled/sql_db.cc	2008-08-13 23:12:06 +0000
+++ drizzled/sql_db.cc	2008-08-16 23:47:43 +0000
@@ -24,6 +24,7 @@
 #include <mysys/my_dir.h>
 #include "log.h"
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 
 #define MAX_DROP_TABLE_Q_LEN      1024
@@ -392,7 +393,7 @@
   buffer= db.characterset();
   if (!(create->default_table_charset= get_charset_by_csname(buffer.c_str(), MY_CS_PRIMARY, MYF(0))))
   {
-    sql_print_error("Error while loading database options: '%s':",path);
+    sql_print_error(_("Error while loading database options: '%s':"),path);
     sql_print_error(ER(ER_UNKNOWN_COLLATION), buffer.c_str());
     create->default_table_charset= default_charset_info;
   }
@@ -400,7 +401,7 @@
   buffer= db.collation();
   if (!(create->default_table_charset= get_charset_by_name(buffer.c_str(), MYF(0))))
   {
-    sql_print_error("Error while loading database options: '%s':",path);
+    sql_print_error(_("Error while loading database options: '%s':"),path);
     sql_print_error(ER(ER_UNKNOWN_COLLATION), buffer.c_str());
     create->default_table_charset= default_charset_info;
   }

=== modified file 'drizzled/sql_plugin.cc'
--- drizzled/sql_plugin.cc	2008-08-12 21:13:01 +0000
+++ drizzled/sql_plugin.cc	2008-08-16 23:47:43 +0000
@@ -644,7 +644,7 @@
   {
     if ((*plugin_type_deinitialize[plugin->plugin->type])(plugin))
     {
-      sql_print_error("Plugin '%s' of type %s failed deinitialization",
+      sql_print_error(_("Plugin '%s' of type %s failed deinitialization"),
                       plugin->name.str, plugin_type_names[plugin->plugin->type].str);
     }
   }
@@ -658,7 +658,7 @@
     exit until NDB is shut down.
   */
   if (ref_check && plugin->ref_count)
-    sql_print_error("Plugin '%s' has ref_count=%d after deinitialization.",
+    sql_print_error(_("Plugin '%s' has ref_count=%d after deinitialization."),
                     plugin->name.str, plugin->ref_count);
 }
 
@@ -778,7 +778,7 @@
   {
     if ((*plugin_type_initialize[plugin->plugin->type])(plugin))
     {
-      sql_print_error("Plugin '%s' registration as a %s failed.",
+      sql_print_error(_("Plugin '%s' registration as a %s failed."),
                       plugin->name.str, plugin_type_names[plugin->plugin->type].str);
       goto err;
     }
@@ -787,7 +787,7 @@
   {
     if (plugin->plugin->init(plugin))
     {
-      sql_print_error("Plugin '%s' init function returned error.",
+      sql_print_error(_("Plugin '%s' init function returned error."),
                       plugin->name.str);
       goto err;
     }
@@ -1032,7 +1032,7 @@
   {
     if (p == buffer + sizeof(buffer) - 1)
     {
-      sql_print_error("plugin-load parameter too long");
+      sql_print_error(_("plugin-load parameter too long"));
       return(true);
     }
 
@@ -1092,7 +1092,7 @@
   }
   return(false);
 error:
-  sql_print_error("Couldn't load plugin named '%s' with soname '%s'.",
+  sql_print_error(_("Couldn't load plugin named '%s' with soname '%s'."),
                   name.str, dl.str);
   return(true);
 }
@@ -1143,7 +1143,8 @@
     }
 
     if (count > free_slots)
-      sql_print_warning("Forcing shutdown of %d plugins", count - free_slots);
+      sql_print_warning(_("Forcing shutdown of %d plugins"),
+                        count - free_slots);
 
     plugins= (struct st_plugin_int **) my_alloca(sizeof(void*) * (count+1));
 
@@ -1164,7 +1165,7 @@
     for (i= 0; i < count; i++)
       if (!(plugins[i]->state & (PLUGIN_IS_UNINITIALIZED | PLUGIN_IS_FREED)))
       {
-        sql_print_information("Plugin '%s' will be forced to shutdown",
+        sql_print_information(_("Plugin '%s' will be forced to shutdown"),
                               plugins[i]->name.str);
         /*
           We are forcing deinit on plugins so we don't want to do a ref_count
@@ -1180,7 +1181,7 @@
     for (i= 0; i < count; i++)
     {
       if (plugins[i]->ref_count)
-        sql_print_error("Plugin '%s' has ref_count=%d after shutdown.",
+        sql_print_error(_("Plugin '%s' has ref_count=%d after shutdown."),
                         plugins[i]->name.str, plugins[i]->ref_count);
       if (plugins[i]->state & PLUGIN_IS_UNINITIALIZED)
         plugin_del(plugins[i]);
@@ -2429,7 +2430,7 @@
       (((thdvar_set_t *)opt)->resolve)= mysql_sys_var_ptr_set;
       break;
     default:
-      sql_print_error("Unknown variable type code 0x%x in plugin '%s'.",
+      sql_print_error(_("Unknown variable type code 0x%x in plugin '%s'."),
                       opt->flags, plugin_name);
       return(-1);
     };
@@ -2472,9 +2473,9 @@
         if ((opt->flags & (PLUGIN_VAR_MEMALLOC | PLUGIN_VAR_READONLY)) == false)
         {
           opt->flags|= PLUGIN_VAR_READONLY;
-          sql_print_warning("Server variable %s of plugin %s was forced "
+          sql_print_warning(_("Server variable %s of plugin %s was forced "
                             "to be read-only: string variable without "
-                            "update_func and PLUGIN_VAR_MEMALLOC flag",
+                            "update_func and PLUGIN_VAR_MEMALLOC flag"),
                             opt->name, plugin_name);
         }
       }
@@ -2492,7 +2493,7 @@
         opt->update= update_func_int64_t;
       break;
     default:
-      sql_print_error("Unknown variable type code 0x%x in plugin '%s'.",
+      sql_print_error(_("Unknown variable type code 0x%x in plugin '%s'."),
                       opt->flags, plugin_name);
       return(-1);
     }
@@ -2503,7 +2504,7 @@
 
     if (!opt->name)
     {
-      sql_print_error("Missing variable name in plugin '%s'.",
+      sql_print_error(_("Missing variable name in plugin '%s'."),
                       plugin_name);
       return(-1);
     }
@@ -2520,8 +2521,8 @@
       /* this should not fail because register_var should create entry */
       if (!(v= find_bookmark(name, opt->name, opt->flags)))
       {
-        sql_print_error("Thread local variable '%s' not allocated "
-                        "in plugin '%s'.", opt->name, plugin_name);
+        sql_print_error(_("Thread local variable '%s' not allocated "
+                        "in plugin '%s'."), opt->name, plugin_name);
         return(-1);
       }
 
@@ -2639,14 +2640,14 @@
   {
     if (!(opts= (my_option*) alloc_root(tmp_root, sizeof(my_option) * count)))
     {
-      sql_print_error("Out of memory for plugin '%s'.", tmp->name.str);
+      sql_print_error(_("Out of memory for plugin '%s'."), tmp->name.str);
       return(-1);
     }
     memset(opts, 0, sizeof(my_option) * count);
 
     if (construct_options(tmp_root, tmp, opts, can_disable))
     {
-      sql_print_error("Bad options for plugin '%s'.", tmp->name.str);
+      sql_print_error(_("Bad options for plugin '%s'."), tmp->name.str);
       return(-1);
     }
 
@@ -2655,7 +2656,7 @@
 
     if (error)
     {
-       sql_print_error("Parsing options for plugin '%s' failed.",
+       sql_print_error(_("Parsing options for plugin '%s' failed."),
                        tmp->name.str);
        goto err;
     }
@@ -2698,7 +2699,7 @@
       chain.last->next = NULL;
       if (mysql_add_sys_var_chain(chain.first, NULL))
       {
-        sql_print_error("Plugin '%s' has conflicting system variables",
+        sql_print_error(_("Plugin '%s' has conflicting system variables"),
                         tmp->name.str);
         goto err;
       }
@@ -2708,7 +2709,7 @@
   }
 
   if (enabled_saved && global_system_variables.log_warnings)
-    sql_print_information("Plugin '%s' disabled by command line option",
+    sql_print_information(_("Plugin '%s' disabled by command line option"),
                           tmp->name.str);
 err:
   if (opts)

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2008-08-16 22:34:15 +0000
+++ drizzled/sql_select.cc	2008-08-18 04:35:40 +0000
@@ -29,6 +29,7 @@
 
 #include <mysys/my_bit.h>
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 const char *join_type_str[]={ "UNKNOWN","system","const","eq_ref","ref",
 			      "MAYBE_REF","ALL","range","index",
@@ -11315,7 +11316,7 @@
     print them to the .err log
   */
   if (error != HA_ERR_LOCK_DEADLOCK && error != HA_ERR_LOCK_WAIT_TIMEOUT)
-    sql_print_error("Got error %d when reading table '%s'",
+    sql_print_error(_("Got error %d when reading table '%s'"),
 		    error, table->s->path.str);
   table->file->print_error(error,MYF(0));
   return 1;

=== modified file 'drizzled/sql_show.cc'
--- drizzled/sql_show.cc	2008-08-16 22:34:15 +0000
+++ drizzled/sql_show.cc	2008-08-18 04:35:40 +0000
@@ -20,6 +20,7 @@
 #include <drizzled/sql_show.h>
 #include "repl_failsafe.h"
 #include <mysys/my_dir.h>
+#include <libdrizzle/gettext.h>
 
 #define STR_OR_NIL(S) ((S) ? (S) : "<nil>")
 
@@ -4667,7 +4668,7 @@
 
     if (plugin->plugin->init(schema_table))
     {
-      sql_print_error("Plugin '%s' init function returned error.",
+      sql_print_error(_("Plugin '%s' init function returned error."),
                       plugin->name.str);
       goto err;
     }

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2008-08-16 22:34:15 +0000
+++ drizzled/sql_table.cc	2008-08-18 04:35:40 +0000
@@ -19,6 +19,7 @@
 #include <storage/myisam/myisam.h>
 #include <drizzled/sql_show.h>
 #include <drizzled/drizzled_error_messages.h>
+#include <libdrizzle/gettext.h>
 
 int creating_table= 0;        // How many mysql_create_table are running
 
@@ -77,11 +78,7 @@
     {
       res= (strxnmov(to, to_length, MYSQL50_TABLE_NAME_PREFIX,  from, NullS) -
             to);
-      sql_print_error("Invalid (old?) table or database name '%s'", from);
-      /*
-        TODO: add a stored procedure for fix table and database names,
-        and mention its name in error log.
-      */
+      sql_print_error(_("Invalid (old?) table or database name '%s'"), from);
     }
   }
 
@@ -2716,7 +2713,7 @@
       {
         char buf[ERRMSGSIZE+20];
         uint length=snprintf(buf, ERRMSGSIZE,
-                             "Unknown - internal error %d during operation",
+                             _("Unknown - internal error %d during operation"),
                              result_code);
         protocol->store(STRING_WITH_LEN("error"), system_charset_info);
         protocol->store(buf, length, system_charset_info);
@@ -4993,7 +4990,7 @@
       my_free(t_table, MYF(0));
     }
     else
-      sql_print_warning("Could not open table %s.%s after rename\n",
+      sql_print_warning(_("Could not open table %s.%s after rename\n"),
                         new_db,table_name);
     ha_flush_logs(old_db_type);
   }
@@ -5169,8 +5166,9 @@
     {
       char warn_buff[DRIZZLE_ERRMSG_SIZE];
       snprintf(warn_buff, sizeof(warn_buff), 
-               "ORDER BY ignored as there is a user-defined clustered index"
-               " in the table '%-.192s'", from->s->table_name.str);
+               _("ORDER BY ignored because there is a user-defined clustered "
+                 "index in the table '%-.192s'"),
+               from->s->table_name.str);
       push_warning(thd, DRIZZLE_ERROR::WARN_LEVEL_WARN, ER_UNKNOWN_ERROR,
                    warn_buff);
     }

=== modified file 'drizzled/sql_udf.cc'
--- drizzled/sql_udf.cc	2008-08-06 18:46:02 +0000
+++ drizzled/sql_udf.cc	2008-08-16 23:47:43 +0000
@@ -15,6 +15,7 @@
 
 /* This implements 'user defined functions' */
 #include <drizzled/server_includes.h>
+#include <libdrizzle/gettext.h>
 
 static bool udf_startup= false; /* We do not lock because startup is single threaded */
 static MEM_ROOT mem;
@@ -35,7 +36,7 @@
 
   if (hash_init(&udf_hash, system_charset_info, 32, 0, 0, get_hash_key, NULL, 0))
   {
-    sql_print_error("Can't allocate memory for udf structures");
+    sql_print_error(_("Can't allocate memory for udf structures"));
     hash_free(&udf_hash);
     free_root(&mem, MYF(0));
     return;
@@ -96,7 +97,7 @@
 
     if (plugin->plugin->init((void *)udff))
     {
-      sql_print_error("Plugin '%s' init function returned error.",
+      sql_print_error(_("Plugin '%s' init function returned error."),
                       plugin->name.str);
       goto err;
     }

=== modified file 'libdrizzle/client.c'
--- libdrizzle/client.c	2008-08-13 00:55:29 +0000
+++ libdrizzle/client.c	2008-08-16 21:06:40 +0000
@@ -50,13 +50,11 @@
 #define CLI_DRIZZLE_CONNECT drizzle_connect
 
 #include <mysys/my_sys.h>
-#include <mysys/mysys_err.h>
 #include <mystrings/m_string.h>
 #include <mystrings/m_ctype.h>
 #include <drizzled/error.h>
 #include "errmsg.h"
 #include <vio/violite.h>
-#include <mysys/my_pthread.h>        /* because of signal()  */
 
 #include <sys/stat.h>
 #include <signal.h>
@@ -86,6 +84,7 @@
 #include "client_settings.h"
 #include <drizzled/version.h>
 #include <libdrizzle/sql_common.h>
+#include <libdrizzle/gettext.h>
 
 uint    drizzle_port=0;
 char    *drizzle_unix_port= 0;
@@ -671,7 +670,7 @@
           if ((options->protocol= find_type(opt_arg,
                                             &sql_protocol_typelib,0)) <= 0)
           {
-            fprintf(stderr, "Unknown option to protocol: %s\n", opt_arg);
+            fprintf(stderr, _("Unknown option to protocol: %s\n"), opt_arg);
             exit(1);
           }
           break;
@@ -957,8 +956,6 @@
     if (my_init())
       return NULL;
 
-    init_client_errs();
-
     if (!drizzle_port)
     {
       drizzle_port = DRIZZLE_PORT;
@@ -1064,7 +1061,6 @@
   if (!drizzle_client_init)
     return;
 
-  finish_client_errs();
   vio_end();
 
   /* If library called my_init(), free memory allocated by it */
@@ -1154,7 +1150,7 @@
         if (!my_charset_same(drizzle->charset, collation))
         {
           my_printf_error(ER_UNKNOWN_ERROR,
-                         "COLLATION %s is not valid for CHARACTER SET %s",
+                         _("COLLATION %s is not valid for CHARACTER SET %s"),
                          MYF(0),
                          default_collation_name, drizzle->options.charset_name);
           drizzle->charset= NULL;
@@ -1276,7 +1272,7 @@
     if (gai_errno != 0)
     {
       set_drizzle_extended_error(drizzle, CR_UNKNOWN_HOST, unknown_sqlstate,
-                               ER(CR_UNKNOWN_HOST), host, errno);
+                                 ER(CR_UNKNOWN_HOST), host, errno);
 
       goto error;
     }
@@ -1340,8 +1336,7 @@
       vio_poll_read(net->vio, drizzle->options.connect_timeout))
   {
     set_drizzle_extended_error(drizzle, CR_SERVER_LOST, unknown_sqlstate,
-                             ER(CR_SERVER_LOST_EXTENDED),
-                             "waiting for initial communication packet",
+                             ER(CR_SERVER_LOST_INITIAL_COMM_WAIT),
                              errno);
     goto error;
   }
@@ -1354,8 +1349,7 @@
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
       set_drizzle_extended_error(drizzle, CR_SERVER_LOST, unknown_sqlstate,
-                               ER(CR_SERVER_LOST_EXTENDED),
-                               "reading initial communication packet",
+                               ER(CR_SERVER_LOST_INITIAL_COMM_READ),
                                errno);
     goto error;
   }
@@ -1486,8 +1480,7 @@
   if (my_net_write(net, (uchar*) buff, (size_t) (end-buff)) || net_flush(net))
   {
     set_drizzle_extended_error(drizzle, CR_SERVER_LOST, unknown_sqlstate,
-                             ER(CR_SERVER_LOST_EXTENDED),
-                             "sending authentication information",
+                             ER(CR_SERVER_LOST_SEND_AUTH),
                              errno);
     goto error;
   }
@@ -1501,8 +1494,7 @@
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
       set_drizzle_extended_error(drizzle, CR_SERVER_LOST, unknown_sqlstate,
-                               ER(CR_SERVER_LOST_EXTENDED),
-                               "reading authorization packet",
+                               ER(CR_SERVER_LOST_READ_AUTH),
                                errno);
     goto error;
   }
@@ -1515,8 +1507,7 @@
   {
     if (drizzle->net.last_errno == CR_SERVER_LOST)
         set_drizzle_extended_error(drizzle, CR_SERVER_LOST, unknown_sqlstate,
-                                 ER(CR_SERVER_LOST_EXTENDED),
-                                 "Setting intital database",
+                                 ER(CR_SERVER_LOST_SETTING_DB),
                                  errno);
     goto error;
   }

=== modified file 'libdrizzle/client_settings.h'
--- libdrizzle/client_settings.h	2008-08-10 17:18:41 +0000
+++ libdrizzle/client_settings.h	2008-08-17 06:26:18 +0000
@@ -34,7 +34,6 @@
 #define set_sigpipe(drizzle)
 #define reset_sigpipe(drizzle)
 
-void mysql_detach_stmt_list(LIST **stmt_list, const char *func_name);
 DRIZZLE *
 cli_drizzle_connect(DRIZZLE *drizzle,const char *host, const char *user,
 		       const char *passwd, const char *db,

=== modified file 'libdrizzle/drizzle.h'
--- libdrizzle/drizzle.h	2008-08-12 21:13:01 +0000
+++ libdrizzle/drizzle.h	2008-08-17 06:26:18 +0000
@@ -45,8 +45,6 @@
 #include <libdrizzle/drizzle_com.h>
 #include <libdrizzle/drizzle_time.h>
 
-#include <mysys/my_list.h> /* for LISTs used in 'MYSQL' */
-
 extern unsigned int drizzle_port;
 extern char *drizzle_unix_port;
 
@@ -219,7 +217,6 @@
   bool unused1;
   void *unused2, *unused3, *unused4, *unused5;
 
-  LIST  *stmts;                     /* list of all statements */
   const struct st_drizzle_methods *methods;
   void *thd;
   /*

=== modified file 'libdrizzle/errmsg.c'
--- libdrizzle/errmsg.c	2008-07-30 05:33:20 +0000
+++ libdrizzle/errmsg.c	2008-08-16 21:06:40 +0000
@@ -21,229 +21,86 @@
 /* (Error messages for the daemon are in share/language/errmsg.sys) */
 
 #include <drizzled/global.h>
-#include <mysys/my_sys.h>
+#include <libdrizzle/gettext.h>
 #include "errmsg.h"
 
-#ifdef GERMAN
-const char *client_errors[]=
-{
-  "Unbekannter MySQL Fehler",
-  "Kann UNIX-Socket nicht anlegen (%d)",
-  "Keine Verbindung zu lokalem MySQL Server, socket: '%-.100s' (%d)",
-  "Keine Verbindung zu MySQL Server auf %-.100s (%d)",
-  "Kann TCP/IP-Socket nicht anlegen (%d)",
-  "Unbekannter MySQL Server Host (%-.100s) (%d)",
-  "MySQL Server nicht vorhanden",
-  "Protokolle ungleich; Server Version = %d, Client Version = %d",
-  "MySQL client ran out of memory",
-  "Wrong host info",
-  "Localhost via UNIX socket",
-  "%-.100s via TCP/IP",
-  "Error in server handshake",
-  "Lost connection to MySQL server during query",
-  "Commands out of sync; you can't run this command now",
-  "Verbindung ueber Named Pipe: %-.32s",
-  "Kann nicht auf Named Pipe warten. Host: %-.64s  pipe: %-.32s (%lu)",
-  "Kann Named Pipe nicht oeffnen. Host: %-.64s  pipe: %-.32s (%lu)",
-  "Kann den Status der Named Pipe nicht setzen.  Host: %-.64s  pipe: %-.32s (%lu)",
-  "Can't initialize character set %-.32s (path: %-.100s)",
-  "Got packet bigger than 'max_allowed_packet' bytes",
-  "Embedded server",
-  "Error on SHOW SLAVE STATUS:",
-  "Error on SHOW SLAVE HOSTS:",
-  "Error connecting to slave:",
-  "Error connecting to master:",
-  "SSL connection error",
-  "Malformed packet",
-  "This client library is licensed only for use with MySQL servers having '%s' license",
-  "Invalid use of null pointer",
-  "Statement not prepared",
-  "No data supplied for parameters in prepared statement",
-  "Data truncated",
-  "No parameters exist in the statement",
-  "Invalid parameter number",
-  "Can't send long data for non-string/non-binary data types (parameter: %d)",
-  "Using unsupported buffer type: %d  (parameter: %d)",
-  "Shared memory: %-.100s",
-  "Can't open shared memory; client could not create request event (%lu)",
-  "Can't open shared memory; no answer event received from server (%lu)",
-  "Can't open shared memory; server could not allocate file mapping (%lu)",
-  "Can't open shared memory; server could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not allocate file mapping (%lu)",
-  "Can't open shared memory; client could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not create %s event (%lu)",
-  "Can't open shared memory; no answer from server (%lu)",
-  "Can't open shared memory; cannot send request event to server (%lu)",
-  "Wrong or unknown protocol",
-  "Invalid connection handle",
-  "Connection using old (pre-4.1.1) authentication protocol refused (client option 'secure_auth' enabled)",
-  "Row retrieval was canceled by drizzle_stmt_close() call",
-  "Attempt to read column without prior row fetch",
-  "Prepared statement contains no metadata",
-  "Attempt to read a row while there is no result set associated with the statement",
-  "This feature is not implemented yet",
-  "Lost connection to MySQL server at '%s', system error: %d",
-  "Statement closed indirectly because of a preceeding %s() call",
-  ""
-};
-
-/* Start of code added by Roberto M. Serqueira - martinsc@uol.com.br - 05.24.2001 */
-
-#elif defined PORTUGUESE
-const char *client_errors[]=
-{
-  "Erro desconhecido do MySQL",
-  "No pode criar 'UNIX socket' (%d)",
-  "No pode se conectar ao servidor MySQL local atravs do 'socket' '%-.100s' (%d)", 
-  "No pode se conectar ao servidor MySQL em '%-.100s' (%d)",
-  "No pode criar 'socket TCP/IP' (%d)",
-  "'Host' servidor MySQL '%-.100s' (%d) desconhecido",
-  "Servidor MySQL desapareceu",
-  "Incompatibilidade de protocolos; verso do servidor = %d, verso do cliente = %d",
-  "Cliente do MySQL com falta de memria",
-  "Informao invlida de 'host'",
-  "Localhost via 'UNIX socket'",
-  "%-.100s via 'TCP/IP'",
-  "Erro na negociao de acesso ao servidor",
-  "Conexo perdida com servidor MySQL durante 'query'",
-  "Comandos fora de sincronismo; voc no pode executar este comando agora",
-  "Named pipe: %-.32s",
-  "No pode esperar pelo 'named pipe' para o 'host' %-.64s - 'pipe' %-.32s (%lu)",
-  "No pode abrir 'named pipe' para o 'host' %-.64s - 'pipe' %-.32s (%lu)",
-  "No pode estabelecer o estado do 'named pipe' para o 'host' %-.64s - 'pipe' %-.32s (%lu)",
-  "No pode inicializar conjunto de caracteres %-.32s (caminho %-.100s)",
-  "Obteve pacote maior do que 'max_allowed_packet' bytes",
-  "Embedded server"
-  "Error on SHOW SLAVE STATUS:",
-  "Error on SHOW SLAVE HOSTS:",
-  "Error connecting to slave:",
-  "Error connecting to master:",
-  "SSL connection error",
-  "Malformed packet",
-  "This client library is licensed only for use with MySQL servers having '%s' license",
-  "Invalid use of null pointer",
-  "Statement not prepared",
-  "No data supplied for parameters in prepared statement",
-  "Data truncated",
-  "No parameters exist in the statement",
-  "Invalid parameter number",
-  "Can't send long data for non-string/non-binary data types (parameter: %d)",
-  "Using unsupported buffer type: %d  (parameter: %d)",
-  "Shared memory: %-.100s",
-  "Can't open shared memory; client could not create request event (%lu)",
-  "Can't open shared memory; no answer event received from server (%lu)",
-  "Can't open shared memory; server could not allocate file mapping (%lu)",
-  "Can't open shared memory; server could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not allocate file mapping (%lu)",
-  "Can't open shared memory; client could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not create %s event (%lu)",
-  "Can't open shared memory; no answer from server (%lu)",
-  "Can't open shared memory; cannot send request event to server (%lu)",
-  "Wrong or unknown protocol",
-  "Invalid connection handle",
-  "Connection using old (pre-4.1.1) authentication protocol refused (client option 'secure_auth' enabled)",
-  "Row retrieval was canceled by drizzle_stmt_close() call",
-  "Attempt to read column without prior row fetch",
-  "Prepared statement contains no metadata",
-  "Attempt to read a row while there is no result set associated with the statement",
-  "This feature is not implemented yet",
-  "Lost connection to MySQL server at '%s', system error: %d",
-  "Statement closed indirectly because of a preceeding %s() call",
-  ""
-};
-
-#else /* ENGLISH */
-const char *client_errors[]=
-{
-  "Unknown MySQL error",
-  "Can't create UNIX socket (%d)",
-  "Can't connect to local MySQL server through socket '%-.100s' (%d)",
-  "Can't connect to MySQL server on '%-.100s' (%d)",
-  "Can't create TCP/IP socket (%d)",
-  "Unknown MySQL server host '%-.100s' (%d)",
-  "MySQL server has gone away",
-  "Protocol mismatch; server version = %d, client version = %d",
-  "MySQL client ran out of memory",
-  "Wrong host info",
-  "Localhost via UNIX socket",
-  "%-.100s via TCP/IP",
-  "Error in server handshake",
-  "Lost connection to MySQL server during query",
-  "Commands out of sync; you can't run this command now",
-  "Named pipe: %-.32s",
-  "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)",
-  "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)",
-  "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)",
-  "Can't initialize character set %-.32s (path: %-.100s)",
-  "Got packet bigger than 'max_allowed_packet' bytes",
-  "Embedded server",
-  "Error on SHOW SLAVE STATUS:",
-  "Error on SHOW SLAVE HOSTS:",
-  "Error connecting to slave:",
-  "Error connecting to master:",
-  "SSL connection error",
-  "Malformed packet",
-  "This client library is licensed only for use with MySQL servers having '%s' license",
-  "Invalid use of null pointer",
-  "Statement not prepared",
-  "No data supplied for parameters in prepared statement",
-  "Data truncated",
-  "No parameters exist in the statement",
-  "Invalid parameter number",
-  "Can't send long data for non-string/non-binary data types (parameter: %d)",
-  "Using unsupported buffer type: %d  (parameter: %d)",
-  "Shared memory: %-.100s",
-  "Can't open shared memory; client could not create request event (%lu)",
-  "Can't open shared memory; no answer event received from server (%lu)",
-  "Can't open shared memory; server could not allocate file mapping (%lu)",
-  "Can't open shared memory; server could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not allocate file mapping (%lu)",
-  "Can't open shared memory; client could not get pointer to file mapping (%lu)",
-  "Can't open shared memory; client could not create %s event (%lu)",
-  "Can't open shared memory; no answer from server (%lu)",
-  "Can't open shared memory; cannot send request event to server (%lu)",
-  "Wrong or unknown protocol",
-  "Invalid connection handle",
-  "Connection using old (pre-4.1.1) authentication protocol refused (client option 'secure_auth' enabled)",
-  "Row retrieval was canceled by drizzle_stmt_close() call",
-  "Attempt to read column without prior row fetch",
-  "Prepared statement contains no metadata",
-  "Attempt to read a row while there is no result set associated with the statement",
-  "This feature is not implemented yet",
-  "Lost connection to MySQL server at '%s', system error: %d",
-  "Statement closed indirectly because of a preceeding %s() call",
-  ""
-};
-#endif
-
-
-/*
-  Register client error messages for use with my_error().
-
-  SYNOPSIS
-    init_client_errs()
-
-  RETURN
-    void
-*/
-
-void init_client_errs(void)
-{
-  (void) my_error_register(client_errors, CR_ERROR_FIRST, CR_ERROR_LAST);
-}
-
-
-/*
-  Unregister client error messages.
-
-  SYNOPSIS
-    finish_client_errs()
-
-  RETURN
-    void
-*/
-
-void finish_client_errs(void)
-{
-  (void) my_error_unregister(CR_ERROR_FIRST, CR_ERROR_LAST);
+const char *client_errors[]=
+{
+  N_("Unknown Drizzle error"),
+  N_("Can't create UNIX socket (%d)"),
+  N_("Can't connect to local Drizzle server through socket '%-.100s' (%d)"),
+  N_("Can't connect to Drizzle server on '%-.100s' (%d)"),
+  N_("Can't create TCP/IP socket (%d)"),
+  N_("Unknown Drizzle server host '%-.100s' (%d)"),
+  N_("Drizzle server has gone away"),
+  N_("Protocol mismatch; server version = %d, client version = %d"),
+  N_("Drizzle client ran out of memory"),
+  N_("Wrong host info"),
+  N_("Localhost via UNIX socket"),
+  N_("%-.100s via TCP/IP"),
+  N_("Error in server handshake"),
+  N_("Lost connection to Drizzle server during query"),
+  N_("Commands out of sync; you can't run this command now"),
+  N_("Named pipe: %-.32s"),
+  N_("Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"),
+  N_("Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"),
+  N_("Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"),
+  N_("Can't initialize character set %-.32s (path: %-.100s)"),
+  N_("Got packet bigger than 'max_allowed_packet' bytes"),
+  N_("Embedded server"),
+  N_("Error on SHOW SLAVE STATUS:"),
+  N_("Error on SHOW SLAVE HOSTS:"),
+  N_("Error connecting to slave:"),
+  N_("Error connecting to master:"),
+  N_("SSL connection error"),
+  N_("Malformed packet"),
+  N_("(unused error message)"),
+  N_("Invalid use of null pointer"),
+  N_("Statement not prepared"),
+  N_("No data supplied for parameters in prepared statement"),
+  N_("Data truncated"),
+  N_("No parameters exist in the statement"),
+  N_("Invalid parameter number"),
+  N_("Can't send long data for non-string/non-binary data types "
+     "(parameter: %d)"),
+  N_("Using unsupported buffer type: %d  (parameter: %d)"),
+  N_("Shared memory: %-.100s"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("(unused error message)"),
+  N_("Wrong or unknown protocol"),
+  N_("Invalid connection handle"),
+  N_("Connection using old (pre-4.1.1) authentication protocol refused "
+     "(client option 'secure_auth' enabled)"),
+  N_("Row retrieval was canceled by drizzle_stmt_close() call"),
+  N_("Attempt to read column without prior row fetch"),
+  N_("Prepared statement contains no metadata"),
+  N_("Attempt to read a row while there is no result set associated with "
+     "the statement"),
+  N_("This feature is not implemented yet"),
+  N_("Lost connection to Drizzle server while waiting for initial "
+     "communication packet, system error: %d"),
+  N_("Lost connection to Drizzle server while reading initial communication "
+     "packet, system error: %d"),
+  N_("Lost connection to Drizzle server while sending authentication "
+     "information, system error: %d"),
+  N_("Lost connection to Drizzle server while reading authorization "
+     "information, system error: %d"),
+  N_("Lost connection to Drizzle server while setting initial database, "
+     "system error: %d"),
+  N_("Statement closed indirectly because of a preceeding %s() call"),
+  ""
+};
+
+
+const char *
+get_client_error(unsigned int err_index)
+{
+  return _(client_errors[err_index]);
 }

=== modified file 'libdrizzle/errmsg.h'
--- libdrizzle/errmsg.h	2008-07-31 18:16:01 +0000
+++ libdrizzle/errmsg.h	2008-08-16 21:06:40 +0000
@@ -24,88 +24,80 @@
 /* Error messages for MySQL clients */
 /* (Error messages for the daemon are in sql/share/errmsg.txt) */
 
-#ifdef	__cplusplus
+#ifdef  __cplusplus
 extern "C" {
 #endif
-void	init_client_errs(void);
-void	finish_client_errs(void);
-extern const char *client_errors[];	/* Error messages */
-#ifdef	__cplusplus
+const char * get_client_error(unsigned int err_index);
+#ifdef  __cplusplus
 }
 #endif
 
-#define CR_MIN_ERROR		2000	/* For easier client code */
-#define CR_MAX_ERROR		2999
+#define CR_MIN_ERROR    2000  /* For easier client code */
+#define CR_MAX_ERROR    2999
 #if !defined(ER)
-#define ER(X) client_errors[(X)-CR_MIN_ERROR]
+#define ER(X) get_client_error((X)-CR_MIN_ERROR)
 #endif
-#define CLIENT_ERRMAP		2	/* Errormap used by my_error() */
+#define CLIENT_ERRMAP    2  /* Errormap used by my_error() */
 
 /* Do not add error numbers before CR_ERROR_FIRST. */
 /* If necessary to add lower numbers, change CR_ERROR_FIRST accordingly. */
-#define CR_ERROR_FIRST  	2000 /*Copy first error nr.*/
-#define CR_UNKNOWN_ERROR	2000
-#define CR_SOCKET_CREATE_ERROR	2001
-#define CR_CONNECTION_ERROR	2002
-#define CR_CONN_HOST_ERROR	2003
-#define CR_IPSOCK_ERROR		2004
-#define CR_UNKNOWN_HOST		2005
-#define CR_SERVER_GONE_ERROR	2006
-#define CR_VERSION_ERROR	2007
-#define CR_OUT_OF_MEMORY	2008
-#define CR_WRONG_HOST_INFO	2009
-#define CR_LOCALHOST_CONNECTION 2010
-#define CR_TCP_CONNECTION	2011
-#define CR_SERVER_HANDSHAKE_ERR 2012
-#define CR_SERVER_LOST		2013
-#define CR_COMMANDS_OUT_OF_SYNC 2014
-#define CR_NAMEDPIPE_CONNECTION 2015
-#define CR_NAMEDPIPEWAIT_ERROR  2016
-#define CR_NAMEDPIPEOPEN_ERROR  2017
-#define CR_NAMEDPIPESETSTATE_ERROR 2018
-#define CR_CANT_READ_CHARSET	2019
-#define CR_NET_PACKET_TOO_LARGE 2020
-#define CR_EMBEDDED_CONNECTION	2021
-#define CR_PROBE_SLAVE_STATUS   2022
-#define CR_PROBE_SLAVE_HOSTS    2023
-#define CR_PROBE_SLAVE_CONNECT  2024
-#define CR_PROBE_MASTER_CONNECT 2025
-#define CR_SSL_CONNECTION_ERROR 2026
-#define CR_MALFORMED_PACKET     2027
-#define CR_WRONG_LICENSE	2028
-
-/* new 4.1 error codes */
-#define CR_NULL_POINTER		2029
-#define CR_NO_PREPARE_STMT	2030
-#define CR_PARAMS_NOT_BOUND	2031
-#define CR_DATA_TRUNCATED	2032
-#define CR_NO_PARAMETERS_EXISTS 2033
-#define CR_INVALID_PARAMETER_NO 2034
-#define CR_INVALID_BUFFER_USE	2035
-#define CR_UNSUPPORTED_PARAM_TYPE 2036
-
-#define CR_SHARED_MEMORY_CONNECTION             2037
-#define CR_SHARED_MEMORY_CONNECT_REQUEST_ERROR  2038
-#define CR_SHARED_MEMORY_CONNECT_ANSWER_ERROR   2039
-#define CR_SHARED_MEMORY_CONNECT_FILE_MAP_ERROR 2040
-#define CR_SHARED_MEMORY_CONNECT_MAP_ERROR      2041
-#define CR_SHARED_MEMORY_FILE_MAP_ERROR         2042
-#define CR_SHARED_MEMORY_MAP_ERROR              2043
-#define CR_SHARED_MEMORY_EVENT_ERROR     	2044
-#define CR_SHARED_MEMORY_CONNECT_ABANDONED_ERROR 2045
-#define CR_SHARED_MEMORY_CONNECT_SET_ERROR      2046
-#define CR_CONN_UNKNOW_PROTOCOL 		2047
-#define CR_INVALID_CONN_HANDLE			2048
-#define CR_SECURE_AUTH                          2049
-#define CR_FETCH_CANCELED                       2050
-#define CR_NO_DATA                              2051
-#define CR_NO_STMT_METADATA                     2052
-#define CR_NO_RESULT_SET                        2053
-#define CR_NOT_IMPLEMENTED                      2054
-#define CR_SERVER_LOST_EXTENDED			2055
-#define CR_STMT_CLOSED				2056
-#define CR_ERROR_LAST  /*Copy last error nr:*/  2056
-/* Add error numbers before CR_ERROR_LAST and change it accordingly. */
-
+enum CR_CLIENT_ERRORS {
+  CR_ERROR_FIRST    =2000, /*Copy first error nr.*/
+  CR_UNKNOWN_ERROR  =2000,
+  CR_SOCKET_CREATE_ERROR  =2001,
+  CR_CONNECTION_ERROR  =2002,
+  CR_CONN_HOST_ERROR  =2003,
+  CR_IPSOCK_ERROR    =2004,
+  CR_UNKNOWN_HOST    =2005,
+  CR_SERVER_GONE_ERROR  =2006,
+  CR_VERSION_ERROR  =2007,
+  CR_OUT_OF_MEMORY  =2008,
+  CR_WRONG_HOST_INFO  =2009,
+  CR_LOCALHOST_CONNECTION =2010,
+  CR_TCP_CONNECTION  =2011,
+  CR_SERVER_HANDSHAKE_ERR =2012,
+  CR_SERVER_LOST    =2013,
+  CR_COMMANDS_OUT_OF_SYNC =2014,
+  CR_NAMEDPIPE_CONNECTION =2015,
+  CR_NAMEDPIPEWAIT_ERROR  =2016,
+  CR_NAMEDPIPEOPEN_ERROR  =2017,
+  CR_NAMEDPIPESETSTATE_ERROR =2018,
+  CR_CANT_READ_CHARSET  =2019,
+  CR_NET_PACKET_TOO_LARGE =2020,
+  CR_EMBEDDED_CONNECTION  =2021,
+  CR_PROBE_SLAVE_STATUS   =2022,
+  CR_PROBE_SLAVE_HOSTS    =2023,
+  CR_PROBE_SLAVE_CONNECT  =2024,
+  CR_PROBE_MASTER_CONNECT =2025,
+  CR_SSL_CONNECTION_ERROR =2026,
+  CR_MALFORMED_PACKET     =2027,
+
+  CR_NULL_POINTER    =2029,
+  CR_NO_PREPARE_STMT  =2030,
+  CR_PARAMS_NOT_BOUND  =2031,
+  CR_DATA_TRUNCATED  =2032,
+  CR_NO_PARAMETERS_EXISTS =2033,
+  CR_INVALID_PARAMETER_NO =2034,
+  CR_INVALID_BUFFER_USE  =2035,
+  CR_UNSUPPORTED_PARAM_TYPE =2036,
+
+  CR_CONN_UNKNOW_PROTOCOL     =2047,
+  CR_INVALID_CONN_HANDLE      =2048,
+  CR_SECURE_AUTH                          =2049,
+  CR_FETCH_CANCELED                       =2050,
+  CR_NO_DATA                              =2051,
+  CR_NO_STMT_METADATA                     =2052,
+  CR_NO_RESULT_SET                        =2053,
+  CR_NOT_IMPLEMENTED                      =2054,
+  CR_SERVER_LOST_INITIAL_COMM_WAIT  =2055,
+  CR_SERVER_LOST_INITIAL_COMM_READ  =2056,
+  CR_SERVER_LOST_SEND_AUTH    =2057,
+  CR_SERVER_LOST_READ_AUTH    =2058,
+  CR_SERVER_LOST_SETTING_DB    =2059,
+
+  CR_STMT_CLOSED  =2060,
+  /* Add error numbers before CR_ERROR_LAST and change it accordingly. */
+  CR_ERROR_LAST    =2060 /*Copy last error nr:*/
+};
 
 #endif

=== modified file 'libdrizzle/get_password.c'
--- libdrizzle/get_password.c	2008-08-09 06:41:03 +0000
+++ libdrizzle/get_password.c	2008-08-15 19:55:19 +0000
@@ -22,7 +22,6 @@
 ** This is an own file to avoid conflicts with curses
 */
 #include <drizzled/global.h>
-#include <mysys/my_sys.h>
 #include "drizzle.h"
 #include <mystrings/m_string.h>
 #include <mystrings/m_ctype.h>
@@ -203,6 +202,6 @@
     fputc('\n',stdout);
 # endif /* HAVE_GETPASS */
 
-  return(my_strdup(buff,MYF(MY_FAE)));
+  return strdup(buff);
 }
 #endif /*__WIN__*/

=== modified file 'libdrizzle/libdrizzle.c'
--- libdrizzle/libdrizzle.c	2008-08-12 21:13:01 +0000
+++ libdrizzle/libdrizzle.c	2008-08-15 20:20:33 +0000
@@ -20,7 +20,6 @@
 #include <drizzled/global.h>
 #include <mysys/my_sys.h>
 #include "my_time.h"
-#include <mysys/mysys_err.h>
 #include "drizzle.h"
 #include "errmsg.h"
 #include <vio/violite.h>
@@ -48,7 +47,6 @@
 #ifdef HAVE_SYS_UN_H
 #include <sys/un.h>
 #endif
-#include <mysys/my_pthread.h>        /* because of signal()  */
 #ifndef INADDR_NONE
 #define INADDR_NONE  -1
 #endif

=== modified file 'libdrizzle/local_infile.c'
--- libdrizzle/local_infile.c	2008-08-04 03:48:26 +0000
+++ libdrizzle/local_infile.c	2008-08-15 20:20:33 +0000
@@ -19,11 +19,7 @@
 
 
 #include <drizzled/global.h>
-#include <mysys/my_sys.h>
 #include "my_time.h"
-#include <mysys/mysys_err.h>
-#include <mystrings/m_string.h>
-#include <mystrings/m_ctype.h>
 #include "drizzle.h"
 #include "errmsg.h"
 #include <vio/violite.h>
@@ -183,12 +179,11 @@
   data->error_num=    0;
   data->filename= filename;
 
-  fn_format(tmp_name, filename, "", "", MY_UNPACK_FILENAME);
-  if ((data->fd = my_open(tmp_name, O_RDONLY, MYF(0))) < 0)
+  if ((data->fd = open(tmp_name, O_RDONLY)) < 0)
   {
-    data->error_num= my_errno;
+    data->error_num= errno;
     snprintf(data->error_msg, sizeof(data->error_msg)-1,
-             EE(EE_FILENOTFOUND), tmp_name, data->error_num);
+             _("File '%s' not found (Errcode: %d)"), tmp_name, data->error_num);
     return 1;
   }
   return 0; /* ok */
@@ -215,12 +210,12 @@
   int count;
   default_local_infile_data*data = (default_local_infile_data *) ptr;
 
-  if ((count= (int) my_read(data->fd, (uchar *) buf, buf_len, MYF(0))) < 0)
+  if ((count= (int) read(data->fd, (uchar *) buf, buf_len)) < 0)
   {
-    data->error_num= EE_READ; /* the errmsg for not entire file read */
+    data->error_num= 2; /* the errmsg for not entire file read */
     snprintf(data->error_msg, sizeof(data->error_msg)-1,
-             EE(EE_READ),
-             data->filename, my_errno);
+             _("Error reading file '%s' (Errcode: %d)"),
+             data->filename, errno);
   }
   return count;
 }
@@ -243,7 +238,7 @@
   if (data)          /* If not error on open */
   {
     if (data->fd >= 0)
-      my_close(data->fd, MYF(MY_WME));
+      close(data->fd);
     free(ptr);
   }
 }

=== modified file 'libdrizzle/my_time.c'
--- libdrizzle/my_time.c	2008-08-10 16:57:26 +0000
+++ libdrizzle/my_time.c	2008-08-15 19:55:19 +0000
@@ -17,7 +17,6 @@
 #include <mystrings/m_string.h>
 #include <mystrings/m_ctype.h>
 /* Windows version of localtime_r() is declared in my_ptrhead.h */
-#include <mysys/my_pthread.h>
 
 uint64_t log_10_int[20]=
 {

=== modified file 'libdrizzle/net_serv.c'
--- libdrizzle/net_serv.c	2008-08-10 17:18:41 +0000
+++ libdrizzle/net_serv.c	2008-08-15 20:20:33 +0000
@@ -21,7 +21,6 @@
 #include <drizzle.h>
 #include <drizzled/error.h>
 #include <mysys/my_sys.h>
-#include <mystrings/m_string.h>
 #include <vio/violite.h>
 #include <signal.h>
 #include <errno.h>
@@ -37,11 +36,6 @@
 */
 
 
-#define DONT_USE_THR_ALARM
-
-#include <mysys/thr_alarm.h>
-
-
 #define update_statistics(A)
 #define thd_increment_bytes_sent(N)
 

=== modified file 'libdrizzle/password.c'
--- libdrizzle/password.c	2008-08-10 16:57:26 +0000
+++ libdrizzle/password.c	2008-08-15 20:20:33 +0000
@@ -59,9 +59,6 @@
 *****************************************************************************/
 
 #include <drizzled/global.h>
-#include <mysys/my_sys.h>
-#include <mystrings/m_string.h>
-#include <mysys/sha1.h>
 #include "drizzle.h"
 
 /************ MySQL 3.23-4.0 authentication routines: untouched ***********/

=== modified file 'libdrizzle/sql_common.h'
--- libdrizzle/sql_common.h	2008-08-09 04:36:27 +0000
+++ libdrizzle/sql_common.h	2008-08-15 20:20:33 +0000
@@ -28,6 +28,7 @@
 #ifdef	__cplusplus
 extern "C" {
 #endif
+#include <mystrings/m_ctype.h>
 
 extern CHARSET_INFO *default_client_charset_info;
 DRIZZLE_FIELD *unpack_fields(DRIZZLE_DATA *data, MEM_ROOT *alloc, uint fields,

=== modified file 'po/POTFILES.in'
--- po/POTFILES.in	2008-08-13 18:02:06 +0000
+++ po/POTFILES.in	2008-08-17 01:31:40 +0000
@@ -1,18 +1,35 @@
 # List of source files which contain translatable strings.
 client/drizzle.cc
 client/drizzleadmin.cc
+libdrizzle/client.c
+libdrizzle/errmsg.c
+libdrizzle/local_infile.c
 mysys/errors.c
 mysys/my_error.c
 mysys/my_getopt.c
 mysys/my_handler_errors.h
+drizzled/authentication.cc
 drizzled/drizzled.cc
 drizzled/drizzled_error_messages.h
 drizzled/error.h
+drizzled/handler.cc
+drizzled/log.cc
+drizzled/log_event.cc
 drizzled/rpl_mi.cc
 drizzled/rpl_reporting.cc
+drizzled/rpl_rli.cc
 drizzled/rpl_utility.cc
+drizzled/scheduler.cc
+drizzled/set_var.cc
 drizzled/slave.cc
+drizzled/sql_base.cc
+drizzled/sql_db.cc
+drizzled/sql_plugin.cc
 drizzled/sql_repl.cc
+drizzled/sql_select.cc
+drizzled/sql_show.cc
+drizzled/sql_table.cc
+drizzled/sql_udf.cc
 drizzled/table.cc
 drizzled/thr_malloc.cc
 drizzled/tztime.cc

=== modified file 'po/ca.po'
--- po/ca.po	2008-08-14 17:35:53 +0000
+++ po/ca.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 14:12+0000\n"
 "Last-Translator: el_libre <el.libre@gmail.com>\n"
 "Language-Team: Catalan <ca@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -151,7 +151,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -184,7 +184,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -214,7 +214,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -404,7 +404,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -612,7 +612,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -720,16 +720,280 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Error desconegut"
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Error desconegut"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -859,11 +1123,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1187,12 +1446,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1205,52 +1470,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1261,7 +1526,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1271,7 +1536,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1279,14 +1544,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1298,7 +1563,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1309,7 +1574,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1321,90 +1586,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1412,91 +1677,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1507,151 +1772,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1661,141 +1926,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1805,7 +2070,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1813,7 +2078,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1822,7 +2087,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1830,20 +2095,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1853,7 +2118,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1863,7 +2128,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1873,7 +2138,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1881,63 +2146,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1945,139 +2210,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2085,161 +2350,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2247,7 +2512,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2255,7 +2520,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2266,161 +2531,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2429,76 +2694,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5810,6 +6075,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5845,18 +6260,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6277,6 +6729,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6293,6 +6858,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/cy.po'
--- po/cy.po	2008-08-14 17:35:53 +0000
+++ po/cy.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 02:56+0000\n"
 "Last-Translator: nhutchings <natalie@nuttycrafts.co.uk>\n"
 "Language-Team: Welsh <cy@li.org>\n"
@@ -16,7 +16,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=4; plural=n==1 ? 0 : n==2 ? 1 : (n != 8 || n != 11) ? "
 "2 : 3;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -161,7 +161,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 #, fuzzy
 msgid "Display this help and exit."
 msgstr "Dangos cymorth yma a gadael"
@@ -195,7 +195,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -226,7 +226,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -423,7 +423,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -627,7 +627,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -735,16 +735,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -874,11 +1136,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1202,12 +1459,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1220,52 +1483,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1276,7 +1539,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1286,7 +1549,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1294,14 +1557,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1313,7 +1576,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1324,7 +1587,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1336,90 +1599,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1427,91 +1690,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1522,151 +1785,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1676,141 +1939,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1820,7 +2083,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1828,7 +2091,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1837,7 +2100,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1845,20 +2108,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1868,7 +2131,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1878,7 +2141,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1888,7 +2151,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1896,63 +2159,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1960,139 +2223,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2100,161 +2363,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2262,7 +2525,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2270,7 +2533,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2281,161 +2544,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2444,76 +2707,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5827,6 +6090,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5862,18 +6275,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6294,6 +6744,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6310,6 +6873,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/de.po'
--- po/de.po	2008-08-14 17:35:53 +0000
+++ po/de.po	2008-08-16 23:49:05 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
-"PO-Revision-Date: 2008-08-13 21:24+0000\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
+"PO-Revision-Date: 2008-08-14 18:02+0000\n"
 "Last-Translator: Hartmut Holzgraefe <hartmut@php.net>\n"
 "Language-Team: German <de@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -161,7 +161,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Abfrage durch Strg-C abgebrochen\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Diese Hilfe anzeigen und beenden."
 
@@ -199,7 +199,7 @@
 "Benutze keine history Datei. Deaktiviere interaktives Verhalten. (Aktiviert "
 "--silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 #, fuzzy
 msgid "Directory where character sets are."
 msgstr "Verzeichnis in dem die Zeichensätze enthalten sind"
@@ -235,7 +235,7 @@
 msgid "Database to use."
 msgstr "Zu benutzende Datenbank"
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Setzt den Standardezeichensatz."
 
@@ -429,7 +429,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Versionsinformation ausgeben und beenden."
 
@@ -661,7 +661,7 @@
 msgstr[0] "Abfrage in Ordnung, %ld Zeile betroffen"
 msgstr[1] "Abfrage in Ordnung, %ld Zeilen betroffen"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -773,16 +773,292 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Unbekannter Fehler %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "Verzeichnis '%s' kann nicht angelegt werden (Fehlercode: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Kann keine Verbindung zum Server aufbauen\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "Unbekanntes Kommando: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Unbekannter Fehler %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Ungültige Fehlernummer"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+#, fuzzy
+msgid "Prepared statement contains no metadata"
+msgstr "Prepared Statement enthält zu viele Platzhalter"
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"Verbindung zum Server unter '%s' fehlgeschlagen,\n"
+"Fehler: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"Verbindung zum Server unter '%s' fehlgeschlagen,\n"
+"Fehler: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"Verbindung zum Server unter '%s' fehlgeschlagen,\n"
+"Fehler: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"Verbindung zum Server unter '%s' fehlgeschlagen,\n"
+"Fehler: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"Verbindung zum Server unter '%s' fehlgeschlagen,\n"
+"Fehler: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "Datei '%s' nicht gefunden (Fehlercode: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Fehler beim Lesen der Datei '%s' (Fehlercode: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "Datei '%s' kann nicht erstellt/geschrieben werden (Fehlercode: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "Fehler beim Lesen der Datei '%s' (Fehlercode: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -899,6 +1175,7 @@
 #, c-format
 msgid "Can't create symlink '%s' pointing at '%s' (Error %d)"
 msgstr ""
+"Kann '%s' nicht als symbolische Verknüpfung auf '%s' anlegen (Fehlercode: %d)"
 
 #: mysys/errors.c:49
 #, c-format
@@ -919,11 +1196,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "Datei '%s' nicht gefunden (Fehlercode: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -945,7 +1217,7 @@
 #: mysys/my_getopt.c:350
 #, c-format
 msgid "%s: %s: Option '%s' used, but is disabled\n"
-msgstr ""
+msgstr "%s: %s: Option '%s' wurde benzutzt obwohl sie deaktiviert ist\n"
 
 #: mysys/my_getopt.c:351
 msgid "WARNING"
@@ -958,7 +1230,7 @@
 #: mysys/my_getopt.c:454
 #, c-format
 msgid "%s: ERROR: Option '-%c' used, but is disabled\n"
-msgstr ""
+msgstr "%s: Option '-%c' wurde benzutzt obwohl sie deaktiviert ist\n"
 
 #: mysys/my_getopt.c:767
 #, c-format
@@ -1193,7 +1465,7 @@
 
 #: mysys/my_handler_errors.h:102
 msgid "Failed to get next auto increment value"
-msgstr ""
+msgstr "Der nächste Autoincrement-Wert konnte nicht ermittelt werden"
 
 #: mysys/my_handler_errors.h:104
 msgid "Failed to set row auto increment value"
@@ -1251,12 +1523,18 @@
 msgid "Tablespace not empty"
 msgstr "Tablespace ist nicht leer"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1269,52 +1547,54 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
-msgstr ""
+msgstr "Nur root kann die --user Option benutzen\n"
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
+"Fataler Fehler: Bitte lesen Sie den Handbuchabschnitt zum Thema Sicherheit "
+"um herauszufinden wie mysqld als root ausgeführt werden kann\n"
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1325,7 +1605,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1335,7 +1615,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1343,14 +1623,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1362,7 +1642,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1373,7 +1653,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1385,90 +1665,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Schreibe history Datei %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
-msgstr ""
+msgstr "gethostname fehlgeschlagen, benutze '%s' als Hostnamen"
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
-msgstr ""
+msgstr "Unbekannte Lokale: '%s'"
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
-msgstr ""
+msgstr "Kein Speicher mehr verfügbar"
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1476,91 +1756,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1571,151 +1851,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
-msgstr ""
+msgstr "Core-Datei schreiben beim Auftreten von Fehlern."
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
-msgstr ""
+msgstr "Nur für Debuggingzwecke, Nutzung auf eigene Gefahr!"
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
-msgstr ""
+msgstr "Generelles Query Log aktivieren"
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
-msgstr ""
+msgstr "(IGNORIERT)"
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1725,141 +2005,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
-msgstr ""
+msgstr "INSERT/DELETE/UPDATE bekommen geringere Priorität als Selects."
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1869,7 +2149,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1877,7 +2157,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1886,7 +2166,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1894,20 +2174,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1917,7 +2197,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1927,7 +2207,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1937,7 +2217,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1945,63 +2225,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
-msgstr ""
+msgstr "Überspringt einige Optimierungsschritte (für Testzwecke)."
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
-msgstr ""
+msgstr "Bei Fehlern keinen Stacktrace ausgeben,"
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2009,139 +2289,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
-msgstr ""
+msgstr "Aktiviert/deaktiviert das Protokoll langsamer Abfragen"
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
-msgstr ""
+msgstr "(IGNORIERT)"
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
-msgstr ""
+msgstr "Aktiviert Unterstützung für symbolische Verknüpfungen."
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
-msgstr ""
+msgstr "Veraltet, nutzen Sie statt dessen --log-warnings."
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
-msgstr ""
+msgstr "Maximale Länger für das Ergebnis der group_concat Funktion."
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2149,163 +2429,164 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
+"Maximale Anzahl der für ein Statement zu speichernden Fehler und Warnungen"
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "Ungültige Create-Optionen"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Puffer für TCP/IP- und Socket-Kommunikation"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2313,7 +2594,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2321,7 +2602,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2332,165 +2613,164 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr ""
 "Nutze das komprimierte Übertragungsprotokoll zwischen Server und Anwendung."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
-msgstr ""
-"WARNUNG: Veraltete Option, nutzen Sie bitte statt dessen --disable-pager\n"
+msgstr "Veraltet, nutzen Sie statt dessen --log-warnings."
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2499,86 +2779,86 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
 #: drizzled/drizzled_error_messages.h:32
 msgid "hashchk"
-msgstr ""
+msgstr "hashchk"
 
 #: drizzled/drizzled_error_messages.h:34
 msgid "isamchk"
-msgstr ""
+msgstr "isamchk"
 
 #: drizzled/drizzled_error_messages.h:36
 msgid "NO"
@@ -2606,12 +2886,12 @@
 #: drizzled/drizzled_error_messages.h:46
 #, c-format
 msgid "Can't create database '%-.192s'; database exists"
-msgstr ""
+msgstr "Kann Datenbank '%-.192s' nicht anlegen da sie bereits existiert"
 
 #: drizzled/drizzled_error_messages.h:48
 #, c-format
 msgid "Can't drop database '%-.192s'; database doesn't exist"
-msgstr ""
+msgstr "Kann Datenbank '%-.192s' nicht entfernen da sie nicht existiert"
 
 #: drizzled/drizzled_error_messages.h:50
 #, fuzzy, c-format
@@ -2622,6 +2902,8 @@
 #, c-format
 msgid "Error dropping database (can't rmdir '%-.192s', errno: %d)"
 msgstr ""
+"Fehler bein Entfernen der Datenbank (rmdir '%-.192s' mit Fehlercode %d "
+"abgebrochen)"
 
 #: drizzled/drizzled_error_messages.h:54
 #, fuzzy, c-format
@@ -2836,11 +3118,11 @@
 #: drizzled/drizzled_error_messages.h:136
 #, c-format
 msgid "Column '%-.192s' in %-.192s is ambiguous"
-msgstr ""
+msgstr "Spalte '%-.192s' in %-.192s ist mehrdeutig"
 
 #: drizzled/drizzled_error_messages.h:138
 msgid "Server shutdown in progress"
-msgstr ""
+msgstr "Server wird heruntergefahren"
 
 #: drizzled/drizzled_error_messages.h:140
 #, fuzzy, c-format
@@ -2868,22 +3150,22 @@
 #: drizzled/drizzled_error_messages.h:150
 #, c-format
 msgid "Identifier name '%-.100s' is too long"
-msgstr ""
+msgstr "Der Bezeichnername '%-.100s' ist zu lang"
 
 #: drizzled/drizzled_error_messages.h:152
 #, c-format
 msgid "Duplicate column name '%-.192s'"
-msgstr ""
+msgstr "Doppelter Spaltenname '%-.192s'"
 
 #: drizzled/drizzled_error_messages.h:154
 #, c-format
 msgid "Duplicate key name '%-.192s'"
-msgstr ""
+msgstr "Doppelter Schlüsselname '%-.192s'"
 
 #: drizzled/drizzled_error_messages.h:156
 #, c-format
 msgid "Duplicate entry '%-.192s' for key %d"
-msgstr ""
+msgstr "Doppelter Eintrag '%-.192s' für Schlüssel %d"
 
 #: drizzled/drizzled_error_messages.h:158
 #, c-format
@@ -2893,11 +3175,11 @@
 #: drizzled/drizzled_error_messages.h:160
 #, c-format
 msgid "%s near '%-.80s' at line %d"
-msgstr ""
+msgstr "%s nahe '%-.80s' auf Zeile %d"
 
 #: drizzled/drizzled_error_messages.h:162
 msgid "Query was empty"
-msgstr ""
+msgstr "Abfrage war leer"
 
 #: drizzled/drizzled_error_messages.h:164
 #, c-format
@@ -2959,6 +3241,8 @@
 "%s: ready for connections.\n"
 "Version: '%s'  socket: '%s'  port: %d"
 msgstr ""
+"%s: bereit für Verbindungen.\n"
+"Version: '%s' Socket: '%s' Port: %d"
 
 #: drizzled/drizzled_error_messages.h:186
 #, c-format
@@ -3009,7 +3293,7 @@
 #: drizzled/drizzled_error_messages.h:204
 #, c-format
 msgid "File '%-.200s' already exists"
-msgstr ""
+msgstr "Datei '%-.200s' existiert bereits"
 
 #: drizzled/drizzled_error_messages.h:206
 #, c-format
@@ -3082,7 +3366,7 @@
 #: drizzled/drizzled_error_messages.h:232
 #, c-format
 msgid "Table '%-.192s' was not locked with LOCK TABLES"
-msgstr ""
+msgstr "Tabelle '%-.192s' wurde nicht mit LOCK TABLES gesperrt"
 
 #: drizzled/drizzled_error_messages.h:234
 #, c-format
@@ -3092,12 +3376,12 @@
 #: drizzled/drizzled_error_messages.h:236
 #, c-format
 msgid "Incorrect database name '%-.100s'"
-msgstr ""
+msgstr "Ungültiger Datenbankname '%-.100s'"
 
 #: drizzled/drizzled_error_messages.h:238
 #, c-format
 msgid "Incorrect table name '%-.100s'"
-msgstr ""
+msgstr "Ungültiger Tabellenname '%-.100s'"
 
 #: drizzled/drizzled_error_messages.h:240
 msgid ""
@@ -3974,12 +4258,12 @@
 #: drizzled/drizzled_error_messages.h:592
 #, c-format
 msgid "Incorrect index name '%-.100s'"
-msgstr ""
+msgstr "Ungültiger Indexname '%-.100s'"
 
 #: drizzled/drizzled_error_messages.h:594
 #, c-format
 msgid "Incorrect catalog name '%-.100s'"
-msgstr ""
+msgstr "Ungültiger Katalogname '%-.100s'"
 
 #: drizzled/drizzled_error_messages.h:596
 #, c-format
@@ -3989,7 +4273,7 @@
 #: drizzled/drizzled_error_messages.h:598
 #, c-format
 msgid "Column '%-.192s' cannot be part of FULLTEXT index"
-msgstr ""
+msgstr "Die Spalte '%-.192s' kann nicht Teil eines FULLTEXT Index sein"
 
 #: drizzled/drizzled_error_messages.h:600
 #, fuzzy, c-format
@@ -4030,6 +4314,8 @@
 "The MySQL server is running with the %s option so it cannot execute this "
 "statement"
 msgstr ""
+"Der MySQL Server kann dieses Kommando nicht ausführen da er mit der Option %"
+"s gestartet wurde"
 
 #: drizzled/drizzled_error_messages.h:614
 #, c-format
@@ -4064,7 +4350,7 @@
 #: drizzled/drizzled_error_messages.h:626
 #, c-format
 msgid "Got temporary error %d '%-.100s' from %s"
-msgstr ""
+msgstr "Vorübergehender Fehler %d '%-.100s' von %s erhalten"
 
 #: drizzled/drizzled_error_messages.h:628
 #, fuzzy, c-format
@@ -4074,12 +4360,12 @@
 #: drizzled/drizzled_error_messages.h:630
 #, c-format
 msgid "Invalid TIMESTAMP value in column '%s' at row %ld"
-msgstr ""
+msgstr "Ungültiger TIMESTAMP Wert in Spalte '%s' auf Zeile %ld"
 
 #: drizzled/drizzled_error_messages.h:632
 #, c-format
 msgid "Invalid %s character string: '%.64s'"
-msgstr ""
+msgstr "Ungültige %s Zeichenkette: '%.64s'"
 
 #: drizzled/drizzled_error_messages.h:634
 #, c-format
@@ -4089,7 +4375,7 @@
 #: drizzled/drizzled_error_messages.h:636
 #, c-format
 msgid "Conflicting declarations: '%s%s' and '%s%s'"
-msgstr ""
+msgstr "Wiedersrpüchliche Deklarationen: '%s%s' und '%s%s'"
 
 #: drizzled/drizzled_error_messages.h:638
 #, c-format
@@ -4099,12 +4385,12 @@
 #: drizzled/drizzled_error_messages.h:640
 #, c-format
 msgid "%s %s already exists"
-msgstr ""
+msgstr "%s %s existiert bereits"
 
 #: drizzled/drizzled_error_messages.h:642
 #, c-format
 msgid "%s %s does not exist"
-msgstr ""
+msgstr "%s %s existiert nicht"
 
 #: drizzled/drizzled_error_messages.h:644
 #, c-format
@@ -4164,7 +4450,7 @@
 
 #: drizzled/drizzled_error_messages.h:666
 msgid "Query execution was interrupted"
-msgstr ""
+msgstr "Ausführung der Abfrage wurde unterbrochen"
 
 #: drizzled/drizzled_error_messages.h:668
 #, c-format
@@ -4270,7 +4556,7 @@
 #: drizzled/drizzled_error_messages.h:712
 #, c-format
 msgid "Configuration file '%-.192s' is too big"
-msgstr ""
+msgstr "Konfigurationsdatei '%-.192s' ist zu groß"
 
 #: drizzled/drizzled_error_messages.h:714
 #, c-format
@@ -4470,7 +4756,7 @@
 #, c-format
 msgid ""
 "The '%-.64s' syntax is reserved for purposes internal to the MySQL server"
-msgstr ""
+msgstr "Die '%-.64s' Syntax ist für serverinternen Einsatz reserviert"
 
 #: drizzled/drizzled_error_messages.h:798
 msgid "WSAStartup Failed"
@@ -5913,6 +6199,161 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "Stelle Verbindung her"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+#, fuzzy
+msgid "Starting crash recovery..."
+msgstr "Starte Restore-Prozess"
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+#, fuzzy
+msgid "I/O error reading the header from the binary log"
+msgstr "In der Indexdatei ist kein Platz mehr verfügbar"
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+"Datei '%s' kann nicht mit der Festplatte synchronisiert werden (Fehlercode: %"
+"d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, fuzzy, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, fuzzy, c-format
+msgid "Failed to delete file '%s'"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, fuzzy, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr "Erzeugen der Slave Threads fehlgeschlagen"
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "Datei kann nicht gesperrt werden (Fehlercode: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5948,18 +6389,56 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr "Slave %s: %s%s Fehlercode: %d"
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+"Kann '%s' nicht als symbolische Verknüpfung auf '%s' anlegen (Fehlercode: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6384,6 +6863,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, fuzzy, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr "Kann Datei %-.64s nicht öffnen"
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "Datei '%s' kann nicht erstellt/geschrieben werden (Fehlercode: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "Unbekanntes Kommando: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Kein Speicher mehr verfügbar"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr "Fehler in send_file() beim Lesen des Dateinamens"
@@ -6400,6 +6992,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, fuzzy, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr "Ungültiger Datenbankname '%-.100s'"
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "Unbekannter Fehler %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/drizzle.pot'
--- po/drizzle.pot	2008-08-14 17:35:53 +0000
+++ po/drizzle.pot	2008-08-16 23:49:05 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: drizzle 7.0.0\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -150,7 +150,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -183,7 +183,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -213,7 +213,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -403,7 +403,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -607,7 +607,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -715,16 +715,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -854,11 +1116,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1182,12 +1439,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1200,52 +1463,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1256,7 +1519,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1266,7 +1529,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1274,14 +1537,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1293,7 +1556,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1304,7 +1567,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1316,90 +1579,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1407,91 +1670,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1502,151 +1765,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1656,141 +1919,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1800,7 +2063,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1808,7 +2071,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1817,7 +2080,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1825,20 +2088,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1848,7 +2111,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1858,7 +2121,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1868,7 +2131,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1876,63 +2139,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1940,139 +2203,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2080,161 +2343,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2242,7 +2505,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2250,7 +2513,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2261,161 +2524,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2424,76 +2687,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5805,6 +6068,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5840,18 +6253,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6272,6 +6722,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6288,6 +6851,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/en_AU.po'
--- po/en_AU.po	2008-08-14 17:35:53 +0000
+++ po/en_AU.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-12 07:05+0000\n"
 "Last-Translator: Morgan Tocker <tocker@gmail.com>\n"
 "Language-Team: English (Australia) <en_AU@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -151,7 +151,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -184,7 +184,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -214,7 +214,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -404,7 +404,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -608,7 +608,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -716,16 +716,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -855,11 +1117,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1183,12 +1440,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1201,52 +1464,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1257,7 +1520,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1267,7 +1530,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1275,14 +1538,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1294,7 +1557,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1305,7 +1568,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1317,90 +1580,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1408,91 +1671,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1503,151 +1766,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1657,141 +1920,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1801,7 +2064,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1809,7 +2072,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1818,7 +2081,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1826,20 +2089,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1849,7 +2112,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1859,7 +2122,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1869,7 +2132,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1877,63 +2140,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1941,139 +2204,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2081,161 +2344,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2243,7 +2506,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2251,7 +2514,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2262,161 +2525,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2425,76 +2688,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5806,6 +6069,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5841,18 +6254,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6273,6 +6723,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6289,6 +6852,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/en_GB.po'
--- po/en_GB.po	2008-08-14 17:35:53 +0000
+++ po/en_GB.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 03:09+0000\n"
 "Last-Translator: LinuxJedi <andrew@linuxjedi.co.uk>\n"
 "Language-Team: English (United Kingdom) <en_GB@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -151,7 +151,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -184,7 +184,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -214,7 +214,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -404,7 +404,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -608,7 +608,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -716,16 +716,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -855,11 +1117,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1183,12 +1440,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1201,52 +1464,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1257,7 +1520,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1267,7 +1530,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1275,14 +1538,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1294,7 +1557,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1305,7 +1568,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1317,90 +1580,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1408,91 +1671,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1503,151 +1766,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1657,141 +1920,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1801,7 +2064,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1809,7 +2072,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1818,7 +2081,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1826,20 +2089,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1849,7 +2112,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1859,7 +2122,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1869,7 +2132,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1877,63 +2140,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1941,139 +2204,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2081,161 +2344,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2243,7 +2506,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2251,7 +2514,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2262,161 +2525,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2425,76 +2688,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5807,6 +6070,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5842,18 +6255,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6274,6 +6724,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6290,6 +6853,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/es.po'
--- po/es.po	2008-08-14 17:35:53 +0000
+++ po/es.po	2008-08-16 23:49:05 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
-"PO-Revision-Date: 2008-08-13 15:59+0000\n"
-"Last-Translator: Javier Infante <jabi@irontec.com>\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
+"PO-Revision-Date: 2008-08-15 04:23+0000\n"
+"Last-Translator: tamgo <enmanuelr@gmail.com>\n"
 "Language-Team: Spanish <es@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -28,18 +28,18 @@
 
 #: client/drizzle.cc:259
 msgid "Reconnect to the server. Optional arguments are db and host."
-msgstr "Reconectar al servidor. Los argumentos óptimos son db y host."
+msgstr "Reconectar al servidor. Argumentos opcionales son db y host."
 
 #: client/drizzle.cc:261
 msgid ""
 "Set statement delimiter. NOTE: Takes the rest of the line as new delimiter."
 msgstr ""
-"Ajustar delimitador de declaración. NOTA: Coge el resto de la línea como un "
-"nuevo delimitador."
+"Adjustar delimitador de declaracion. NOTA: Establece el resto de la línea "
+"como un nuevo delimitador."
 
 #: client/drizzle.cc:263
 msgid "Send command to drizzle server, display result vertically."
-msgstr "Enviar comando al servidor drizzle,"
+msgstr "Enviar comando al servidor drizzle, despliega resultado verticalmente."
 
 #: client/drizzle.cc:264
 msgid "Exit drizzle. Same as quit."
@@ -166,7 +166,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Consulta abortada por Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Mostrar esta ayuda y salir."
 
@@ -210,7 +210,7 @@
 "No usar fichero histórico. Deshabilitar comportamiento interactivo. "
 "(Habilita --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "Directorio donde se encuentran los character sets."
 
@@ -242,7 +242,7 @@
 msgid "Database to use."
 msgstr "Base de datos a utilizar."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Ajustar el character set por defecto."
 
@@ -475,7 +475,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "Escribir más. (-v -v -v muestra el formato de salida de la tabla)."
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Mostrar información de la versión y salir."
 
@@ -585,7 +585,7 @@
 #: client/drizzle.cc:2550
 #, c-format
 msgid "Name: '%s'\n"
-msgstr ""
+msgstr "Nombre: '%s'\n"
 
 #: client/drizzle.cc:2551
 #, c-format
@@ -593,6 +593,8 @@
 "Description:\n"
 "%s"
 msgstr ""
+"Descripción:\n"
+"%s"
 
 #: client/drizzle.cc:2553
 #, c-format
@@ -600,110 +602,124 @@
 "Examples:\n"
 "%s"
 msgstr ""
+"Ejemplos:\n"
+"%s"
 
 #: client/drizzle.cc:2566
 msgid "Many help items for your request exist."
-msgstr ""
+msgstr "Existen muchos elementos de ayuda para tu petición."
 
 #: client/drizzle.cc:2567
 msgid ""
 "To make a more specific request, please type 'help <item>',\n"
 "where <item> is one of the following"
 msgstr ""
+"Para realizar una petición más específica, por favor escriba 'help "
+"<elemento>',\n"
+"donde <elemento> es un de estos"
 
 #: client/drizzle.cc:2573
 #, c-format
 msgid "You asked for help about help category: '%s'\n"
-msgstr ""
+msgstr "Has pedido ayuda acerca de la categoría: '%s'\n"
 
 #: client/drizzle.cc:2574
 msgid ""
 "For more information, type 'help <item>', where <item> is one of the "
 "following"
 msgstr ""
+"Para más información, excriba 'help <elemento>', donde <elemento> es uno de "
+"estos"
 
 #: client/drizzle.cc:2587
 msgid ""
 "\n"
 "Nothing found"
 msgstr ""
+"\n"
+"No se ha encontrado nada"
 
 #: client/drizzle.cc:2588
 msgid "Please try to run 'help contents' for a list of all accessible topics\n"
 msgstr ""
+"Por favor, intentar ejecutar 'help contents' para un listado con los temas "
+"disponibles\n"
 
 #: client/drizzle.cc:2610
 msgid "List of all Drizzle commands:"
-msgstr ""
+msgstr "Listado de todos los comandos en Drizzle:"
 
 #: client/drizzle.cc:2612
 msgid "Note that all text commands must be first on line and end with ';'"
 msgstr ""
+"Notar que todos los comandos de texto deben ser lo primero en la línea y "
+"terminar con ';'"
 
 #: client/drizzle.cc:2623
 msgid ""
 "\n"
 "For server side help, type 'help contents'\n"
 msgstr ""
+"\n"
+"Para conseguir ayuda desde el servidor, escriba 'help contents'\n"
 
 #: client/drizzle.cc:2648
 msgid "Usage: \\C char_setname | charset charset_name"
-msgstr ""
+msgstr "Uso: \\C char_setname | charset charset_name"
 
 #: client/drizzle.cc:2658
 msgid "Charset changed"
-msgstr ""
+msgstr "Charset cambiado"
 
 #: client/drizzle.cc:2660
 msgid "Charset is not found"
-msgstr ""
+msgstr "Charset no encontrado"
 
 #: client/drizzle.cc:2691
 msgid "No query specified\n"
-msgstr ""
+msgstr "No se ha especificado consulta\n"
 
 #: client/drizzle.cc:2706
 msgid "Ignoring query to other database"
-msgstr ""
+msgstr "Ignorando consulta a otra base de datos"
 
 #: client/drizzle.cc:2755
 msgid "Empty set"
-msgstr ""
+msgstr "Conjunto vacío"
 
 #: client/drizzle.cc:2768
 #, c-format
 msgid "%ld row in set"
 msgid_plural "%ld rows in set"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "fila %ld en el conjunto"
+msgstr[1] "filas %ld en el conjunto"
 
 #: client/drizzle.cc:2777
 msgid "Query OK"
-msgstr ""
+msgstr "Consulta OK"
 
 #: client/drizzle.cc:2779
 #, c-format
 msgid "Query OK, %ld row affected"
 msgid_plural "Query OK, %ld rows affected"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "Consulta OK, %ld fila afectada"
+msgstr[1] "Consulta OK, %ld filas afectadas"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
-#, fuzzy
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
 msgstr ""
 "Puerto para la conexión o 0 por defecto, en orden de preferencia, my.cnf, "
-"$DRIZZLE_TCP_POST,"
+"$DRIZZLE_TCP_PORT, puesto por defecto ("
 
 #: client/drizzleadmin.cc:81
 msgid "Silently exit if one can't connect to server."
-msgstr ""
+msgstr "Silenciosamente sale si no puede conectarse al servidor."
 
 #: client/drizzleadmin.cc:87
 msgid "Write more information."
-msgstr ""
+msgstr "Escribir más información."
 
 #: client/drizzleadmin.cc:254
 #, c-format
@@ -711,193 +727,476 @@
 "connect to server at '%s' failed\n"
 "error: '%s'"
 msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
 
 #: client/drizzleadmin.cc:260
 #, c-format
 msgid "Check that drizzled is running on %s"
-msgstr ""
+msgstr "Revise que drizzled esta corriendo en %s"
 
 #: client/drizzleadmin.cc:261
 #, c-format
 msgid " and that the port is %d.\n"
-msgstr ""
+msgstr " y el puerto es %d\n"
 
 #: client/drizzleadmin.cc:263
 #, c-format
 msgid "You can check this by doing 'telnet %s %d'\n"
-msgstr ""
+msgstr "Usted puede revisar esto ejecutando 'telnet %s %d'\n"
 
 #: client/drizzleadmin.cc:274
 #, c-format
 msgid "Got error: %s\n"
-msgstr ""
+msgstr "Recibio error: %s\n"
 
 #: client/drizzleadmin.cc:281
 msgid "Waiting for Drizzle server to answer"
-msgstr ""
+msgstr "Esperando respuesta del servidor Drizzle"
 
 #: client/drizzleadmin.cc:314
 #, c-format
 msgid "shutting down drizzled...\n"
-msgstr ""
+msgstr "cerrando drizzled...\n"
 
 #: client/drizzleadmin.cc:318
 #, c-format
 msgid "shutdown failed; error: '%s'"
-msgstr ""
+msgstr "Operacion de cierre fallida; error: '%s'"
 
 #: client/drizzleadmin.cc:325
 #, c-format
 msgid "done\n"
-msgstr ""
+msgstr "hecho\n"
 
 #: client/drizzleadmin.cc:335
 msgid "drizzled is alive"
-msgstr ""
+msgstr "drizzled esta vivo"
 
 #: client/drizzleadmin.cc:343
 msgid "connection was down, but drizzled is now alive"
-msgstr ""
+msgstr "conexion estaba abajo, pero drizzled ahora esta vivo"
 
 #: client/drizzleadmin.cc:347
 #, c-format
 msgid "drizzled doesn't answer to ping, error: '%s'"
-msgstr ""
+msgstr "drizzled no reponde a ping, error: '%s'"
 
 #: client/drizzleadmin.cc:356
 #, c-format
 msgid "Unknown command: '%-.60s'"
-msgstr ""
+msgstr "Comando desconocido: '%-.60s'"
 
 #: client/drizzleadmin.cc:365
 #, c-format
 msgid "%s  Ver %s Distrib %s, for %s on %s\n"
-msgstr ""
+msgstr "%s Ver %s Distrib %s, para %s en %s\n"
 
 #: client/drizzleadmin.cc:372
 msgid "Copyright (C) 2000-2008 MySQL AB"
-msgstr ""
+msgstr "Derechos Reservados (C) 2000-2008 MySQL AB"
 
 #: client/drizzleadmin.cc:373
 msgid ""
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
 "and you are welcome to modify and redistribute it under the GPL license\n"
 msgstr ""
+"Este software viene con ABSOLUTAMENTE NINGUNA GARANTIA. Esto es software "
+"libre y usted es bienvenido a modificarlo y redistribuirlo debajo de la "
+"licencia GPL.\n"
 
 #: client/drizzleadmin.cc:374
 msgid "Administration program for the drizzled daemon."
-msgstr ""
+msgstr "Programa de adminisitracion para el demonio drizzled."
 
 #: client/drizzleadmin.cc:375
 #, c-format
 msgid "Usage: %s [OPTIONS] command command....\n"
-msgstr ""
+msgstr "Utilizacion: %s [OPCIONES] comando comando...\n"
 
 #: client/drizzleadmin.cc:377
 msgid ""
 "  ping         Check if server is down\n"
 "  shutdown     Take server down\n"
 msgstr ""
+"  ping Revisa si el servidor esta abajo\n"
+" shutdown Cierra el servidor\n"
+
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Error desconocido %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "No puede crear directorio '%s' (Codigo de error: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Imposible conectar al servidor\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Código de error inválido"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"conexion al servidor en '%s'  fallido\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "Archivo '%s' no encontrado (Codigo de error: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Error leyendo el archivo '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
-msgstr ""
-
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
+msgstr "No puede crear/escribir el archivo '%s' (Codigo de Error: %d)"
 
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Error escribiendo el archivo '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:28
-#, c-format
+#, fuzzy, c-format
 msgid "Error on close of '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Error tratando de cerrar '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:29
 #, c-format
 msgid "Out of memory (Needed %u bytes)"
-msgstr ""
+msgstr "No hay mas memoria (Se necesitan %u bytes)"
 
 #: mysys/errors.c:30
 #, c-format
 msgid "Error on delete of '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Error tratando de eliminar '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:31
 #, c-format
 msgid "Error on rename of '%s' to '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Error tratando de renombrar '%s' a '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:32
 #, c-format
 msgid "Unexpected eof found when reading file '%s' (Errcode: %d)"
 msgstr ""
+"EOF inesperado encontrado al leer el archivo '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:33
 #, c-format
 msgid "Can't lock file (Errcode: %d)"
-msgstr ""
+msgstr "No puede bloquear el archivo (Codigo de error: %d)"
 
 #: mysys/errors.c:34
 #, c-format
 msgid "Can't unlock file (Errcode: %d)"
-msgstr ""
+msgstr "No puede desbloquear el archivo (Codigo de error: %d)"
 
 #: mysys/errors.c:35
 #, c-format
 msgid "Can't read dir of '%s' (Errcode: %d)"
-msgstr ""
+msgstr "No puede leer el directorio de '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:36
 #, c-format
 msgid "Can't get stat of '%s' (Errcode: %d)"
-msgstr ""
+msgstr "No puede obtener estadistica de '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:37
 #, c-format
 msgid "Can't change size of file (Errcode: %d)"
-msgstr ""
+msgstr "No puede cambiar el tamaño del archivo (Codigo de error: %d)"
 
 #: mysys/errors.c:38
 #, c-format
 msgid "Can't open stream from handle (Errcode: %d)"
-msgstr ""
+msgstr "No puede abrir la corriente desde el tirador (Codigo de error: %d)"
 
 #: mysys/errors.c:39
 #, c-format
 msgid "Can't get working dirctory (Errcode: %d)"
-msgstr ""
+msgstr "No puede obtener directory de trabajo (Codigo de error: %d)"
 
 #: mysys/errors.c:40
 #, c-format
 msgid "Can't change dir to '%s' (Errcode: %d)"
-msgstr ""
+msgstr "No puede cambiar directorio a '%'s (Codigo de error: %d)"
 
 #: mysys/errors.c:41
 #, c-format
 msgid "Warning: '%s' had %d links"
-msgstr ""
+msgstr "Advertencia: '%s' tiene '%d' enlaces"
 
 #: mysys/errors.c:42
 #, c-format
 msgid "Warning: %d files and %d streams is left open\n"
-msgstr ""
+msgstr "Advertencia: %d archivos y %d corrientes se quedaron abiertos\n"
 
 #: mysys/errors.c:43
 #, c-format
 msgid "Disk is full writing '%s'. Waiting for someone to free space..."
 msgstr ""
+"Disco esta lleno escribiendo '%s'. Esperando a que alguien libere espacio..."
 
 #: mysys/errors.c:44
 #, c-format
 msgid "Can't create directory '%s' (Errcode: %d)"
-msgstr ""
+msgstr "No puede crear directorio '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:45
 #, c-format
@@ -905,31 +1204,35 @@
 "Character set '%s' is not a compiled character set and is not specified in "
 "the %s file"
 msgstr ""
+"El conjunto de caracteres '%'s no es un conjunto de caracteres compilado y "
+"no puede ser especificado en el archivo '%s'"
 
 #: mysys/errors.c:46
 #, c-format
 msgid "Out of resources when opening file '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Sin recursos al abrir el archivo '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:47
 #, c-format
 msgid "Can't read value for symlink '%s' (Error %d)"
-msgstr ""
+msgstr "No puede leer el valor para el symlink '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:48
 #, c-format
 msgid "Can't create symlink '%s' pointing at '%s' (Error %d)"
 msgstr ""
+"No puede crear un enlace simbolico '%s' apuntando a '%s' (Codigo de error: %"
+"d)"
 
 #: mysys/errors.c:49
 #, c-format
 msgid "Error on realpath() on '%s' (Error %d)"
-msgstr ""
+msgstr "Error en realpath() en '%s' (Codigo de error: %d)"
 
 #: mysys/errors.c:50
 #, c-format
 msgid "Can't sync file '%s' to disk (Errcode: %d)"
-msgstr ""
+msgstr "No puede sincronizar archivo '%s' a disco (Codigo de error: %d)"
 
 #: mysys/errors.c:51
 #, c-format
@@ -937,57 +1240,54 @@
 "Collation '%s' is not a compiled collation and is not specified in the %s "
 "file"
 msgstr ""
-
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
+"Coalicion '%s' no es una coalicion compilada y no es especificada en el "
+"archivo '%s'"
 
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
-msgstr ""
+msgstr "Archivo '%s' (fileno: %d) no fue cerrado"
 
 #: mysys/my_error.c:86
 #, c-format
 msgid "Unknown error %d"
-msgstr ""
+msgstr "Error desconocido %d"
 
 #: mysys/my_getopt.c:83
 msgid "Warning: "
-msgstr ""
+msgstr "Advertencia: "
 
 #: mysys/my_getopt.c:85
 msgid "Info: "
-msgstr ""
+msgstr "Informacion: "
 
 #: mysys/my_getopt.c:350
 #, c-format
 msgid "%s: %s: Option '%s' used, but is disabled\n"
-msgstr ""
+msgstr "%s: %s: Opcion '%s' usada, pero esta desabilitada\n"
 
 #: mysys/my_getopt.c:351
 msgid "WARNING"
-msgstr ""
+msgstr "ADVERTENCIA"
 
 #: mysys/my_getopt.c:351
 msgid "ERROR"
-msgstr ""
+msgstr "ERROR"
 
 #: mysys/my_getopt.c:454
 #, c-format
 msgid "%s: ERROR: Option '-%c' used, but is disabled\n"
-msgstr ""
+msgstr "%s: ERROR: Opcion '-%c' usada, pero esta desabilitada\n"
 
 #: mysys/my_getopt.c:767
 #, c-format
 msgid "Unknown suffix '%c' used for variable '%s' (value '%s')\n"
-msgstr ""
+msgstr "Sufijo desconocido '%c' usado por variable '%s' (valor '%s')\n"
 
 #: mysys/my_getopt.c:948
 #, c-format
 msgid "%s: ERROR: Invalid decimal value for option '%s'\n"
-msgstr ""
+msgstr "%s: ERROR: Valor decimal invalido para opcion '%s'\n"
 
 #: mysys/my_getopt.c:1170
 #, c-format
@@ -1002,10 +1302,13 @@
 "and boolean options {false|true}  Value (after reading options)\n"
 "--------------------------------- -----------------------------\n"
 msgstr ""
+"\n"
+"variables (--variable-name=valor)\n"
+"y opciones booleanas {false|true} Valor (despues de leer opciones)\n"
 
 #: mysys/my_getopt.c:1206 mysys/my_getopt.c:1222
 msgid "(No default value)"
-msgstr ""
+msgstr "(Ningun valor por defecto)"
 
 #: mysys/my_getopt.c:1225
 msgid "true"
@@ -1018,173 +1321,182 @@
 #: mysys/my_getopt.c:1250
 #, c-format
 msgid "(Disabled)\n"
-msgstr ""
+msgstr "(Desabilitado)\n"
 
 #: mysys/my_handler_errors.h:10
 msgid "Didn't find key on read or update"
-msgstr ""
+msgstr "No encontro llave al leer o actualizar"
 
 #: mysys/my_handler_errors.h:12
 msgid "Duplicate key on write or update"
-msgstr ""
+msgstr "Llave duplicada al leer o actualizar"
 
 #: mysys/my_handler_errors.h:14
 msgid "Internal (unspecified) error in handler"
-msgstr ""
+msgstr "Error interno (no especificado) en manejador"
 
 #: mysys/my_handler_errors.h:16
 msgid ""
 "Someone has changed the row since it was read (while the table was locked to "
 "prevent it)"
 msgstr ""
+"Alguien ha cambiado la fila desde que fue leida (mientras que la tabla fue "
+"bloqueada para prevenirlo)"
 
 #: mysys/my_handler_errors.h:18
 msgid "Wrong index given to function"
-msgstr ""
+msgstr "Indice equivocado otorgado a funcion"
 
 #: mysys/my_handler_errors.h:20
 msgid "Undefined handler error 125"
-msgstr ""
+msgstr "Manejador indefinido error 125"
 
 #: mysys/my_handler_errors.h:22
+#, fuzzy
 msgid "Index file is crashed"
-msgstr ""
+msgstr "Archivo indice ha estrallado"
 
 #: mysys/my_handler_errors.h:24
+#, fuzzy
 msgid "Record file is crashed"
-msgstr ""
+msgstr "Archivo record ha estrallado"
 
 #: mysys/my_handler_errors.h:26
 msgid "Out of memory in engine"
-msgstr ""
+msgstr "Sin memoria en el motor"
 
 #: mysys/my_handler_errors.h:28
 msgid "Undefined handler error 129"
-msgstr ""
+msgstr "Manejador indefinido error 129"
 
 #: mysys/my_handler_errors.h:30
 msgid "Incorrect file format"
-msgstr ""
+msgstr "Formato de archivo incorrecto"
 
 #: mysys/my_handler_errors.h:32
 msgid "Command not supported by database"
-msgstr ""
+msgstr "Comando no soportado por la base de datos"
 
 #: mysys/my_handler_errors.h:34
 msgid "Old database file"
-msgstr ""
+msgstr "Archivo viejo de base de datos"
 
 #: mysys/my_handler_errors.h:36
 msgid "No record read before update"
-msgstr ""
+msgstr "Ningun registro leido antes de la actualizacion"
 
 #: mysys/my_handler_errors.h:38
+#, fuzzy
 msgid "Record was already deleted (or record file crashed)"
-msgstr ""
+msgstr "Registro ya fue eliminado (o el archivo de registro estrallo)"
 
 #: mysys/my_handler_errors.h:40
 msgid "No more room in record file"
-msgstr ""
+msgstr "No hay mas espacio en el archivo de registro"
 
 #: mysys/my_handler_errors.h:42
 msgid "No more room in index file"
-msgstr ""
+msgstr "No hay mas espacio en el archivo de indice"
 
 #: mysys/my_handler_errors.h:44
 msgid "No more records (read after end of file)"
-msgstr ""
+msgstr "No hay mas registros (lectura despues del final del archivo)"
 
 #: mysys/my_handler_errors.h:46
 msgid "Unsupported extension used for table"
-msgstr ""
+msgstr "Extension no soportada usada para tabla"
 
 #: mysys/my_handler_errors.h:48
 msgid "Too big row"
-msgstr ""
+msgstr "Fila demasiado grande"
 
 #: mysys/my_handler_errors.h:50
 msgid "Wrong create options"
-msgstr ""
+msgstr "Opciones de crear equivocados"
 
 #: mysys/my_handler_errors.h:52
 msgid "Duplicate unique key or constraint on write or update"
-msgstr ""
+msgstr "Llave unica duplicada o limitacion al escribir o escribir"
 
 #: mysys/my_handler_errors.h:54
 msgid "Unknown character set used in table"
-msgstr ""
+msgstr "Conjunto de caracteres desconocido usado en tabla"
 
 #: mysys/my_handler_errors.h:56
 msgid "Conflicting table definitions in sub-tables of MERGE table"
 msgstr ""
+"Definiciones de tabla que causan conflictos en las sub-tablas de la tabla "
+"MERGE"
 
 #: mysys/my_handler_errors.h:58
+#, fuzzy
 msgid "Table is crashed and last repair failed"
-msgstr ""
+msgstr "Tabla se estrallo y la reparacion fallo"
 
 #: mysys/my_handler_errors.h:60
 msgid "Table was marked as crashed and should be repaired"
-msgstr ""
+msgstr "Tabla se marco como estrallada y debe ser reparada"
 
 #: mysys/my_handler_errors.h:62
 msgid "Lock timed out; Retry transaction"
-msgstr ""
+msgstr "Bloqueo alcanzo su limite de tiempo; Trate la transaccion de nuevo"
 
 #: mysys/my_handler_errors.h:64
+#, fuzzy
 msgid "Lock table is full;  Restart program with a larger locktable"
-msgstr ""
+msgstr "Lock table esta leno; Reinicie el programa con un locktable mas grande"
 
 #: mysys/my_handler_errors.h:66
 msgid "Updates are not allowed under a read only transactions"
-msgstr ""
+msgstr "Actualizaciones no son permitidas para transacciones de solo lectura"
 
 #: mysys/my_handler_errors.h:68
 msgid "Lock deadlock; Retry transaction"
-msgstr ""
+msgstr "Punto muerto de bloqueo; Reintente la transaccion"
 
 #: mysys/my_handler_errors.h:70
 msgid "Foreign key constraint is incorrectly formed"
-msgstr ""
+msgstr "Limitacion de llave extranjera formada incorrectamente"
 
 #: mysys/my_handler_errors.h:72
 msgid "Cannot add a child row"
-msgstr ""
+msgstr "No puede agregar fila hija"
 
 #: mysys/my_handler_errors.h:74
 msgid "Cannot delete a parent row"
-msgstr ""
+msgstr "No puede eliminar fila padre"
 
 #: mysys/my_handler_errors.h:76
 msgid "No savepoint with that name"
-msgstr ""
+msgstr "Ningun punto de salve con ese nombre"
 
 #: mysys/my_handler_errors.h:78
 msgid "Non unique key block size"
-msgstr ""
+msgstr "Tamaño de llave de bloque no unico"
 
 #: mysys/my_handler_errors.h:80
 msgid "The table does not exist in engine"
-msgstr ""
+msgstr "La tabla no existe en el motor"
 
 #: mysys/my_handler_errors.h:82
 msgid "The table already existed in storage engine"
-msgstr ""
+msgstr "La tabla ya existio en el motor de almacenamiento"
 
 #: mysys/my_handler_errors.h:84
 msgid "Could not connect to storage engine"
-msgstr ""
+msgstr "No se pudo conectar al motor de almacenamiento"
 
 #: mysys/my_handler_errors.h:86
 msgid "Unexpected null pointer found when using spatial index"
-msgstr ""
+msgstr "Puntero nulo no esperado encontrado al usar indice espacial"
 
 #: mysys/my_handler_errors.h:88
 msgid "The table changed in storage engine"
-msgstr ""
+msgstr "La tabla ha cambiado en el motor de almacenamiento"
 
 #: mysys/my_handler_errors.h:90
 msgid "There's no partition in table for the given value"
-msgstr ""
+msgstr "No hay particion en la tabla para el valor dado"
 
 #: mysys/my_handler_errors.h:92
 msgid "Row-based binlogging of row failed"
@@ -1192,43 +1504,45 @@
 
 #: mysys/my_handler_errors.h:94
 msgid "Index needed in foreign key constraint"
-msgstr ""
+msgstr "Indice necesitado para la limitacion de llave extranjera"
 
 #: mysys/my_handler_errors.h:96
 msgid "Upholding foreign key constraints would lead to a duplicate key error"
 msgstr ""
+"Mantener la limitacion de llave extranjera llevaria un error de llave "
+"duplicada"
 
 #: mysys/my_handler_errors.h:98
 msgid "Table needs to be upgraded before it can be used"
-msgstr ""
+msgstr "Tabla necesita ser actualizada antes de que pueda ser usada"
 
 #: mysys/my_handler_errors.h:100
 msgid "Table is read only"
-msgstr ""
+msgstr "La tabla es de solo lectura"
 
 #: mysys/my_handler_errors.h:102
 msgid "Failed to get next auto increment value"
-msgstr ""
+msgstr "No se pudo obtener el proximo valor de auto incremento"
 
 #: mysys/my_handler_errors.h:104
 msgid "Failed to set row auto increment value"
-msgstr ""
+msgstr "No se pudo establecer el valor de auto incremento de la fila"
 
 #: mysys/my_handler_errors.h:106
 msgid "Unknown (generic) error from engine"
-msgstr ""
+msgstr "Error desconocido (generico) desde el motor"
 
 #: mysys/my_handler_errors.h:108
 msgid "Record is the same"
-msgstr ""
+msgstr "Registro es igual"
 
 #: mysys/my_handler_errors.h:110
 msgid "It is not possible to log this statement"
-msgstr ""
+msgstr "No es posible loguear esta declaracion"
 
 #: mysys/my_handler_errors.h:112
 msgid "Tablespace exists"
-msgstr ""
+msgstr "El espacio de tabla existe"
 
 #: mysys/my_handler_errors.h:114
 msgid "The event was corrupt, leading to illegal data being read"
@@ -1236,19 +1550,19 @@
 
 #: mysys/my_handler_errors.h:116
 msgid "The table is of a new format not supported by this version"
-msgstr ""
+msgstr "La tabla es de un nuevo formato no soportado por esta version"
 
 #: mysys/my_handler_errors.h:118
 msgid "The event could not be processed no other hanlder error happened"
-msgstr ""
+msgstr "El evento no pudo ser procesado ningun otro error de manejador ocurrio"
 
 #: mysys/my_handler_errors.h:120
 msgid "Got a fatal error during initialzaction of handler"
-msgstr ""
+msgstr "Obtuvo un error fatal durante la inicializacion del manejador"
 
 #: mysys/my_handler_errors.h:122
 msgid "File to short; Expected more data in file"
-msgstr ""
+msgstr "Archivo muy corto; Esperaba mas data en el archivo"
 
 #: mysys/my_handler_errors.h:124
 msgid "Read page with wrong checksum"
@@ -1264,72 +1578,83 @@
 
 #: mysys/my_handler_errors.h:130
 msgid "Tablespace not empty"
+msgstr "Espacio de tabla no vacio"
+
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
 msgstr ""
 
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
-msgstr ""
+msgstr "Obtuvo error %d de pthread_cond_timedwait"
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
-msgstr ""
+msgstr "No puede crear hilo de ejecucion para matar el servidor"
 
 #: drizzled/drizzled.cc:758
 #, c-format
 msgid "Got signal %d from thread %ld"
-msgstr ""
+msgstr "Obtuvo señal % del hilo de ejecucion %ld"
 
 #: drizzled/drizzled.cc:792
 msgid "Aborting\n"
-msgstr ""
+msgstr "Abortando\n"
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
-msgstr ""
+msgstr "solo se puede user el switch --user si esta ejecutando como root\n"
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
+"Error fatal: Por favor lea la seccion de \"Seguridad\" del manual para "
+"investigar como ejecutar mysqld como root!\n"
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
+"Error fatal: No puede cambiar para ejecutar como el usuario '%s'; Por favor "
+"revise si el usuario ha existe!\n"
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
-msgstr ""
+msgstr "Ya tiene otro servidor drizzled ejecutando en el puerto: %d ?"
+
+#: drizzled/drizzled.cc:1210
+#, fuzzy
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr "No puede iniciar servidor: listen() en TCP/IP puerto"
 
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
-msgstr ""
+msgstr "listen() en TCP/IP fallo con error %d"
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1340,7 +1665,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1350,7 +1675,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1358,14 +1683,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1377,7 +1702,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1388,7 +1713,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1400,182 +1725,201 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Escribiendo fichero histórico %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
+#, fuzzy
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
+"strlimit no pudo cambiar el tamaño de los archivos nucelos a 'infinito'; "
+"Nosotros quiza no podremos generar los archivos nucleos al recibir señales."
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
+"No se pudo crear hilo de ejecucion de interrupcion (error %d, errno: %d)"
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
-msgstr ""
+msgstr "Obtuvo señal %d para cerrar mysqld"
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
-msgstr ""
+msgstr "Obtuvio señal: %d error %d"
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
-msgstr ""
+msgstr "gethostname fallo, usando '%s' como hostname"
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
+"Cambiaron los limites: max_open_files: %u max_connections: %ld table_cache %"
+"ld"
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
+"No se pudo aumentar el number de max_open_files a mas de %u (peticion: %u)"
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
-msgstr ""
+msgstr "Local desconocido: '%s'"
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
+"Aunque la ruta fue especificada para la opcion --log, tablas de log son "
+"usadas. Para habilitar logueo a archivos use la opcion --log-output."
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
-msgstr ""
+msgstr "No se puede crear las llave de hilos de ejecucion"
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
-msgstr ""
+msgstr "Memoria agotada"
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
+"Usted necesita usar --login-bin para hacer que --binlog-format funcione"
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
+"Usar --replicate-same-server-id en conjuncion con --log-slave-updates es "
+"imposible, esto llevaria a ciclos infinitos en el servidor."
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
 "replication may break when this Drizzle server acts as a master and has his "
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
+"Ningun argument proveido a --log-bin, y --login-bin-index no fue usado; asi "
+"que la replicacion puede romper cuando este servidor Drizzle actua  como un "
+"servidor maestro y tiene y su hostname cambia! Porfavor use '--log-bin='%s' "
+"para evitar este problema."
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
-msgstr ""
+msgstr "Fallo al tratar de inicializar plugins."
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
-msgstr ""
+msgstr "No se pueden inicializar las bases de datos"
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
-msgstr ""
+msgstr "Tipo de tabal desconocida o no soportada: %s"
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
-msgstr ""
+msgstr "Motor de almacenamiento usado por defecto (%s) no disponible"
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
-msgstr ""
+msgstr "No se puede inicializar tc_log"
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
-msgstr ""
+msgstr "Fallo al tratar de bloquear memoria. Errno: %d\n"
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
-msgstr ""
+msgstr "Se pidio la pila de hilos de ejecucion %u , pero se obtuvo %llu"
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
-msgstr ""
+msgstr "Antes Lock_thread_count"
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
-msgstr ""
+msgstr "Despues lock_thread_count"
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
-msgstr ""
+msgstr "drizzled: Obtuvo error %d de select"
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
+#, fuzzy
 msgid "Option used by mysql-test for debugging and testing of replication."
-msgstr ""
+msgstr "Opcion usada por mysql-test para debuggear y probar la replicacion."
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
-msgstr ""
+msgstr "Columnas de auto increment son incrementado por esto"
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
+"Ruta a directorio de instalacion. Todas las rutas usualmente resuelven a "
+"esto."
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1586,151 +1930,174 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
+#, fuzzy
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
+"Le dice al maestro que debe loguear actualizaciones para la base de datos "
+"especificada, y excluir todas las otras no mencionadas."
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
+#, fuzzy
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
+"Le dice al maestro que las actualizaciones de para base de datos "
+"especificada no deben ser loggeadas al log binario."
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
+"Tamaño maximo de el log binario basado en filas en bytes. Las filas deben "
+"sesr agrupadas en eventos mas pequeños que este tamaño si es posible. El "
+"valor tiene que ser un multiplo de 256."
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
+#, fuzzy
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
+"No ignora el valor de conjunto de caracteres enviado durante el handshake."
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
-msgstr ""
+msgstr "Establece el conujnto de caracteres del sistema de archivos."
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
-msgstr ""
+msgstr "CHroot mysqld demonio durante inicio."
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
-msgstr ""
+msgstr "Establece la coalicion por defecto."
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
-msgstr ""
+msgstr "Escribe la salida de error a la pantalla."
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
-msgstr ""
+msgstr "Escribe nucleo en errores."
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
-msgstr ""
+msgstr "Ruta a la raiz de la base de datos."
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
+"Establece el conjunto de caracteres por defecto (opcion deprecada, use --"
+"character-set-server en sustitucion)."
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
+"Establece la coalicion por defecto (opcion deprecada, use --collation-server "
+"en sustitucion)."
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
+"Establece el motor de almacenamiento por defecto (tipo de tabla) para las "
+"tablas."
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
-msgstr ""
+msgstr "Establece la zona de tiempo por defecto."
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
-msgstr ""
+msgstr "Tipo de DELAY_KEY_WRITE."
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
-msgstr ""
+msgstr "Imprime stack trace simbolico en fallo."
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
-msgstr ""
+msgstr "Comando(s) que son ejecutados para cada nueva conexion"
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
-msgstr ""
+msgstr "Lee comandos SQL de este archivo al iniciar."
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
-msgstr ""
+msgstr "Comando(s) que son ejecutaods cuando el esclavo se conecta al maestro."
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
-msgstr ""
+msgstr "(IGNORADO)"
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
+"Establece el lenguaje usado para los nombres de los meses y los dias de la "
+"semana."
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
-msgstr ""
+msgstr "Establece/desabilita LOAD DATA LOCAL INFILE (toma valores 1|0)."
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
-msgstr ""
+msgstr "Loguear conexiones y consultas a archivo."
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
+#, fuzzy
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
+"Loguea consultas de actualizacion en formato binario. Argumento opcional es "
+"la locazacion de los archivos de log binario. (Recomendado que se evite la "
+"replicacion de problemas si el hostname del serivdor cambia)"
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1740,141 +2107,143 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
+"Cantidad de intentos que el esclavo intetara conectarse el maestro antes de "
+"rendirse."
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
-msgstr ""
+msgstr "Bloquea mysqld en memoria."
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1884,7 +2253,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1892,7 +2261,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1901,7 +2270,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1909,20 +2278,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1932,7 +2301,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1942,7 +2311,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1952,7 +2321,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1960,63 +2329,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2024,139 +2393,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2164,162 +2533,163 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
+#, fuzzy
 msgid "(Deprecated option)"
-msgstr ""
+msgstr "Opciones de crear equivocados"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Buffer para comunicación socket y TCP/IP"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2327,7 +2697,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2335,7 +2705,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2346,163 +2716,166 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Utilizar compresión en protocolo cliente/servidor."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "ADVERTENCIA: opción desfasada; utilizar mejor --disable-pager.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
+#, fuzzy
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
+"Cantidad de intentos que el esclavo intetara conectarse el maestro antes de "
+"rendirse."
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2511,76 +2884,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5896,6 +6269,158 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "No se pudo conectar al motor de almacenamiento"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr "Fallo al tratar de bloquear memoria. Errno: %d\n"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+#, fuzzy
+msgid "Could not open log file"
+msgstr "No se pudo conectar al motor de almacenamiento"
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5931,18 +6456,56 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+"No se pudo crear hilo de ejecucion de interrupcion (error %d, errno: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6363,6 +6926,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Sin memoria en el motor"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6379,6 +7055,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "¡Imposible reservar memoria para histfile temporal!\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/fr.po'
--- po/fr.po	2008-08-14 17:35:53 +0000
+++ po/fr.po	2008-08-16 23:49:05 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
-"PO-Revision-Date: 2008-08-13 21:41+0000\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
+"PO-Revision-Date: 2008-08-15 17:01+0000\n"
 "Last-Translator: Pierre Hanselmann <pierre.hanselmann@sunrise.ch>\n"
 "Language-Team: French <fr@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n > 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -169,7 +169,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Requête annulée par Ctrl-C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Afficher cette aide et sortir."
 
@@ -215,7 +215,7 @@
 "Ne pas utiliser de fichier d'historique. Désactive l'interactivité. (Active "
 "--silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "Répértoire ou se situent les jeux de caractères."
 
@@ -248,7 +248,7 @@
 msgid "Database to use."
 msgstr "Base de donnée à utiliser"
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Définit le jeu de caractères par défaut."
 
@@ -290,6 +290,12 @@
 "G'. Long format commands still work from the first line. WARNING: option "
 "deprecated; use --disable-named-commands instead."
 msgstr ""
+"Les commandes nommées sont désactivées. Utilisez la forme \\* uniquement, ou "
+"bien utilisez les commandes nommées uniquement au début d'une ligne qui se "
+"termine par un point-virgule (;). Depuis la version 10.9, le client se lance "
+"avec cette option active, par défaut. Désactivez-la avec l'option -G. Les "
+"commandes en format long fonctionnent toujours. Attention : cette option est "
+"obsolète; utilisez de préférence --disable-named-commands."
 
 #: client/drizzle.cc:1326
 msgid "Ignore space after function names."
@@ -364,6 +370,12 @@
 "work in batch mode. Disable with --disable-pager. This option is disabled by "
 "default."
 msgstr ""
+"Le pager à utiliser pour afficher les résultats. Si vous ne fournissez pas "
+"de valeur pour cette option, un pager par défaut sera choisi via la variable "
+"d'environnement PAGER. Les pagers valides sont less, more, cat [> "
+"nom_de_fichier], etc. Sinon, reportez-vous à l'aide interactive (\\h). Cette "
+"option ne fonctionne pas en mode batch. Désactivez le pager avec l'option --"
+"disable-page. Cette option est désactivée par défaut."
 
 #: client/drizzle.cc:1361
 msgid ""
@@ -474,7 +486,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "Affiche plus d'infos. (-v -v -v donne le format de sortie de la table)"
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Donne l'information de la version et quitte."
 
@@ -709,7 +721,7 @@
 msgstr[0] "Requête OK, %ld ligne affectée"
 msgstr[1] "Requête OK, %ld lignes affectées"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 #, fuzzy
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
@@ -828,16 +840,290 @@
 "  ping Vérifie si le serveur est down\n"
 "  shutdown Éteint le serveur\n"
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Erreur inconnue %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "Ne peux créer le répertoire '%s' (Errcode: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Connexion au serveur impossible\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "Commande inconnue: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Erreur inconnue %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"la connexion au serveur '%s' a échoué\n"
+"erreur: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"la connexion au serveur '%s' a échoué\n"
+"erreur: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"la connexion au serveur '%s' a échoué\n"
+"erreur: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"la connexion au serveur '%s' a échoué\n"
+"erreur: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"la connexion au serveur '%s' a échoué\n"
+"erreur: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "Fichier '%s' non trouvé (Errcode: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Erreur de lecture sur le fichier '%s' (Errcode: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "Ne peux créer/écrire le fichier '%s' (Errcode: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "Erreur de lecture sur le fichier '%s' (Errcode: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -975,11 +1261,6 @@
 "La collation '%s' n'est pas compilée, et n'est pas spécifiée dans le fichier "
 "%s."
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "Fichier '%s' non trouvé (Errcode: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1137,7 +1418,7 @@
 
 #: mysys/my_handler_errors.h:44
 msgid "No more records (read after end of file)"
-msgstr ""
+msgstr "Il n'y a plus de lignes (on a atteint la fin du fichier)"
 
 #: mysys/my_handler_errors.h:46
 msgid "Unsupported extension used for table"
@@ -1145,7 +1426,7 @@
 
 #: mysys/my_handler_errors.h:48
 msgid "Too big row"
-msgstr ""
+msgstr "La ligne est trop grosse"
 
 #: mysys/my_handler_errors.h:50
 msgid "Wrong create options"
@@ -1154,6 +1435,8 @@
 #: mysys/my_handler_errors.h:52
 msgid "Duplicate unique key or constraint on write or update"
 msgstr ""
+"Doublon pour une clé unique ou une contrainte durant une écriture ou une "
+"modification"
 
 #: mysys/my_handler_errors.h:54
 msgid "Unknown character set used in table"
@@ -1161,7 +1444,7 @@
 
 #: mysys/my_handler_errors.h:56
 msgid "Conflicting table definitions in sub-tables of MERGE table"
-msgstr ""
+msgstr "Conflit de définition de tables dans les sous-tables de la table MERGE"
 
 #: mysys/my_handler_errors.h:58
 msgid "Table is crashed and last repair failed"
@@ -1189,7 +1472,7 @@
 
 #: mysys/my_handler_errors.h:68
 msgid "Lock deadlock; Retry transaction"
-msgstr ""
+msgstr "Blocage de verrous. Réessayez la transaction un peu plus tard"
 
 #: mysys/my_handler_errors.h:70
 msgid "Foreign key constraint is incorrectly formed"
@@ -1197,7 +1480,7 @@
 
 #: mysys/my_handler_errors.h:72
 msgid "Cannot add a child row"
-msgstr ""
+msgstr "Impossible d'ajouter une ligne fille"
 
 #: mysys/my_handler_errors.h:74
 msgid "Cannot delete a parent row"
@@ -1320,70 +1603,81 @@
 msgid "Tablespace not empty"
 msgstr "L'espace de tables n'est pas vide"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
-msgstr ""
+msgstr "Reçu l'erreur %d de pthread_cond_timedwait"
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
-msgstr ""
+msgstr "Impossible de créer un thread pour terminer le serveur"
 
 #: drizzled/drizzled.cc:758
 #, c-format
 msgid "Got signal %d from thread %ld"
-msgstr ""
+msgstr "Reçu le signal %d du thread %ld"
 
 #: drizzled/drizzled.cc:792
 msgid "Aborting\n"
-msgstr ""
+msgstr "Annulation\n"
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
-msgstr ""
+msgstr "On ne peut utiliser l'option --user que si on est root\n"
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
+"Erreur fatale : relisez la section '\"Sécurité\" du manuel pour savoir "
+"comment exécuter mysqld en tant que root\n"
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
+"Erreur fatale : impossible d'exécuter mysqld en tant qu'utilisateur '%s'. "
+"Vérifiez que cet utilisateur existe\n"
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
-msgstr ""
+msgstr "Nouvelle tentative de connexion TCP/IP sur le port %u"
+
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr "Impossible de lancer le serveur : connexion sur le port TCP/IP"
 
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
+"Auriez-vous un autre serveur Drizzle qui fonctionne déjà sur le port %d?"
+
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr "Impossible de démarrer le serveur : listen() sur le port TCP/IP"
 
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
-msgstr ""
+msgstr "listen() sur TCP/IP a échoué avec l'erreur %d"
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1394,7 +1688,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1404,7 +1698,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1412,14 +1706,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1431,7 +1725,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1442,7 +1736,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1454,90 +1748,95 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Ecris le fichier historique %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
-msgstr ""
+msgstr "Impossible de créer un thread d'interruption (erreur %d, errno : %d)"
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
-msgstr ""
+msgstr "Reçu le signal %d pour arrêter le serveur mysqld"
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
-msgstr ""
+msgstr "Reçu le signal : %d erreur : %d"
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
-msgstr ""
+msgstr "gethostname a échoué, on utilise '%s' comme nom d'hôte"
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
+"Changement de limites : max_open_files : %u max_connections : %ld "
+"table_cache : %ld"
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
+"Impossible d'augmenter le nombre de max_open_files à plus de %u (exigé: %u)"
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
-msgstr ""
+msgstr "Locale inconnue : '%s'"
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
-msgstr ""
+msgstr "Mémoire insuffisante"
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
-msgstr ""
+msgstr "Vous devez utilisez -log-bin pour que --binlog-format fonctionne."
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
+"Utiliser --replicate-same-server-id en conjonction avec --log-slave-updates "
+"est impossible, cela amènerait des boucle infinies dans ce serveur."
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1545,91 +1844,93 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
-msgstr ""
+msgstr "Échec à l'initialisation des plugins."
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
-msgstr ""
+msgstr "Initialisation des base de données impossible."
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
-msgstr ""
+msgstr "Type de table: %s inconnu/non supporté"
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
-msgstr ""
+msgstr "Le moteur de stockage par défaut (%s) indisponible"
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
-msgstr ""
+msgstr "Initialisation de tc_log impossible"
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
-msgstr ""
+msgstr "Avant lock_thread_count"
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
-msgstr ""
+msgstr "Après lock_thread_count"
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
+"Chemin du répertoire d'installation. Tous les les chemins relatifs se "
+"résolvent a partir de ce point."
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1640,151 +1941,154 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
-msgstr ""
+msgstr "Définit l'encodage de caractère du système de fichier."
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
-msgstr ""
+msgstr "Ecrit les erreurs à l'écran."
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
-msgstr ""
+msgstr "Chemin à la racine de la base de donnée."
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
+"Définit les jeu de caractères (option obsolète, utilisez --character-set-"
+"server à la place)."
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
-msgstr ""
+msgstr "Définit le fuseau horraire par défaut."
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
-msgstr ""
+msgstr "Type de DELAY_KEY_WRITE."
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
-msgstr ""
+msgstr "Utilisé pour le debuggage; A utiliser à vos risques et périls!"
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
-msgstr ""
+msgstr "Active le log des requêtes"
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
-msgstr ""
+msgstr "Commande(s) utilisée(s) à chaque nouvelle connexion"
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
-msgstr ""
+msgstr "Lis les commandes SQL depuis ce fichier à chaque démarrage."
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
-msgstr ""
+msgstr "Commande(s) exécutée(s) lorsqu'un esclave se connecte à ce maître"
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
-msgstr ""
+msgstr "(IGNORÉ)"
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
+"Définit la langue utilisée pour le nom des mois et des jours de la semaine."
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
-msgstr ""
+msgstr "Active/désactive LOAD DATA LOCAL INFILE (prends 1 ou 0 comme valeurs)."
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1794,141 +2098,143 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
-msgstr ""
+msgstr "Fichier du log d'erreur."
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
+"Syntaxe: log-output[=valeur[,valeur...]], où \"valeur\" peut être TABLE, "
+"FILE ou NONE."
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1938,7 +2244,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1946,7 +2252,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1955,7 +2261,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1963,20 +2269,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1986,7 +2292,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1996,7 +2302,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -2006,7 +2312,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -2014,63 +2320,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2078,139 +2384,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2218,163 +2524,163 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "Fausse option de creation"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Tampon pour les communications TCP/IP et socket"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2382,7 +2688,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2390,7 +2696,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2401,163 +2707,163 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Utilise la compression dans le protocole serveur/client."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "ATTENTION: option obsolète; utilisez --disable-pager à la place.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2566,76 +2872,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5975,6 +6281,158 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "Erreur %d du moteur de stockage"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr "Impossible de verrouiller le fichier (Errcode : %d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+#, fuzzy
+msgid "Could not open log file"
+msgstr "Connexion au moteur de stockage impossible"
+
+#: drizzled/log.cc:1102
+#, fuzzy, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr "Echoué sur request_dump()"
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, fuzzy, c-format
+msgid "Failed to delete file '%s'"
+msgstr "Echoué sur request_dump()"
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, fuzzy, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr "Echoué sur request_dump()"
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "Impossible de verrouiller le fichier (Errcode : %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -6010,18 +6468,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "Impossible de créer un thread d'interruption (erreur %d, errno : %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6450,6 +6945,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "Ne peux créer la table '%-.200s' (errno: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "Commande inconnue: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Mémoire insuffisante dans le moteur"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr "Echec dans send_file() à la lecture du nom de fichier"
@@ -6466,6 +7074,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr "Echec dans send_file() à la fin du transfert de fichier."
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "Erreur inconnue %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "Ne peux allouer de la mémoire pour le fichier historique temporaire!\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/hi.po'
--- po/hi.po	2008-08-14 17:35:53 +0000
+++ po/hi.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 03:14+0000\n"
 "Last-Translator: Monty Taylor <monty@inaugust.com>\n"
 "Language-Team: Hindi <hi@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -159,7 +159,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "कुएरी Ctrl+C द्वारा रद्द की गई.\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "इस सहायता को पर्दर्शित करे और बाहर निकले."
 
@@ -194,7 +194,7 @@
 "इतिहासिक फाइल का उपयोग न करे. परस्पर व्यवहार को अक्षम करता है. (--silent को सक्षम "
 "करता है)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "चारसेट वाली डाईरेकट्री."
 
@@ -226,7 +226,7 @@
 msgid "Database to use."
 msgstr "प्रयोग किया जाने वाला डाटाबेस."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "डीफौल्ट चारसेट सेट करे."
 
@@ -442,7 +442,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "अधिक लिखें . (-v -v -v तालिका उत्पादन प्रारूप देता है) ."
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "संस्करण सूचना प्रिंट करे और बाहर निकले."
 
@@ -663,7 +663,7 @@
 msgstr[0] "क्वैरी ओ.के, %ld पंक्ति प्रभावित"
 msgstr[1] "क्वैरी ओ.के, %ld पंक्तियाँ प्रभावित"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -775,16 +775,291 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "अज्ञात त्रुटि %d"
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "सर्वर से कनेक्ट नही कर पा रहा है\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "अज्ञात कमांड: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "अज्ञात त्रुटि %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "त्रुटी कोड अवैध है"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"'%s' पर सर्वर को कनेक्ट करना विफल हुआ\n"
+"त्रुटी: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"'%s' पर सर्वर को कनेक्ट करना विफल हुआ\n"
+"त्रुटी: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"'%s' पर सर्वर को कनेक्ट करना विफल हुआ\n"
+"त्रुटी: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"'%s' पर सर्वर को कनेक्ट करना विफल हुआ\n"
+"त्रुटी: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"'%s' पर सर्वर को कनेक्ट करना विफल हुआ\n"
+"त्रुटी: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "'%s' फाइल नही मिली (त्रुटी कोड: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "फ़ाइल '%s' पढ़ने में त्रुटि (त्रुटि कोड: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "'%s' फाइल को बनाने/लिखने के समय विफल हुआ (त्रुटि कोड: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "फ़ाइल '%s' पढ़ने में त्रुटि (त्रुटि कोड: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -914,11 +1189,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "'%s' फाइल नही मिली (त्रुटी कोड: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1242,12 +1512,18 @@
 msgid "Tablespace not empty"
 msgstr "तालिकास्थान खाली नही है"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1260,52 +1536,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1316,7 +1592,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1326,7 +1602,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1334,14 +1610,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1353,7 +1629,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1364,7 +1640,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1376,90 +1652,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "इतिहासिक फाइल %s लिखी जा रही है.\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1467,91 +1743,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1562,151 +1838,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1716,141 +1992,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1860,7 +2136,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1868,7 +2144,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1877,7 +2153,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1885,20 +2161,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1908,7 +2184,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1918,7 +2194,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1928,7 +2204,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1936,63 +2212,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2000,139 +2276,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2140,163 +2416,163 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "निरमाण के विकल्प ग़लत है"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "TCP/IP एवं सॉकेट संचार का बफ़र"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2304,7 +2580,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2312,7 +2588,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2323,163 +2599,163 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "सर्वर/क्लाइंट प्रोटोकॉल में संपीडन का प्रयोग करे."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "चेतावनी : विकल्प पदावनत है; इसकी बजाये --disable-pager का उपयोग करे.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2488,76 +2764,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5884,6 +6160,158 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "कनेक्ट कर रहा है"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+#, fuzzy
+msgid "I/O error reading the header from the binary log"
+msgstr "इंडेक्स फाइल में और जगह नही है"
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr "फ़ाइल लॉक नहीं कर सकता (त्रुटी कोड: %d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "फ़ाइल लॉक नहीं कर सकता (त्रुटी कोड: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5919,18 +6347,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr "दास %s: %s%s त्रुटी कोड: %d"
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "'%s' फाइल को बनाने/लिखने के समय विफल हुआ (त्रुटि कोड: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6351,6 +6816,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "'%s' फाइल को बनाने/लिखने के समय विफल हुआ (त्रुटि कोड: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "अज्ञात कमांड: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6367,6 +6945,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "अज्ञात त्रुटि %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "temp histfile के लिए मेमोरी आवंटित नही किया जा सका.\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/it.po'
--- po/it.po	2008-08-14 17:35:53 +0000
+++ po/it.po	2008-08-16 23:49:05 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
-"PO-Revision-Date: 2008-08-13 17:40+0000\n"
-"Last-Translator: vivo <Unknown>\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
+"PO-Revision-Date: 2008-08-16 09:34+0000\n"
+"Last-Translator: Claudio Cherubino <sembee@ngweb.it>\n"
 "Language-Team: Italian <it@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -109,7 +109,7 @@
 
 #: client/drizzle.cc:285 client/drizzle.cc:1437
 msgid "Show warnings after every statement."
-msgstr "Mostra le avvertimenti dopo ogni istruzione."
+msgstr "Mostra gli avvertimenti dopo ogni istruzione."
 
 #: client/drizzle.cc:287
 msgid "Don't show warnings after every statement."
@@ -161,7 +161,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Interrogazione abortita da Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Mostra questo aiuto ed esce."
 
@@ -187,7 +187,7 @@
 "reconnect. WARNING: options deprecated; use --disable-auto-rehash instead."
 msgstr ""
 "Nessun aggiornamento [rehashing] automatico del completamento comandi. "
-"Implica un avvio più rapido di Drizzle e disabilita il rehashing alla ri-"
+"Implica un avvio più rapido di drizzle e disabilita il rehashing alla ri-"
 "connessione. ATTENZIONE: opzione deprecata; usare invece --disable-auto-"
 "rehash."
 
@@ -206,7 +206,7 @@
 "Ignora il file storico dei comandi. Disabilita l'interazione utente. "
 "(Abilita --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "Percorso degli insiemi di caratteri."
 
@@ -238,7 +238,7 @@
 msgid "Database to use."
 msgstr "Database da utilizzare."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Imposta insieme di caratteri."
 
@@ -472,7 +472,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "Scrivi di più. (-v -v -v usa il formato di output tabellare)."
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Restituisce informazioni sulla versione ed esce."
 
@@ -703,10 +703,10 @@
 #, c-format
 msgid "Query OK, %ld row affected"
 msgid_plural "Query OK, %ld rows affected"
-msgstr[0] "Interrogazione OK, %ld riga afflitta"
-msgstr[1] "Interrogazione OK, %ld righe afflitte"
+msgstr[0] "Interrogazione OK, %ld riga affetta"
+msgstr[1] "Interrogazione OK, %ld righe affette"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -826,16 +826,293 @@
 "  ping         Controlla che il server risponda\n"
 "  shutdown     Chiude il server\n"
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, fuzzy, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr "La COLLATION '%s' non è valida per il CHARACTER SET '%s'"
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Errore sconosciuto"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "Impossibile creare socket IP"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Impossibile connettersi al server\n"
+
+#: libdrizzle/errmsg.c:33
+#, fuzzy, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr "Impossibile creare socket IP"
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "Tabella sconosciuta: '%-.100s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, fuzzy, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr "Impossibile inizializzare la funzione '%-.192s'; %-.80s"
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+#, fuzzy
+msgid "Error connecting to master:"
+msgstr "Errore di rete durante il trasferimento al master"
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Errore sconosciuto"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+#, fuzzy
+msgid "Invalid use of null pointer"
+msgstr "Uso non valido di valori NULL"
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Codice di errore invalido"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"connessione al server '%s' fallita\n"
+"errore: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"connessione al server '%s' fallita\n"
+"errore: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"connessione al server '%s' fallita\n"
+"errore: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"connessione al server '%s' fallita\n"
+"errore: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"connessione al server '%s' fallita\n"
+"errore: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "File '%s' non trovato (Errcode: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Errore di lettura dal file '%s' (Errcode: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "Impossibile creare/scrivere sul file '%s' (Errcode: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "Errore di lettura dal file '%s' (Errcode: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -976,11 +1253,6 @@
 "L'ordinamento [collation] '%s' non 'e stato compilato e non è specificato "
 "nel file '%s'"
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "File '%s' non trovato (Errcode: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1318,70 +1590,82 @@
 msgid "Tablespace not empty"
 msgstr "Tablespace non vuoto"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
-msgstr ""
+msgstr "Ricevuto errore %d da pthread_cond_timedwait"
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
-msgstr ""
+msgstr "Impossibile creare thread per terminare il server"
 
 #: drizzled/drizzled.cc:758
 #, c-format
 msgid "Got signal %d from thread %ld"
-msgstr ""
+msgstr "Ricevuto segnale %d dal thread %ld"
 
 #: drizzled/drizzled.cc:792
 msgid "Aborting\n"
-msgstr ""
+msgstr "Abortisco\n"
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
+"È possibile utilizzare l'opzione --user solo se si esegue il programma come "
+"root\n"
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
+"Errore fatale: Si prega di leggere la sezione \"Security\" del manuale per "
+"scoprire come eseguire drizzled da root!\n"
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
+"Errore fatale: Impossibile acquisire i privilegi dell'utente '%s'; Si prega "
+"di controllare che l'utente esista!\n"
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
-msgstr ""
+msgstr "Riprovo a impegnare la porta TCP/IP %u"
+
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr "Impossibile avviare il server: Impegnare  porta TCPI/IP"
 
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
-msgstr ""
+msgstr "C'è già un server in esecuzione sulla porta: %d?"
+
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr "Impossibile avviare il server: listen() su porta TCP/IP"
 
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
-msgstr ""
+msgstr "listen() su TCP/IP fallito con errore %d"
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1392,7 +1676,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1402,7 +1686,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1410,14 +1694,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1429,7 +1713,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1440,7 +1724,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1452,182 +1736,209 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Sto scrivendo il file storico dei comandi %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
+"setrlimit non può cambiare la dimensione dei file core ad 'infinito'; "
+"Potremmo non essere in grado di generare file core in seguito a segnali"
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
-msgstr ""
+msgstr "Impossibile creare interrupt-thread (error %d, errno: %d)"
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
-msgstr ""
+msgstr "Ricevuto segnale %d per fermare drizzled"
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
-msgstr ""
+msgstr "Ricevuto segnale %d errore: %d"
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
-msgstr ""
+msgstr "gethostname() fallito, utilizzo '%s' come hostname"
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
+"Limiti modificati: max_open_files: %u max_connections: %ld table_cache: %ld"
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
+"Impossibile incrementare il valore max_open_files  superiore a %u (richiesto "
+"%u)"
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
-msgstr ""
+msgstr "'locale' sconosciuta: '%s'"
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
+"Seppur sia stato specificato un percorso per l'opzione --log, viene "
+"utilizzato il log su tabelle. Per abilitare la registrazione su file "
+"utilizzare l'opzione --log-output"
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
+"Seppur sia stato specificato un percorso per l'opzione --log-slow-queries "
+"verranno usate tabelle per i log. Per abilitare i registri su file "
+"otilizzare l'opzione --log-output=file."
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
-msgstr ""
+msgstr "Impossibile creare i thread per le chiavi"
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
-msgstr ""
+msgstr "Memoria esaurita"
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
-msgstr ""
+msgstr "E' necessario utilizzare --log-bin per poter usare --binlog-format."
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
+"Usare --replicate-same-server-id contemporaneamente a --log-slave-updates è "
+"impossibile, porterebbe a ricorsione infinita nel server."
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
 "replication may break when this Drizzle server acts as a master and has his "
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
+"Nessun argomento fornito a --log-bin, e --log-bin-index non è stato usato; "
+"in questo modo la replicazione può rompersi nel caso in cui server Drizzle "
+"agisca come master e il suo hostname dovesse cambiare!! Utilizzare '--log-"
+"bin=%s' per evitare il problema."
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
-msgstr ""
+msgstr "Impossibile inizializzare i plugin."
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
-msgstr ""
+msgstr "Impossibile inizializzare i database"
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
-msgstr ""
+msgstr "Tipo di tabella %s sconosciuto / non supportato"
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
-msgstr ""
+msgstr "Motore di memorizzazione di default (%s) non disponibile"
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
-msgstr ""
+msgstr "Impossibile inizializzare tc_log"
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
-msgstr ""
+msgstr "Fallimento nel lock della memoria. Errore numero: %d\n"
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
-msgstr ""
+msgstr "Richiesto %u stack per i thread, ma ho ottenuto %llu"
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
+"Hai abilitato i registri binari [binary log], ma non hai impostato la "
+"variabile server-id a un valore non zero: Forziamo il server id a 1; le "
+"modifiche verranno registrate nel binary log, ma le connessioni verranno "
+"rifiutate agli slave."
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
-msgstr ""
+msgstr "Prima di Lock_thread_count"
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
-msgstr ""
+msgstr "Dopo Lock_thread_count"
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
-msgstr ""
+msgstr "Drizzled: Ricevuto errore %d da select"
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
+"Opzione utilizzata da drizzle-test per il debugging e il test della "
+"replicazione."
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
-msgstr ""
+msgstr "Le colonne ad Incremento automatico sono incrementate di"
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
+"Intervallo aggiunto per le colonne ad Incremento automatico. Utilizzato "
+"quando auto-increment-increment != 1"
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
+"Percorso della directory di installazione. Tutti i percorsi sono "
+"generalmente risolti in relativamente a questo."
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
-msgstr ""
+msgstr "IP address da utilizzare."
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1637,152 +1948,184 @@
 "the UUID() function; for those, row-based binary logging is automatically "
 "used. "
 msgstr ""
+"Non ha alcun effetto senza '--log-bin'. Imposta la forma del registro "
+"binario da utilizzare sul master, uno di: 'row' per la registrazione binaria "
+"delle righe, 'statement' per la registrazione delle istruzioni, o 'mixed'. "
+"'mixed' è una registrazione basata sulle istruzioni [statement] eccetto per "
+"quei casi dove solo la registrazione della riga sia corretta: Quelle che "
+"includono funzioni definite dall'utente (es. UDF) o la funzionie UUID(); per "
+"queste viene automaticamente utilizzata la registrazione della riga. "
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
+"Dice al master che dovrebbe registrare le modifiche per il database "
+"specificato, esclude tutti gli altri non menzionati specificamente."
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
+"Dice al master che non dovrebbe registrare le modifiche sul log binario per "
+"il database specificato."
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
+"La dimensione massima in byte per un evento nei registri binari. Le righe "
+"verrano raggruppate in eventi di dimensione minore se possibile. Il valore "
+"deve essere multiplo di 256."
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
+"Non ignorare l'insieme dei caratteri del client spedito durante "
+"l'inizializzazione [handshake]."
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
-msgstr ""
+msgstr "Imposta l'insieme dei caratteri del filesystem."
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
+"Rinchiude il demone drizzled in un chroot (cambio della directory radice) "
+"durante l'avvio."
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
-msgstr ""
+msgstr "Imposta l'ordinamento [collation] predefinito"
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
-msgstr ""
+msgstr "Tipo di completamento automatico predefinito."
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
-msgstr ""
+msgstr "Mostra descrizione dell'errore sullo schermo"
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
-msgstr ""
+msgstr "Scrivi file di core se incontra errori"
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
-msgstr ""
+msgstr "Path della root del database"
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
+"Imposta l'insieme di caratteri predefinito (opzione deprecata, usare --"
+"character-set-server invece)."
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
+"Imposta l'ordinamento [collation] predefinito (opzione deprecata, usare --"
+"collation-server invece)."
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
+"Imposta il motore di memorizzazione predefinito (tipo tabella) per le tabelle"
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
-msgstr ""
+msgstr "Imposta il fuso orario di default."
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
-msgstr ""
+msgstr "Tipo di DELAY_KEY_WRITE."
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
+"Non svuotare i buffer delle chiavi tra le scritture per ogni tabella MyISAM "
+"(opzione deprecata, usare --delay-key-write=all invece)."
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
+"Stampa una traccia della pila di istruzioni [stack trace] su fallimento."
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
+"Invia le condizioni supportate dal motore di memorizzazione per le "
+"interrogazioni."
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
-msgstr ""
+msgstr "Usato per fase di debug; Usare a proprio rischio!"
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
-msgstr ""
+msgstr "Sincronizza le tabelle al disco tra i comandi SQL."
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
-msgstr ""
+msgstr "Imposta segnali utilizzabili per il debug"
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
-msgstr ""
+msgstr "Abilita il registro generale delle interrogazioni"
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
-msgstr ""
+msgstr "Comando(i) da eseguire per ogni nuova connessione"
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
-msgstr ""
+msgstr "Leggi i comandi SQL da questo file allo startup"
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
-msgstr ""
+msgstr "Comando(i) da eseguire quando uno slave si connette al proprio master"
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
-msgstr ""
+msgstr "(IGNORATO)"
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
+"Imposta la lingua usata per i nomi dei mese e dei giorni della settimana"
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
-msgstr ""
+msgstr "Abilita/disabilita LOAD DATA LOCAL INFILE (valori ammissibili 1|0)"
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
-msgstr ""
+msgstr "Scrivi log delle connessioni e delle query su file."
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
+"Registra le operazioni di modifica in formato binario. Argomento opzionale è "
+"la locazione dei registri binari. (Fortemente raccomandato per evitare "
+"problemi di replicazione se l'hostname del server dovesse cambiare)"
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
-msgstr ""
+msgstr "File contenente i nomi per i file degli ultimi registri binari."
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1791,142 +2134,188 @@
 "binary logging, the security issues do not exist and the binary logging "
 "cannot break, so you can safely set this to 1."
 msgstr ""
+"Se uguale a 0 (predefinito=, allora quando --log-bin viene utilizzato, la "
+"creazione di stored function (o trigger) è permessa solo ad utenti che "
+"abbiano il privilegio SUPER e solo se la stored function (o trigger) non può "
+"interrompere la registrazione binaria. Nota che TUTTE le connessioni a "
+"questo server utilizzano SEMPRE la registrazione binaria row-based, le falle "
+"di sicurezza non esistono e la registrazione binaria non può interrompersi, "
+"quindi è ottimale impostare questo valore a 1."
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
-msgstr ""
+msgstr "Errore in scrittura sul file di log."
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
-msgstr ""
+msgstr "Scrivi su file di log tutte le modifiche a MyISAM"
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
+"Registra alcune informazioni addizionali sul registro delle modifiche. Prego "
+"prenda nota che quest'opzione è deprecata; vedere l'opzione --log-queries-"
+"not-using-indexes."
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
+"Sintassi: log-output[=valore[,valore...]], dove \"valore\" può essere TABLE, "
+"FILE o NONE."
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
+#, fuzzy
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
+"Registra le interrogazioni che siano eseguite senza il beneficio di alcun "
+"indice sullo 'slow log' se è aperto."
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
+#, fuzzy
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
+"Non registrare informazioni addizionali sul registro delle modifiche e sullo "
+"'slow log'"
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
+"Dice allo slave di registrare le modifiche dallo slave thread ai registri "
+"binari. Necessario per poter utilizzare più slave in cascata."
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
+#, fuzzy
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
+"Registra OPTIMIZE, ANALYZE, ALTER e altre istruzioni lente sullo 'slow log' "
+"se aperto."
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
+#, fuzzy
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
+"Registra istruzioni lente eseguite dallo slave thread sullo 'slow log' se "
+"aperto."
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
+"Registra le interrogazioni lente su tabella o file. Da impostazione "
+"predefinita registra sulla tabella drizzle.slow_log o hostname-slow.log se --"
+"log-output=file viene usato. Deve essere abilitato per attivare ulteriori "
+"opzioni riguardanti lo 'slow log'."
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
+"Percorso del registro di coordinamento delle transazioni (usato per le "
+"transazioni che interessano più di un motore di memorizzazione, quando il "
+"registro binario è disattivato)"
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
-msgstr ""
+msgstr "Dimensione del registro di coordinamento delle transazioni."
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
-msgstr ""
+msgstr "Registra alcuni avvertimenti non critici sul file registro."
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
-msgstr ""
+msgstr "INSERT/DELETE/UPDATE hanno minore priorità delle selezioni"
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
+"La locazione e il nome del file che ricorda al master quando e dove sia il "
+"thread I/O di replicazione sui registri binari del master."
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
+"Il numero di tentativi che lo slave farà per connettersi al master prima di "
+"lasciar perdere."
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
-msgstr ""
+msgstr "Blocca drizzled in memoria."
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
+"Sintassi: myisam-recover[=opzione[,opzione...]], dove opzione può essere "
+"DEFAULT, BACKUP, FORCE o QUICK."
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
-msgstr ""
+msgstr "Utilizzare funzioni nuovissime possibilmente 'insecure'"
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
-msgstr ""
+msgstr "Utilizza il vecchio, non ottimizzato ALTER TABLE."
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
+"Abilita i limiti utente vecchio stile (prima del 5.0.3 le risorse utente "
+"erano calcolate per utente+host piuttosto ch per utente)"
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
-msgstr ""
+msgstr "File pid (id processo) utilizzato da safe_drizzled."
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
+"Massimo tempo di attesa perchè la porta si liberi. (Default: nessuna attesa)"
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
-msgstr ""
+msgstr "Il percorso e il nome da utilizzare per i relay log."
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
+"Il percorso e il nome da utilizzare per il file che memorizza la lista degli "
+"ultimi relay log."
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
+"Il percorso e il nome da utilizzare per il file che memorizza la posizione "
+"del thread SQL di replicazione nei relay log."
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1935,16 +2324,27 @@
 "having selected a different or no database. If you need cross database "
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
+"Informa lo slave thread di restringere la replicazione al database "
+"specificato. Per specificare più di un database, utilizzare la direttiva più "
+"volte, una volta per ogni database. Nota che questo funziona solo se non si "
+"utilizza interrogazioni multi-database come ad esempio UPDATE un_db."
+"una_tabella SET tizio='caio' pur avendo selezionato un diverso o nessun "
+"database. Se hai bisogno di modifiche multi-database, utilizza replicate-"
+"wild-do-table=db_name.%."
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
 "table. This will work for cross-database updates, in contrast to replicate-"
 "do-db."
 msgstr ""
+"Informa lo slave thread di restringere la replicazione alla specifica "
+"tabella. Per specificare più di una  tabella, utilizzare la direttiva più "
+"volte, una volta per ogni tabella. Funzionerà anche per aggiornamenti su "
+"database multipli, in contrasto con replicate-do-db."
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1952,29 +2352,44 @@
 "updates. If you need cross database updates to work, use replicate-wild-"
 "ignore-table=db_name.%. "
 msgstr ""
+"Informa lo slave thread di non replicare il database specificato. Per "
+"specificare più di un database da ignorare, utilizzare la direttiva più "
+"volte, una volta per ogni database. Questa opzione non funzionerà se si "
+"utilizza aggiornamenti su database multipli. Se hai bisogno di modifiche "
+"multi-database, utilizza replicate-wild-ignore-table=db_name.% "
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
 "each table. This will work for cross-datbase updates, in contrast to "
 "replicate-ignore-db."
 msgstr ""
+"Informa lo slave thread di non replicare la specifica tabella. Per "
+"specificare più di una  tabella da ignorare, utilizzare la direttiva più "
+"volte, una volta per ogni tabella. Funzionerà anche per aggiornamenti su "
+"database multipli, in contrasto con replicate-ignore-db."
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
+"Aggiorna su un database con un nome differente dall'originale. Esempio: "
+"replicate-rewrite-db=nome_db_master->nome_db_slave."
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
+"In replicazione, se impostato a 1, non scartare eventi che abbiano il nostro "
+"server id. Valore predefinito 0 (per interrompere cicli infiniti nella "
+"replicazione circolare). Può essere impostato a 1 se --log-slave-updates è "
+"utilizzato."
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1983,8 +2398,15 @@
 "only updates to tables in all databases that start with foo and whose table "
 "names start with bar."
 msgstr ""
+"Informa lo slave thread di restringere la replicazione alle tabelle "
+"specificate dalla identificazione con caratteri jolly. È possibile "
+"utilizzare la direttiva più volte, una volta per ogni identificazione. "
+"Funzionerà anche per interrogazioni multi-database. Esempio: replicate-wild-"
+"do-table=tizio%.caio% replicherà solo modifiche a tabelle in tutti i "
+"database che inizino per tizio e le cui tabelle abbiano nome che inizia per "
+"caio."
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1993,8 +2415,14 @@
 "updates to tables in databases that start with foo and whose table names "
 "start with bar."
 msgstr ""
+"Informa lo slave thread di non replicare le tabelle specificate dalla "
+"identificazione con caratteri jolly. È possibile utilizzare la direttiva più "
+"volte, una volta per ogni identificazione. Funzionerà anche per "
+"interrogazioni multi-database. Esempio: replicate-wild-ignore-table=tizio%."
+"caio% non replicherà le modifiche a tabelle in tutti i database che inizino "
+"per tizio e le cui tabelle abbiano nome che inizia per caio."
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -2003,8 +2431,14 @@
 "socket once the slave connects. Due to NAT and other routing issues, that IP "
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
+"Hostname o IP dello slave da riportare al master durante la registrazione "
+"dello slave. Apparirà nell'output di SHOW SLAVE HOSTS. Lasciare vuoto se non "
+"si vuole che lo slave si registri con il master. Nota che non è sufficiente "
+"per il master leggere semplicemente l'IP dello slave dal socket una volta "
+"connesso. Per via delle NAT e altri problemi di routing, quell'IP può non "
+"essere valido per connettersi allo slave dal master o da altri host."
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -2012,63 +2446,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2076,139 +2510,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
-msgstr ""
+msgstr "Abilita supporto link simbolici"
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
-msgstr ""
+msgstr "Avvia il daemon mysqld come utente"
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2216,163 +2650,164 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
-msgstr ""
+msgstr "Il numero di client simultanei consentiti."
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
+"Non consentire la creazione di tabelle heap più grandi di questo valore."
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "Opzioni di creazione errate"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Buffer per le comunicazioni TCP/IP e socket."
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2380,7 +2815,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2388,7 +2823,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2399,163 +2834,168 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
+#, fuzzy
 msgid "Maximum space to use for all relay logs."
-msgstr ""
+msgstr "Il percorso e il nome da utilizzare per i relay log."
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Utilizza la compressione nel protocollo server/client."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "ATTENZIONE: opzione deprecata; utilizzare --disable-pager invece.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
+#, fuzzy
 msgid "The number of cached open tables."
-msgstr ""
+msgstr "Il numero di client simultanei consentiti."
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
+#, fuzzy
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
+"Il numero di tentativi che lo slave farà per connettersi al master prima di "
+"lasciar perdere."
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2564,76 +3004,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
-msgstr ""
+msgstr "Uso: %s [OPZIONI]\n"
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -2856,9 +3296,8 @@
 msgstr "Non posso recuperare l' hostname per il tuo indirizzo IP"
 
 #: drizzled/drizzled_error_messages.h:118
-#, fuzzy
 msgid "Bad handshake"
-msgstr "Inizializzazione fallita [handshake]"
+msgstr "Inizializzazione [handshake] fallita"
 
 #: drizzled/drizzled_error_messages.h:120
 #, c-format
@@ -3286,12 +3725,12 @@
 #: drizzled/drizzled_error_messages.h:276
 #, c-format
 msgid "Can't load function '%-.192s'"
-msgstr ""
+msgstr "Impossibile caricare la funzione '%-.192s'"
 
 #: drizzled/drizzled_error_messages.h:278
 #, c-format
 msgid "Can't initialize function '%-.192s'; %-.80s"
-msgstr ""
+msgstr "Impossibile inizializzare la funzione '%-.192s'; %-.80s"
 
 #: drizzled/drizzled_error_messages.h:280
 msgid "No paths allowed for shared library"
@@ -3453,19 +3892,19 @@
 
 #: drizzled/drizzled_error_messages.h:340
 msgid "Got a read error from the connection pipe"
-msgstr ""
+msgstr "Ricevuto un errore di lettura dalla pipe di connessione"
 
 #: drizzled/drizzled_error_messages.h:342
 msgid "Got an error from fcntl()"
-msgstr ""
+msgstr "Ricevuto un errore da fcntl()"
 
 #: drizzled/drizzled_error_messages.h:344
 msgid "Got packets out of order"
-msgstr ""
+msgstr "Ricevuti pacchetti fuori ordine"
 
 #: drizzled/drizzled_error_messages.h:346
 msgid "Couldn't uncompress communication packet"
-msgstr ""
+msgstr "Impossibile decomprimere pacchetto di comunicazione"
 
 #: drizzled/drizzled_error_messages.h:348
 msgid "Got an error reading communication packets"
@@ -3675,7 +4114,7 @@
 
 #: drizzled/drizzled_error_messages.h:432
 msgid "The server is not configured as slave; fix with CHANGE MASTER TO"
-msgstr ""
+msgstr "Il server non è configurato come slave; risolvere con CHANGE MASTER TO"
 
 #: drizzled/drizzled_error_messages.h:434
 msgid ""
@@ -3696,7 +4135,7 @@
 
 #: drizzled/drizzled_error_messages.h:440
 msgid "You may only use constant expressions with SET"
-msgstr ""
+msgstr "Si possono usare solo espressioni costanti con SET"
 
 #: drizzled/drizzled_error_messages.h:442
 msgid "Lock wait timeout exceeded; try restarting transaction"
@@ -3801,6 +4240,7 @@
 #, c-format
 msgid "Access denied; you need the %-.128s privilege for this operation"
 msgstr ""
+"Accesso negato; per questa operazione è richiesto il privilegio %-.128s"
 
 #: drizzled/drizzled_error_messages.h:488
 #, c-format
@@ -3871,7 +4311,7 @@
 #: drizzled/drizzled_error_messages.h:514
 #, c-format
 msgid "Operand should contain %d column(s)"
-msgstr ""
+msgstr "L'operando deve contenere %d colonna(e)"
 
 #: drizzled/drizzled_error_messages.h:516
 msgid "Subquery returns more than 1 row"
@@ -3888,7 +4328,7 @@
 
 #: drizzled/drizzled_error_messages.h:522
 msgid "Cyclic reference on subqueries"
-msgstr ""
+msgstr "Riferimento ciclico nelle subquery"
 
 #: drizzled/drizzled_error_messages.h:524
 #, c-format
@@ -3922,20 +4362,20 @@
 
 #: drizzled/drizzled_error_messages.h:536
 msgid "All parts of a SPATIAL index must be NOT NULL"
-msgstr ""
+msgstr "Tutte le parti di un indice SPATIAL devono essere NOT NULL"
 
 #: drizzled/drizzled_error_messages.h:538
 #, c-format
 msgid "COLLATION '%s' is not valid for CHARACTER SET '%s'"
-msgstr ""
+msgstr "La COLLATION '%s' non è valida per il CHARACTER SET '%s'"
 
 #: drizzled/drizzled_error_messages.h:540
 msgid "Slave is already running"
-msgstr ""
+msgstr "Lo slave è già in esecuzione"
 
 #: drizzled/drizzled_error_messages.h:542
 msgid "Slave already has been stopped"
-msgstr ""
+msgstr "Lo slave è già stato arrestato"
 
 #: drizzled/drizzled_error_messages.h:544
 #, c-format
@@ -3946,7 +4386,7 @@
 
 #: drizzled/drizzled_error_messages.h:546
 msgid "ZLIB: Not enough memory"
-msgstr ""
+msgstr "ZLIB: Memoria insufficiente"
 
 #: drizzled/drizzled_error_messages.h:548
 msgid ""
@@ -3956,7 +4396,7 @@
 
 #: drizzled/drizzled_error_messages.h:550
 msgid "ZLIB: Input data corrupted"
-msgstr ""
+msgstr "ZLIB: Dati input corrotti"
 
 #: drizzled/drizzled_error_messages.h:552
 #, c-format
@@ -4128,6 +4568,8 @@
 "The MySQL server is running with the %s option so it cannot execute this "
 "statement"
 msgstr ""
+"Il server MySQL è in esceuzione con l'opzione %s quindi non può eseguire il "
+"comando"
 
 #: drizzled/drizzled_error_messages.h:614
 #, c-format
@@ -4197,7 +4639,7 @@
 #: drizzled/drizzled_error_messages.h:640
 #, c-format
 msgid "%s %s already exists"
-msgstr ""
+msgstr "%s %s è già esistente"
 
 #: drizzled/drizzled_error_messages.h:642
 #, c-format
@@ -4299,7 +4741,7 @@
 
 #: drizzled/drizzled_error_messages.h:682
 msgid "Cursor is already open"
-msgstr ""
+msgstr "Il cursore è già aperto"
 
 #: drizzled/drizzled_error_messages.h:684
 msgid "Cursor is not open"
@@ -5478,11 +5920,11 @@
 
 #: drizzled/drizzled_error_messages.h:1160
 msgid "This partition function is not allowed"
-msgstr ""
+msgstr "Questa funzione di partizione non è consentita"
 
 #: drizzled/drizzled_error_messages.h:1162
 msgid "Error in DDL log"
-msgstr ""
+msgstr "Errore nel log DDL"
 
 #: drizzled/drizzled_error_messages.h:1164
 msgid "Not allowed to use NULL value in VALUES LESS THAN"
@@ -5735,7 +6177,7 @@
 
 #: drizzled/drizzled_error_messages.h:1268
 msgid "Backup completed"
-msgstr ""
+msgstr "Backup completato"
 
 #: drizzled/drizzled_error_messages.h:1270
 msgid "Starting restore process"
@@ -5743,7 +6185,7 @@
 
 #: drizzled/drizzled_error_messages.h:1272
 msgid "Restore completed"
-msgstr ""
+msgstr "Ripristino completato"
 
 #: drizzled/drizzled_error_messages.h:1274
 msgid "Nothing to backup"
@@ -5822,7 +6264,7 @@
 #: drizzled/drizzled_error_messages.h:1304
 #, c-format
 msgid "Can't open table %-.64s"
-msgstr ""
+msgstr "Impossibile aprire la tabella %-.64s"
 
 #: drizzled/drizzled_error_messages.h:1306
 msgid "Can't read backup archive preamble"
@@ -5871,7 +6313,7 @@
 #: drizzled/drizzled_error_messages.h:1324
 #, c-format
 msgid "Can't create %-.64s"
-msgstr ""
+msgstr "Impossibile creare %-.64s"
 
 #: drizzled/drizzled_error_messages.h:1326
 msgid "Can't allocate buffer for image data transfer"
@@ -6004,6 +6446,163 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "Ricevuto errore %d dal motore di memorizzazione"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+#, fuzzy
+msgid "I/O error reading the header from the binary log"
+msgstr "Errore I/O leggendo il file di indice dei registri"
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+"Fallita l'apertura del il file di informazioni sul master (file '%s', errnum "
+"%d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+#, fuzzy
+msgid "Could not open log file"
+msgstr "Impossibile connettersi al motore di memorizzazione"
+
+#: drizzled/log.cc:1102
+#, fuzzy, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+"Fallita la creazione di una cache per il file di informazioni sul master "
+"(file '%s')"
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, fuzzy, c-format
+msgid "Failed to delete file '%s'"
+msgstr "Fallimento nel creare '%s'"
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, fuzzy, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr "Fallimento nel creare '%s'"
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, fuzzy, c-format
+msgid "Recovering after a crash using %s"
+msgstr "Riconnessione dopo un tentativo fallito di dump dei log binari"
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "Lock del file impossibile (errno: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -6047,12 +6646,12 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr "Slave %s: %s%s Error_code: %d"
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr "Tipo colonna %d incongruente - tipo ricevuto %d, %s.%s ha tipo %d"
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
@@ -6062,6 +6661,43 @@
 "sullo slave ha dimensione %d. La dimensione della colonna sul Master's "
 "dovrebbe essere <= a quella dello slave."
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "Impossibile creare interrupt-thread (error %d, errno: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6579,6 +7215,119 @@
 "versione almeno pari a '%d.%d.%d'. Quindi la replicazione può essere "
 "riavviata."
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, fuzzy, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr "Impossibile aprire la tabella %-.64s"
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "Impossibile creare tabella '%-.200s' (errno: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "Table engine sconosciuto: '%s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Memoria esaurita nel motore di memorizzazione"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6599,6 +7348,39 @@
 "Fallimento della funzione send_file() durante la negoziazione della chiusura "
 "del file"
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "Errore sconosciuto durante la pulizia dei registri"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+"Allocazione di memoria fallita per la struttura di informazioni del master"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/ko.po'
--- po/ko.po	2008-08-14 17:35:53 +0000
+++ po/ko.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 10:22+0000\n"
 "Last-Translator: YoungWoo Kim <Unknown>\n"
 "Language-Team: Korean <ko@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -158,7 +158,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -192,7 +192,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "문자셋이 있는 디렉토리"
 
@@ -222,7 +222,7 @@
 msgid "Database to use."
 msgstr "사용할 데이터베이스"
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "기본 문자셋 설정"
 
@@ -413,7 +413,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -617,7 +617,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -725,16 +725,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -864,11 +1126,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1192,12 +1449,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1210,52 +1473,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1266,7 +1529,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1276,7 +1539,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1284,14 +1547,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1303,7 +1566,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1314,7 +1577,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1326,90 +1589,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1417,91 +1680,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1512,151 +1775,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1666,141 +1929,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1810,7 +2073,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1818,7 +2081,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1827,7 +2090,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1835,20 +2098,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1858,7 +2121,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1868,7 +2131,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1878,7 +2141,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1886,63 +2149,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1950,139 +2213,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2090,161 +2353,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2252,7 +2515,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2260,7 +2523,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2271,162 +2534,162 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "서버/클라이언트 프로토콜에서 압축 사용"
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2435,76 +2698,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5816,6 +6079,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5851,18 +6264,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6283,6 +6733,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6299,6 +6862,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/mr.po'
--- po/mr.po	2008-08-14 17:35:53 +0000
+++ po/mr.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 19:40+0000\n"
 "Last-Translator: Ranjeet Walunj <Unknown>\n"
 "Language-Team: Marathi <mr@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -157,7 +157,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -190,7 +190,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -220,7 +220,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -410,7 +410,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -614,7 +614,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -722,16 +722,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -861,11 +1123,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1189,12 +1446,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1207,52 +1470,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1263,7 +1526,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1273,7 +1536,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1281,14 +1544,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1300,7 +1563,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1311,7 +1574,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1323,90 +1586,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1414,91 +1677,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1509,151 +1772,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1663,141 +1926,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1807,7 +2070,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1815,7 +2078,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1824,7 +2087,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1832,20 +2095,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1855,7 +2118,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1865,7 +2128,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1875,7 +2138,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1883,63 +2146,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1947,139 +2210,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2087,161 +2350,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2249,7 +2512,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2257,7 +2520,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2268,161 +2531,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2431,76 +2694,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5812,6 +6075,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5847,18 +6260,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6279,6 +6729,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6295,6 +6858,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/nb.po'
--- po/nb.po	2008-08-14 17:35:53 +0000
+++ po/nb.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 19:03+0000\n"
 "Last-Translator: matslindh <Unknown>\n"
 "Language-Team: Norwegian Bokmal <nb@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -164,7 +164,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Spørringen ble avbrutt med Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Vis denne hjelpeteksten og avslutt."
 
@@ -206,7 +206,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr "Ikke bruk en historiefil. Skru av interaktivitet. (Skrur på --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "Katalogen hvor tegnsettene ligger"
 
@@ -238,7 +238,7 @@
 msgid "Database to use."
 msgstr "Databasen som skal brukes."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Setter standardtegnsett."
 
@@ -472,7 +472,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "Skriv ut mer. (-v -v -v gir tabellformat på utskriften)"
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Skriv ut versjonsnummeret og avslutt."
 
@@ -706,7 +706,7 @@
 msgstr[0] "Spørring OK, %ld rad påvirket"
 msgstr[1] "Spørring OK, %ld rader påvirket"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 #, fuzzy
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
@@ -824,16 +824,292 @@
 "  ping Sjekk om serveren er nede\n"
 "  shutdown Avslutt serveren\n"
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Ukjent feil %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "Kan ikke lage katalogen '%s' (Feilkode: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Klarte ikke å koble til serveren\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+#, fuzzy
+msgid "Error connecting to master:"
+msgstr "Nettverkslesefeil ved lasting av '%s' fra masteren"
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Ukjent feil %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Ugyldig feilkode"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"tilkobling til serveren på '%s' mislykkes\n"
+"feil: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"tilkobling til serveren på '%s' mislykkes\n"
+"feil: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"tilkobling til serveren på '%s' mislykkes\n"
+"feil: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"tilkobling til serveren på '%s' mislykkes\n"
+"feil: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"tilkobling til serveren på '%s' mislykkes\n"
+"feil: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "Filen '%s' ble ikke funnet (Feilkode: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Lesingen av '%s' mislykkes (Feilkode: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "Kan ikke lage/skrive til filen '%s' (Feilkode: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "Lesingen av '%s' mislykkes (Feilkode: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -968,11 +1244,6 @@
 "Sorteringsrekkefølgen '%s' er ikke en kompilert sorteringsrekkefølge og er "
 "ikke spesifisert i filen %s"
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "Filen '%s' ble ikke funnet (Feilkode: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1310,12 +1581,18 @@
 msgid "Tablespace not empty"
 msgstr "Tabellplassen er ikke tom"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1328,52 +1605,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1384,7 +1661,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1394,7 +1671,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1402,14 +1679,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1421,7 +1698,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1432,7 +1709,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1444,90 +1721,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Skriver historiefilen %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1535,91 +1812,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1630,151 +1907,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1784,141 +2061,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1928,7 +2205,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1936,7 +2213,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1945,7 +2222,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1953,20 +2230,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1976,7 +2253,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1986,7 +2263,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1996,7 +2273,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -2004,63 +2281,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2068,139 +2345,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2208,163 +2485,163 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "Egenskapene for å opprette en ny er feil"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Buffer for TCP/IP og socket-kommunikasjon"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2372,7 +2649,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2380,7 +2657,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2391,163 +2668,163 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Bruk kompresjon i klient/server-protokollen."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "ADVARSEL: egenskapen er utgått; bruk --disable-pager i stedet.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2556,76 +2833,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5977,6 +6254,162 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "Kunne ikke koble til lagringsmotoren"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+#, fuzzy
+msgid "I/O error reading the header from the binary log"
+msgstr "Ikke mer plass i indeksfilen"
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+"Klarte ikke å åpne den eksisterende masterinfofilen (filen '%s', feilnummer %"
+"d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+#, fuzzy
+msgid "Could not open log file"
+msgstr "Kunne ikke koble til lagringsmotoren"
+
+#: drizzled/log.cc:1102
+#, fuzzy, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+"Klarte ikke å lage et hurtiglager (cache) for masterinfofilen (filen '%s')"
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, fuzzy, c-format
+msgid "Failed to delete file '%s'"
+msgstr "Klarte ikke å lage slavetrådene"
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, fuzzy, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr "Klarte ikke å lage slavetrådene"
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, fuzzy, c-format
+msgid "Recovering after a crash using %s"
+msgstr "Kobler til på nytt etter at vi ikke klarte å hente masterdumpen"
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "Kan ikke låse filen (Feilkode: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -6018,14 +6451,14 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr "Slave %s: %s%s Feilkode: %d"
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 "Kolonne %d stemmer ikke overrens med typen. Mottok type %d, %s. %s har typen "
 "%d"
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
@@ -6035,6 +6468,43 @@
 "s.%s på slaven har størrelse %d. Masterens kolonnestørrelse skulle ha vært "
 "mindre eller lik slavens kolonnestørrelse."
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "Kan ikke opprette symlinken '%s' som peker til '%s' (Feilkode: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr "Venter på å koble til masteren på nytt etter at registreringen feilet"
@@ -6540,6 +7010,119 @@
 "sletter binærloggene hos masteren og deretter oppgraderer masteren til en "
 "versjon som minst tilsvarer '%d.%d.%d'. Replikasjonen kan så bli restartet."
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "Kan ikke lage/skrive til filen '%s' (Feilkode: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "Ukjent kommando: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Databasemotoren er tom for minne"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr "Feilet i send_file() da vi leste filnavnet"
@@ -6556,6 +7139,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr "Feilet i send_file() da vi forhandlet om avslutning av filoverføringen"
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "Ukjent feil %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "Klarte ikke å allokere minne for masterinfostrukturen"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/nl.po'
--- po/nl.po	2008-08-14 17:35:53 +0000
+++ po/nl.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 03:19+0000\n"
 "Last-Translator: Monty Taylor <monty@inaugust.com>\n"
 "Language-Team: Dutch <nl@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n != 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -161,7 +161,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Query afgebroken door Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Toon deze hulp en sluit af."
 
@@ -198,7 +198,7 @@
 "Gebruik het geschiedenisbestand niet. Schakel interactief gedrag uit. "
 "(Activeert --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr "Directory waar de karaktersets zich bevinden."
 
@@ -230,7 +230,7 @@
 msgid "Database to use."
 msgstr "Te gebruiken databank"
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Stel de standaard karakterset in."
 
@@ -452,7 +452,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr "Schrijf meer. (-v -v -v geeft het tabel uitvoer formaat)"
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Voer versie informatie uit en sluit af."
 
@@ -686,7 +686,7 @@
 msgstr[0] "Query OK, %ld rij beïnvloed"
 msgstr[1] "Query OK, %ld rijen beïnvloed"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 #, fuzzy
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
@@ -801,16 +801,291 @@
 "  ping Controleer of server uitgeschakeld is\n"
 "  shutdown Schakel de server uit\n"
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "Onbekende fout %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "Kan directory '%s' niet creëren (Foutcode: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "Kan niet verbinden met de server\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "Onbekende opdracht: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+#, fuzzy
+msgid "Error connecting to master:"
+msgstr "Fout bij lezen van de master configuratie"
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "Onbekende fout %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"verbinding met server op '%s' is mislukt\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"verbinding met server op '%s' is mislukt\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"verbinding met server op '%s' is mislukt\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"verbinding met server op '%s' is mislukt\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"verbinding met server op '%s' is mislukt\n"
+"error: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "Bestand '%s' niet gevonden (Foutcode: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "Fout bij lezen van bestand '%s' (Foutcode: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr "Kan bestand '%s' niet aanmaken/wijzigen (Foutcode: %d)"
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "Fout bij lezen van bestand '%s' (Foutcode: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -949,11 +1224,6 @@
 "Collation '%s' is geen gecompileerde collation en werd niet gespecifieerd in "
 "het bestand %s"
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "Bestand '%s' niet gevonden (Foutcode: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1291,12 +1561,18 @@
 msgid "Tablespace not empty"
 msgstr "Tablespace is niet leeg"
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1309,52 +1585,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1365,7 +1641,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1375,7 +1651,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1383,14 +1659,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1402,7 +1678,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1413,7 +1689,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1425,90 +1701,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Schrijft geschiedenisbestand %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1516,91 +1792,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1611,151 +1887,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1765,141 +2041,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1909,7 +2185,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1917,7 +2193,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1926,7 +2202,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1934,20 +2210,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1957,7 +2233,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1967,7 +2243,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1977,7 +2253,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1985,63 +2261,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -2049,139 +2325,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2189,163 +2465,163 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 #, fuzzy
 msgid "(Deprecated option)"
 msgstr "Foutieve creatie opties"
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 #, fuzzy
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr "Buffer voor TCP/IP en socket communicatie"
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2353,7 +2629,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2361,7 +2637,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2372,163 +2648,163 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Gebruik compressie in het server/client protocol."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 #, fuzzy
 msgid "Deprecated; use --table_open_cache instead."
 msgstr "WAARSCHUWING: deze optie wordt afgeraden; gebruik --disable-pager.\n"
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2537,76 +2813,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5945,6 +6221,161 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "Kon niet verbinden met storage engine"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+#, fuzzy
+msgid "I/O error reading the header from the binary log"
+msgstr "Geen plaats meer in het index bestand"
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+"Openen van een  bestaand master info bestand mislukt (bestand '%s', "
+"foutnummer %d')"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+#, fuzzy
+msgid "Could not open log file"
+msgstr "Kon niet verbinden met storage engine"
+
+#: drizzled/log.cc:1102
+#, fuzzy, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr "Creatie van een  cache op master info bestand mislukt (bestand '%s')"
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, fuzzy, c-format
+msgid "Failed to delete file '%s'"
+msgstr "Leegmaken van het master info bestand is mislukt"
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, fuzzy, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr "Creatie van een  cache op master info bestand mislukt (bestand '%s')"
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "Kan bestand niet vergrendelen (Foutcode: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5984,12 +6415,12 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr "Slave %s: %s%s Foutcode: %d"
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr "Kolom %d type afwijking - ontvangen type %d, %s.%s heeft type %d"
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
@@ -5998,6 +6429,43 @@
 "Kolom %d grootte afwijking - master heeft grootte %d, %s.%s onp de slave "
 "heedt grootte %d. Master kolomgrootte zou <= slave's kolomgrootte."
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "Kan symlink '%s' verwijzend naar '%s' niet creëren (Fout %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6419,6 +6887,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "Kan bestand '%s' niet aanmaken/wijzigen (Foutcode: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "Onbekende opdracht: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, fuzzy, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr "Geheugen tekort in engine"
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6435,6 +7016,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "Onbekende fout %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "Kon geen geheugen toewijzen voor tijdelijk geschiedenisbestand !\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/pt_BR.po'
--- po/pt_BR.po	2008-08-14 17:35:53 +0000
+++ po/pt_BR.po	2008-08-16 23:49:05 +0000
@@ -7,15 +7,15 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
-"PO-Revision-Date: 2008-08-13 23:05+0000\n"
-"Last-Translator: Alexandre Sapata Carbonell <alexandrenescau@gmail.com>\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
+"PO-Revision-Date: 2008-08-16 16:41+0000\n"
+"Last-Translator: Augusto Bott <Unknown>\n"
 "Language-Team: Brazilian Portuguese <pt_BR@li.org>\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=2; plural=n > 1;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -29,13 +29,13 @@
 #: client/drizzle.cc:259
 msgid "Reconnect to the server. Optional arguments are db and host."
 msgstr ""
-"Reconecte ao servidor. Argumentos opcionais são banco de dados e servidor."
+"Reconecta ao servidor. Argumentos opcionais são banco de dados e servidor."
 
 #: client/drizzle.cc:261
 msgid ""
 "Set statement delimiter. NOTE: Takes the rest of the line as new delimiter."
 msgstr ""
-"Troca o delimitador de comandos. NOTA: Toma o rest da linha como o novo "
+"Troca o delimitador de comandos. NOTA: Toma o resto da linha como o novo "
 "delimitador"
 
 #: client/drizzle.cc:263
@@ -61,17 +61,19 @@
 "(stdout)."
 
 #: client/drizzle.cc:268
-#, fuzzy
 msgid "Don't write into outfile."
-msgstr "Não escreva no arquivo de saída"
+msgstr "Não escreve em um arquivo de saída."
 
 #: client/drizzle.cc:270
+#, fuzzy
 msgid "Set PAGER [to_pager]. Print the query results via PAGER."
 msgstr ""
+"Muda o PAGINADOR [nome_do_paginador]. Mostra os resultados das consultas "
+"através PAGINADOR."
 
 #: client/drizzle.cc:271
 msgid "Print current command."
-msgstr "Imprimir comando atual."
+msgstr "Exibe o comando atual."
 
 #: client/drizzle.cc:272
 msgid "Change your drizzle prompt."
@@ -82,8 +84,9 @@
 msgstr "Sair do drizzle."
 
 #: client/drizzle.cc:274
+#, fuzzy
 msgid "Rebuild completion hash."
-msgstr ""
+msgstr "Reconstrói o índice de auto-completar"
 
 #: client/drizzle.cc:276
 msgid "Execute an SQL script file. Takes a file name as an argument."
@@ -92,11 +95,13 @@
 
 #: client/drizzle.cc:277
 msgid "Get status information from the server."
-msgstr "Exibe informações sobre o estado do servidor."
+msgstr "Exibe informações sobre o estado atual do servidor."
 
 #: client/drizzle.cc:279
 msgid "Set outfile [to_outfile]. Append everything into given outfile."
 msgstr ""
+"Seleciona um arquivo de saída [nome_de_arquivo]. Manda todas as saídas para "
+"o nome_de_arquivo indicado."
 
 #: client/drizzle.cc:281
 msgid "Use another database. Takes database name as argument."
@@ -109,18 +114,22 @@
 "Switch to another charset. Might be needed for processing binlog with multi-"
 "byte charsets."
 msgstr ""
+"Troca para outro charset. Pode ser necessário para processar binlog com "
+"charsets de múltiplos bytes."
 
 #: client/drizzle.cc:285 client/drizzle.cc:1437
 msgid "Show warnings after every statement."
-msgstr ""
+msgstr "Mostra avisos após cada comando."
 
 #: client/drizzle.cc:287
 msgid "Don't show warnings after every statement."
-msgstr ""
+msgstr "Não mostra avisos após cada comando."
 
 #: client/drizzle.cc:1120
+#, fuzzy
 msgid "Welcome to the Drizzle client..  Commands end with ; or \\g."
-msgstr "Bem-vindo ao cliente Drizzle.. Comandos acabam com ; ou \\g"
+msgstr ""
+"Bem-vindo ao cliente Drizzle.. Comandos devem ser terminados com ; ou \\g"
 
 #: client/drizzle.cc:1130
 #, c-format
@@ -128,27 +137,29 @@
 "Your Drizzle connection id is %u\n"
 "Server version: %s\n"
 msgstr ""
-"Sua conexão de ID Drizzle é %u\n"
+"O ID de sua conexão no Drizzle é %u\n"
 "Versão do servidor: %s\n"
 
 #: client/drizzle.cc:1160
 #, c-format
 msgid "Reading history-file %s\n"
-msgstr "Lendo arquivo de história %s\n"
+msgstr "Lendo arquivo de histórico %s\n"
 
 #: client/drizzle.cc:1165
 #, c-format
 msgid "Couldn't allocate memory for temp histfile!\n"
 msgstr ""
+"Não foi possível alocar memória para arquivo de histórico temporário.\n"
 
 #: client/drizzle.cc:1172
 msgid "Type 'help;' or '\\h' for help. Type '\\c' to clear the buffer.\n"
 msgstr ""
+"Digite 'help:' ou '\\h' para ajuda. DIgite '\\c' para limpar o buffer.\n"
 
 #: client/drizzle.cc:1190
 #, c-format
 msgid "Writing history-file %s\n"
-msgstr "Escrevendo arquivo de história %s\n"
+msgstr "Escrevendo arquivo de histórico %s\n"
 
 #: client/drizzle.cc:1199
 msgid "Aborted"
@@ -156,15 +167,15 @@
 
 #: client/drizzle.cc:1199
 msgid "Bye"
-msgstr "Tchau"
+msgstr "Adeus"
 
 #: client/drizzle.cc:1248
 msgid "Query aborted by Ctrl+C\n"
-msgstr ""
+msgstr "Query abortada por Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
-msgstr ""
+msgstr "Mostra este texto de ajuda e sai."
 
 #: client/drizzle.cc:1273
 msgid "Synonym for -?"
@@ -189,25 +200,31 @@
 "Automatically switch to vertical output mode if the result is wider than the "
 "terminal width."
 msgstr ""
+"Muda automaticamente o modo de visualização para vertical se o resultado é "
+"maior que a largura do terminal."
 
 #: client/drizzle.cc:1286
 msgid ""
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
+"Não usa arquivo de histórico. Desabilita o comportamento interativo. "
+"(Habilita --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
-msgstr ""
+msgstr "Diretório onde os conjuntos de caracteres estão."
 
 #: client/drizzle.cc:1290
 msgid "Display column type information."
-msgstr ""
+msgstr "Mostra informação do tipo de coluna."
 
 #: client/drizzle.cc:1293
 msgid ""
 "Preserve comments. Send comments to the server. The default is --skip-"
 "comments (discard comments), enable with --comments"
 msgstr ""
+"Preserva comentários. Envia comentários para o servidor. O padrão é --skip-"
+"comments (descarta comentários), habilite-o com --comments"
 
 #: client/drizzle.cc:1296
 msgid "Use compression in server/client protocol."
@@ -215,19 +232,19 @@
 
 #: client/drizzle.cc:1299
 msgid "Check memory and open file usage at exit ."
-msgstr ""
+msgstr "Verifica memória e arquivos abertos ao sair do programa."
 
 #: client/drizzle.cc:1302
 msgid "Print some debug info at exit."
-msgstr "Imprimir algumas informações de debugs na saída."
+msgstr "Imprimir alguma informação de debug na saída."
 
 #: client/drizzle.cc:1304
 msgid "Database to use."
 msgstr "Banco de dados a usar."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
-msgstr ""
+msgstr "Define o conjunto de caracteres padrão."
 
 #: client/drizzle.cc:1309
 msgid "Delimiter to be used."
@@ -235,15 +252,15 @@
 
 #: client/drizzle.cc:1311
 msgid "Execute command and quit. (Disables --force and history file)"
-msgstr ""
+msgstr "Executa o comando e sai. (Desabilita --force e arquivo de histórico)"
 
 #: client/drizzle.cc:1313
 msgid "Print the output of a query (rows) vertically."
-msgstr ""
+msgstr "Mostra a saída de uma query (linhas) verticalmente."
 
 #: client/drizzle.cc:1316
 msgid "Continue even if we get an sql error."
-msgstr "Continuar mesmo se nós pegarmos um erro sql."
+msgstr "Continuar mesmo se ocorrer um erro de sql."
 
 #: client/drizzle.cc:1320
 msgid ""
@@ -264,59 +281,71 @@
 
 #: client/drizzle.cc:1326
 msgid "Ignore space after function names."
-msgstr ""
+msgstr "Ignorar espaços após nome de funções."
 
 #: client/drizzle.cc:1328
 msgid "Enable/disable LOAD DATA LOCAL INFILE."
-msgstr ""
+msgstr "Habilita/desabilita LOAD DATA LOCAL INFILE."
 
 #: client/drizzle.cc:1331
+#, fuzzy
 msgid "Turn off beep on error."
-msgstr ""
+msgstr "Desliga o bip em caso de erro (modo silencioso)"
 
 #: client/drizzle.cc:1333 client/drizzleadmin.cc:71
 msgid "Connect to host."
-msgstr ""
+msgstr "Conecta ao host."
 
 #: client/drizzle.cc:1335
 msgid "Write line numbers for errors."
-msgstr ""
+msgstr "Escreve o número das linhas com erros."
 
 #: client/drizzle.cc:1338
+#, fuzzy
 msgid ""
 "Don't write line number for errors. WARNING: -L is deprecated, use long "
 "version of this option instead."
 msgstr ""
+"Não escreve o número das linhas com erros. AVISO: -L está depreciado. Ao "
+"invés disso, use a versão longa dessa opção."
 
 #: client/drizzle.cc:1340
 msgid "Flush buffer after each query."
-msgstr ""
+msgstr "Liberar o buffer após cada query."
 
 #: client/drizzle.cc:1342
 msgid "Write column names in results."
-msgstr ""
+msgstr "Escrever nome de colunas nos resultados."
 
 #: client/drizzle.cc:1346
 msgid ""
 "Don't write column names in results. WARNING: -N is deprecated, use long "
 "version of this options instead."
 msgstr ""
+"Não escrever o nome das colunas nos resultados. AVISO: -N está obsoleto, use "
+"a versão longa desta opção."
 
 #: client/drizzle.cc:1349
+#, fuzzy
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated; "
 "you can set variables directly with --variable-name=value."
 msgstr ""
+"Muda o valor de uma variável. Por favor note que esta opção está depreciada; "
+"você pode setar variáveis diretamente com --nome-da-variável=valor."
 
 #: client/drizzle.cc:1351
 msgid "Ignore SIGINT (CTRL-C)"
-msgstr ""
+msgstr "Ignora SIGINT (CTRL-C)"
 
 #: client/drizzle.cc:1355
+#, fuzzy
 msgid ""
 "Only update the default database. This is useful for skipping updates to "
 "other database in the update log."
 msgstr ""
+"Atualiza apenas a database atual. Isto  útil para ignorar atualizações em "
+"outros databases no 'update log'."
 
 #: client/drizzle.cc:1358
 msgid ""
@@ -338,24 +367,30 @@
 "Password to use when connecting to server. If password is not given it's "
 "asked from the tty."
 msgstr ""
+"Senha a ser usada quando conectando ao servidor. Se nenhuma senha é "
+"fornecida como parâmetro, ela será perguntada no terminal."
 
 #: client/drizzle.cc:1366
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, "
 msgstr ""
+"Número da porta para conectar ou 0 para o padrão, nessa ordem de "
+"preferência: my.cnf, $DRIZZLE_TCP_PORT, "
 
 #: client/drizzle.cc:1367
+#, fuzzy
 msgid "built-in default"
-msgstr ""
+msgstr "padrão da aplicação"
 
 #: client/drizzle.cc:1370
+#, fuzzy
 msgid "Set the drizzle prompt to this value."
-msgstr ""
+msgstr "Muda o prompt do drizzle para este valor"
 
 #: client/drizzle.cc:1373
 msgid "The protocol of connection (tcp,socket,pipe,memory)."
-msgstr ""
+msgstr "O protocolo da conexão (tcp, socket, pipe, memory)."
 
 #: client/drizzle.cc:1376
 msgid ""
@@ -364,27 +399,33 @@
 msgstr ""
 
 #: client/drizzle.cc:1378
+#, fuzzy
 msgid "Write fields without conversion. Used with --batch."
-msgstr ""
+msgstr "Escreve os campos sem conversão. Usado com --batch."
 
 #: client/drizzle.cc:1381
 msgid ""
 "Reconnect if the connection is lost. Disable with --disable-reconnect. This "
 "option is enabled by default."
 msgstr ""
+"Reconectar se a conexão for perdida. Desabilite-o com --disable-reconnect. "
+"Esta opção é habilitada por padrão."
 
 #: client/drizzle.cc:1383
+#, fuzzy
 msgid ""
 "Be more silent. Print results with a tab as separator, each row on new line."
 msgstr ""
+"Seja mais silencioso. Mostra resultados com uma tabulação como separador, "
+"cada linha com um new line."
 
 #: client/drizzle.cc:1385
 msgid "Socket file to use for connection."
-msgstr ""
+msgstr "Arquivo de socket a usar para conexão."
 
 #: client/drizzle.cc:1388
 msgid "Output in table format."
-msgstr ""
+msgstr "Mostrar saída no formato de tabela."
 
 #: client/drizzle.cc:1391
 msgid ""
@@ -401,7 +442,7 @@
 
 #: client/drizzle.cc:1396 client/drizzleadmin.cc:84
 msgid "User for login if not current user."
-msgstr ""
+msgstr "Usuário para login, caso não seja o atual."
 
 #: client/drizzle.cc:1399
 msgid "Only allow UPDATE and DELETE that uses keys."
@@ -415,7 +456,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -425,7 +466,7 @@
 
 #: client/drizzle.cc:1412
 msgid "Number of seconds before connection timeout."
-msgstr ""
+msgstr "Número de segundos antes a conexão expirar."
 
 #: client/drizzle.cc:1417
 msgid "Max packet length to send to, or receive from server"
@@ -437,11 +478,11 @@
 
 #: client/drizzle.cc:1426
 msgid "Automatic limit for SELECT when using --safe-updates"
-msgstr ""
+msgstr "Limite automatico para SELECT quando usando --safe-updates"
 
 #: client/drizzle.cc:1431
 msgid "Automatic limit for rows in a join when using --safe-updates"
-msgstr ""
+msgstr "Limite automatico para linhas em um join quando usando --safe-updates"
 
 #: client/drizzle.cc:1435
 msgid "Refuse client connecting to server if it uses old (pre-4.1.1) protocol"
@@ -464,11 +505,11 @@
 #: client/drizzle.cc:1459
 #, c-format
 msgid "Usage: %s [OPTIONS] [database]\n"
-msgstr ""
+msgstr "Uso: %s [OPÇÕES] [banco de dados]\n"
 
 #: client/drizzle.cc:1492
 msgid "DELIMITER cannot contain a backslash character"
-msgstr ""
+msgstr "DELIMITER não pode conter barra-invertida."
 
 #: client/drizzle.cc:1513
 #, c-format
@@ -499,7 +540,7 @@
 
 #: client/drizzle.cc:2436
 msgid "No connection. Trying to reconnect..."
-msgstr ""
+msgstr "Sem conexão. Tentando reconectar..."
 
 #: client/drizzle.cc:2442
 msgid "Can't connect to the server\n"
@@ -507,16 +548,16 @@
 
 #: client/drizzle.cc:2499
 msgid "categories:"
-msgstr ""
+msgstr "categorias:"
 
 #: client/drizzle.cc:2499
 msgid "topics:"
-msgstr ""
+msgstr "tópicos:"
 
 #: client/drizzle.cc:2550
 #, c-format
 msgid "Name: '%s'\n"
-msgstr ""
+msgstr "Nome: '%s'\n"
 
 #: client/drizzle.cc:2551
 #, c-format
@@ -524,6 +565,8 @@
 "Description:\n"
 "%s"
 msgstr ""
+"Descrição:\n"
+"%s"
 
 #: client/drizzle.cc:2553
 #, c-format
@@ -531,6 +574,8 @@
 "Examples:\n"
 "%s"
 msgstr ""
+"Exemplos:\n"
+"%s"
 
 #: client/drizzle.cc:2566
 msgid "Many help items for your request exist."
@@ -558,6 +603,8 @@
 "\n"
 "Nothing found"
 msgstr ""
+"\n"
+"Nada encontrado"
 
 #: client/drizzle.cc:2588
 msgid "Please try to run 'help contents' for a list of all accessible topics\n"
@@ -565,7 +612,7 @@
 
 #: client/drizzle.cc:2610
 msgid "List of all Drizzle commands:"
-msgstr ""
+msgstr "Lista de todos comandos do Drizzle:"
 
 #: client/drizzle.cc:2612
 msgid "Note that all text commands must be first on line and end with ';'"
@@ -583,23 +630,23 @@
 
 #: client/drizzle.cc:2658
 msgid "Charset changed"
-msgstr ""
+msgstr "Charset modificado"
 
 #: client/drizzle.cc:2660
 msgid "Charset is not found"
-msgstr ""
+msgstr "Charset não encontrado"
 
 #: client/drizzle.cc:2691
 msgid "No query specified\n"
-msgstr ""
+msgstr "Nenhuma query especificada\n"
 
 #: client/drizzle.cc:2706
 msgid "Ignoring query to other database"
-msgstr ""
+msgstr "Ignorando query para outro banco de dados"
 
 #: client/drizzle.cc:2755
 msgid "Empty set"
-msgstr ""
+msgstr "Conjunto vazio"
 
 #: client/drizzle.cc:2768
 #, c-format
@@ -610,16 +657,16 @@
 
 #: client/drizzle.cc:2777
 msgid "Query OK"
-msgstr ""
+msgstr "Query OK"
 
 #: client/drizzle.cc:2779
 #, c-format
 msgid "Query OK, %ld row affected"
 msgid_plural "Query OK, %ld rows affected"
-msgstr[0] ""
-msgstr[1] ""
+msgstr[0] "Query OK, %ld linha afetada"
+msgstr[1] "Query OK, %ld linhas afetadas"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -631,7 +678,7 @@
 
 #: client/drizzleadmin.cc:87
 msgid "Write more information."
-msgstr ""
+msgstr "Escrever mais informação."
 
 #: client/drizzleadmin.cc:254
 #, c-format
@@ -639,6 +686,8 @@
 "connect to server at '%s' failed\n"
 "error: '%s'"
 msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
 
 #: client/drizzleadmin.cc:260
 #, c-format
@@ -677,7 +726,7 @@
 #: client/drizzleadmin.cc:325
 #, c-format
 msgid "done\n"
-msgstr ""
+msgstr "concluído\n"
 
 #: client/drizzleadmin.cc:335
 msgid "drizzled is alive"
@@ -695,7 +744,7 @@
 #: client/drizzleadmin.cc:356
 #, c-format
 msgid "Unknown command: '%-.60s'"
-msgstr ""
+msgstr "Comando desconhecido: '%-.60s'"
 
 #: client/drizzleadmin.cc:365
 #, c-format
@@ -704,7 +753,7 @@
 
 #: client/drizzleadmin.cc:372
 msgid "Copyright (C) 2000-2008 MySQL AB"
-msgstr ""
+msgstr "Copyright (C) 2000-2008 MySQL AB"
 
 #: client/drizzleadmin.cc:373
 msgid ""
@@ -719,7 +768,7 @@
 #: client/drizzleadmin.cc:375
 #, c-format
 msgid "Usage: %s [OPTIONS] command command....\n"
-msgstr ""
+msgstr "Uso: %s [OPÇÕES] comando comando....\n"
 
 #: client/drizzleadmin.cc:377
 msgid ""
@@ -727,15 +776,289 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "conectando"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Código de erro inválido"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
+
+#: libdrizzle/errmsg.c:89
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
+
+#: libdrizzle/errmsg.c:91
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
+
+#: libdrizzle/errmsg.c:93
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
+
+#: libdrizzle/errmsg.c:95
+#, fuzzy, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+"conexão ao servidor '%s' falhou\n"
+"erro: '%s'"
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
-msgstr ""
-
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Não foi possível criar/escrever no arquivo '%s' (Código do erro: %d)"
 
 #: mysys/errors.c:27
 #, c-format
@@ -743,9 +1066,9 @@
 msgstr ""
 
 #: mysys/errors.c:28
-#, c-format
+#, fuzzy, c-format
 msgid "Error on close of '%s' (Errcode: %d)"
-msgstr ""
+msgstr "Não foi possível criar/escrever no arquivo '%s' (Código do erro: %d)"
 
 #: mysys/errors.c:29
 #, c-format
@@ -866,11 +1189,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1194,12 +1512,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1212,52 +1536,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1268,7 +1592,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1278,7 +1602,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1286,14 +1610,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1305,7 +1629,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1316,7 +1640,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1328,90 +1652,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
-msgstr "Escrevendo arquivo de história %s\n"
+msgstr "Escrevendo arquivo de histórico %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1419,91 +1743,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1514,151 +1838,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1668,141 +1992,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1812,7 +2136,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1820,7 +2144,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1829,7 +2153,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1837,20 +2161,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1860,7 +2184,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1870,7 +2194,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1880,7 +2204,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1888,63 +2212,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1952,139 +2276,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2092,161 +2416,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2254,7 +2578,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2262,7 +2586,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2273,162 +2597,162 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Usar compressão em protocolo de Servidor/Cliente."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2437,76 +2761,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5820,6 +6144,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5855,18 +6329,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6065,7 +6576,7 @@
 
 #: drizzled/slave.cc:2002
 msgid "error in drizzle_create()"
-msgstr ""
+msgstr "erro em drizzle_create()"
 
 #: drizzled/slave.cc:2010
 #, c-format
@@ -6205,7 +6716,7 @@
 
 #: drizzled/slave.cc:2702
 msgid "Memory allocation failed"
-msgstr ""
+msgstr "Falha na alocação de memória"
 
 #: drizzled/slave.cc:2727 drizzled/slave.cc:2813
 #, c-format
@@ -6225,11 +6736,11 @@
 
 #: drizzled/slave.cc:3182
 msgid "reconnecting"
-msgstr ""
+msgstr "reconectando"
 
 #: drizzled/slave.cc:3182
 msgid "connecting"
-msgstr ""
+msgstr "conectando"
 
 #: drizzled/slave.cc:3208
 #, c-format
@@ -6287,6 +6798,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6303,6 +6927,39 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+"Não foi possível alocar memória para arquivo de histórico temporário.\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/ro.po'
--- po/ro.po	2008-08-14 17:35:53 +0000
+++ po/ro.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 11:30+0000\n"
 "Last-Translator: Alex Eftimie <alexeftimie@gmail.com>\n"
 "Language-Team: Romanian <ro@li.org>\n"
@@ -16,7 +16,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=(n == 1 ? 0: (((n % 100 > 19) || ((n % 100 "
 "== 0) && (n != 0))) ? 2: 1));\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -164,7 +164,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Cerere abandonata prin Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Afiseaza acest mesaj de ajutor si iesi."
 
@@ -202,7 +202,7 @@
 "Nu utiliza un fisier de istoric. Dezactiveaza comportamentul interactiv. "
 "(Activeaza --silent)"
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -232,7 +232,7 @@
 msgid "Database to use."
 msgstr "Baza de date pe care sa o folosesc."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Stabileste setul de caractere implicit."
 
@@ -422,7 +422,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -626,7 +626,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -734,16 +734,279 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Cod de eroare invalid."
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -873,11 +1136,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1201,12 +1459,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1219,52 +1483,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1275,7 +1539,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1285,7 +1549,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1293,14 +1557,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1312,7 +1576,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1323,7 +1587,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1335,90 +1599,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Scrie fisierul de istoric %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1426,91 +1690,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1521,151 +1785,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1675,141 +1939,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1819,7 +2083,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1827,7 +2091,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1836,7 +2100,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1844,20 +2108,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1867,7 +2131,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1877,7 +2141,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1887,7 +2151,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1895,63 +2159,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1959,139 +2223,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2099,161 +2363,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2261,7 +2525,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2269,7 +2533,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2280,162 +2544,162 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Compreseaza datele in comunicatia server/client."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2444,76 +2708,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5825,6 +6089,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5860,18 +6274,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6292,6 +6743,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6308,6 +6872,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "Nu am putut aloca memorie pentru acest fisier de istoric temporar!\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/ru.po'
--- po/ru.po	2008-08-14 17:35:53 +0000
+++ po/ru.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 05:51+0000\n"
 "Last-Translator: Alexey Kovyrin <Unknown>\n"
 "Language-Team: Russian <ru@li.org>\n"
@@ -16,7 +16,7 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%"
 "10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -169,7 +169,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "Запрос прерван с помощью Ctrl+C\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "Показать справку и выйти."
 
@@ -218,7 +218,7 @@
 "Не использовать файл истории команд. Отключает интерактивное поведение "
 "клиента. (Включает --silent)."
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 #, fuzzy
 msgid "Directory where character sets are."
 msgstr "Каталог, в котором находятся файлы кодировок символов."
@@ -252,7 +252,7 @@
 msgid "Database to use."
 msgstr "База данных для использования."
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr "Установить кодировку по-умолчанию."
 
@@ -451,7 +451,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "Вывод информации о версии и выход из программы."
 
@@ -658,7 +658,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -766,16 +766,279 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "Неверный код ошибки."
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -905,11 +1168,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1233,12 +1491,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1251,52 +1515,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1307,7 +1571,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1317,7 +1581,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1325,14 +1589,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1344,7 +1608,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1355,7 +1619,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1367,90 +1631,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, fuzzy, c-format
 msgid "Writing a core file\n"
 msgstr "Запись файла истории %s\n"
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1458,91 +1722,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1553,151 +1817,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1707,141 +1971,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1851,7 +2115,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1859,7 +2123,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1868,7 +2132,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1876,20 +2140,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1899,7 +2163,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1909,7 +2173,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1919,7 +2183,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1927,63 +2191,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1991,139 +2255,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2131,161 +2395,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2293,7 +2557,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2301,7 +2565,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2312,162 +2576,162 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "Использовать сжатие в клиент-серверном протоколе."
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2476,76 +2740,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5859,6 +6123,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5894,18 +6308,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6326,6 +6777,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6342,6 +6906,38 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+#, fuzzy
+msgid "Can't allocate memory for udf structures"
+msgstr "Невозможно выделить мамять под временный файл истории!\n"
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/tr.po'
--- po/tr.po	2008-08-14 17:35:53 +0000
+++ po/tr.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-12 13:39+0000\n"
 "Last-Translator: Harun Yayli <Unknown>\n"
 "Language-Team: Turkish <tr@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -154,7 +154,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr ""
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr ""
 
@@ -187,7 +187,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -217,7 +217,7 @@
 msgid "Database to use."
 msgstr ""
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -407,7 +407,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr ""
 
@@ -611,7 +611,7 @@
 msgstr[0] ""
 msgstr[1] ""
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -719,16 +719,278 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+msgid "Unknown Drizzle error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:30
+#, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+msgid "SSL connection error"
+msgstr ""
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+msgid "Invalid connection handle"
+msgstr ""
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr ""
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr ""
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -858,11 +1120,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr ""
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1186,12 +1443,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1204,52 +1467,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1260,7 +1523,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1270,7 +1533,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1278,14 +1541,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1297,7 +1560,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1308,7 +1571,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1320,90 +1583,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1411,91 +1674,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1506,151 +1769,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1660,141 +1923,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1804,7 +2067,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1812,7 +2075,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1821,7 +2084,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1829,20 +2092,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1852,7 +2115,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1862,7 +2125,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1872,7 +2135,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1880,63 +2143,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1944,139 +2207,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2084,161 +2347,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2246,7 +2509,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2254,7 +2517,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2265,161 +2528,161 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 msgid "Use compression on master/slave protocol."
 msgstr ""
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2428,76 +2691,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5809,6 +6072,156 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+msgid "Too many storage engines!"
+msgstr ""
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr ""
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr ""
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5844,18 +6257,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr ""
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6276,6 +6726,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr ""
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6292,6 +6855,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr ""
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

=== modified file 'po/zh_HK.po'
--- po/zh_HK.po	2008-08-14 17:35:53 +0000
+++ po/zh_HK.po	2008-08-16 23:49:05 +0000
@@ -7,7 +7,7 @@
 msgstr ""
 "Project-Id-Version: drizzle\n"
 "Report-Msgid-Bugs-To: http://translations.launchpad.net/drizzle\n"
-"POT-Creation-Date: 2008-08-14 10:35-0700\n"
+"POT-Creation-Date: 2008-08-16 16:48-0700\n"
 "PO-Revision-Date: 2008-08-13 03:31+0000\n"
 "Last-Translator: Monty Taylor <monty@inaugust.com>\n"
 "Language-Team: Chinese (Hong Kong) <zh_HK@li.org>\n"
@@ -15,7 +15,7 @@
 "Content-Type: text/plain; charset=UTF-8\n"
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=1; plural=0;\n"
-"X-Launchpad-Export-Date: 2008-08-14 00:36+0000\n"
+"X-Launchpad-Export-Date: 2008-08-16 20:24+0000\n"
 "X-Generator: Launchpad (build Unknown)\n"
 
 #: client/drizzle.cc:256
@@ -151,7 +151,7 @@
 msgid "Query aborted by Ctrl+C\n"
 msgstr "查詢因Ctrl+C而終止\n"
 
-#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3112
+#: client/drizzle.cc:1271 client/drizzleadmin.cc:69 drizzled/drizzled.cc:3110
 msgid "Display this help and exit."
 msgstr "顯示這個項目的說明並離開"
 
@@ -184,7 +184,7 @@
 "Don't use history file. Disable interactive behavior. (Enables --silent)"
 msgstr ""
 
-#: client/drizzle.cc:1288 drizzled/drizzled.cc:3182
+#: client/drizzle.cc:1288 drizzled/drizzled.cc:3180
 msgid "Directory where character sets are."
 msgstr ""
 
@@ -214,7 +214,7 @@
 msgid "Database to use."
 msgstr "使用的資料庫"
 
-#: client/drizzle.cc:1307 drizzled/drizzled.cc:3178
+#: client/drizzle.cc:1307 drizzled/drizzled.cc:3176
 msgid "Set the default character set."
 msgstr ""
 
@@ -404,7 +404,7 @@
 msgid "Write more. (-v -v -v gives the table output format)."
 msgstr ""
 
-#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3650
+#: client/drizzle.cc:1407 client/drizzleadmin.cc:89 drizzled/drizzled.cc:3648
 msgid "Output version information and exit."
 msgstr "顯示版本資料並離開"
 
@@ -611,7 +611,7 @@
 msgid_plural "Query OK, %ld rows affected"
 msgstr[0] "成功執行, %ld 筆記錄受到影響"
 
-#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3441
+#: client/drizzleadmin.cc:76 drizzled/drizzled.cc:3439
 msgid ""
 "Port number to use for connection or 0 for default to, in order of "
 "preference, my.cnf, $DRIZZLE_TCP_PORT, built-in default ("
@@ -719,16 +719,281 @@
 "  shutdown     Take server down\n"
 msgstr ""
 
+#: libdrizzle/client.c:673
+#, c-format
+msgid "Unknown option to protocol: %s\n"
+msgstr ""
+
+#: libdrizzle/client.c:1153
+#, c-format
+msgid "COLLATION %s is not valid for CHARACTER SET %s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:29
+#, fuzzy
+msgid "Unknown Drizzle error"
+msgstr "不明的錯誤 %d"
+
+#: libdrizzle/errmsg.c:30
+#, fuzzy, c-format
+msgid "Can't create UNIX socket (%d)"
+msgstr "不能建立資料夾'%s' (錯誤碼: %d)"
+
+#: libdrizzle/errmsg.c:31
+#, c-format
+msgid "Can't connect to local Drizzle server through socket '%-.100s' (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:32
+#, fuzzy, c-format
+msgid "Can't connect to Drizzle server on '%-.100s' (%d)"
+msgstr "不能連接伺服器\n"
+
+#: libdrizzle/errmsg.c:33
+#, c-format
+msgid "Can't create TCP/IP socket (%d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:34
+#, fuzzy, c-format
+msgid "Unknown Drizzle server host '%-.100s' (%d)"
+msgstr "不明白的指令: '%-.60s'"
+
+#: libdrizzle/errmsg.c:35
+msgid "Drizzle server has gone away"
+msgstr ""
+
+#: libdrizzle/errmsg.c:36
+#, c-format
+msgid "Protocol mismatch; server version = %d, client version = %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:37
+msgid "Drizzle client ran out of memory"
+msgstr ""
+
+#: libdrizzle/errmsg.c:38
+msgid "Wrong host info"
+msgstr ""
+
+#: libdrizzle/errmsg.c:39
+msgid "Localhost via UNIX socket"
+msgstr ""
+
+#: libdrizzle/errmsg.c:40
+#, c-format
+msgid "%-.100s via TCP/IP"
+msgstr ""
+
+#: libdrizzle/errmsg.c:41
+msgid "Error in server handshake"
+msgstr ""
+
+#: libdrizzle/errmsg.c:42
+msgid "Lost connection to Drizzle server during query"
+msgstr ""
+
+#: libdrizzle/errmsg.c:43
+msgid "Commands out of sync; you can't run this command now"
+msgstr ""
+
+#: libdrizzle/errmsg.c:44
+#, c-format
+msgid "Named pipe: %-.32s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:45
+#, c-format
+msgid "Can't wait for named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:46
+#, c-format
+msgid "Can't open named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:47
+#, c-format
+msgid "Can't set state of named pipe to host: %-.64s  pipe: %-.32s (%lu)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:48
+#, c-format
+msgid "Can't initialize character set %-.32s (path: %-.100s)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:49
+msgid "Got packet bigger than 'max_allowed_packet' bytes"
+msgstr ""
+
+#: libdrizzle/errmsg.c:50
+msgid "Embedded server"
+msgstr ""
+
+#: libdrizzle/errmsg.c:51
+msgid "Error on SHOW SLAVE STATUS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:52
+msgid "Error on SHOW SLAVE HOSTS:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:53
+msgid "Error connecting to slave:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:54
+msgid "Error connecting to master:"
+msgstr ""
+
+#: libdrizzle/errmsg.c:55
+#, fuzzy
+msgid "SSL connection error"
+msgstr "不明的錯誤 %d"
+
+#: libdrizzle/errmsg.c:56
+msgid "Malformed packet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:57 libdrizzle/errmsg.c:68 libdrizzle/errmsg.c:69
+#: libdrizzle/errmsg.c:70 libdrizzle/errmsg.c:71 libdrizzle/errmsg.c:72
+#: libdrizzle/errmsg.c:73 libdrizzle/errmsg.c:74 libdrizzle/errmsg.c:75
+#: libdrizzle/errmsg.c:76
+msgid "(unused error message)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:58
+msgid "Invalid use of null pointer"
+msgstr ""
+
+#: libdrizzle/errmsg.c:59
+msgid "Statement not prepared"
+msgstr ""
+
+#: libdrizzle/errmsg.c:60
+msgid "No data supplied for parameters in prepared statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:61
+msgid "Data truncated"
+msgstr ""
+
+#: libdrizzle/errmsg.c:62
+msgid "No parameters exist in the statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:63
+msgid "Invalid parameter number"
+msgstr ""
+
+#: libdrizzle/errmsg.c:64
+#, c-format
+msgid ""
+"Can't send long data for non-string/non-binary data types (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:66
+#, c-format
+msgid "Using unsupported buffer type: %d  (parameter: %d)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:67
+#, c-format
+msgid "Shared memory: %-.100s"
+msgstr ""
+
+#: libdrizzle/errmsg.c:77
+msgid "Wrong or unknown protocol"
+msgstr ""
+
+#: libdrizzle/errmsg.c:78
+#, fuzzy
+msgid "Invalid connection handle"
+msgstr "無效的錯誤碼"
+
+#: libdrizzle/errmsg.c:79
+msgid ""
+"Connection using old (pre-4.1.1) authentication protocol refused (client "
+"option 'secure_auth' enabled)"
+msgstr ""
+
+#: libdrizzle/errmsg.c:81
+msgid "Row retrieval was canceled by drizzle_stmt_close() call"
+msgstr ""
+
+#: libdrizzle/errmsg.c:82
+msgid "Attempt to read column without prior row fetch"
+msgstr ""
+
+#: libdrizzle/errmsg.c:83
+msgid "Prepared statement contains no metadata"
+msgstr ""
+
+#: libdrizzle/errmsg.c:84
+msgid ""
+"Attempt to read a row while there is no result set associated with the "
+"statement"
+msgstr ""
+
+#: libdrizzle/errmsg.c:86
+msgid "This feature is not implemented yet"
+msgstr ""
+
+#: libdrizzle/errmsg.c:87
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while waiting for initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:89
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading initial communication "
+"packet, system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:91
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while sending authentication information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:93
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while reading authorization information, "
+"system error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:95
+#, c-format
+msgid ""
+"Lost connection to Drizzle server while setting initial database, system "
+"error: %d"
+msgstr ""
+
+#: libdrizzle/errmsg.c:97
+#, c-format
+msgid "Statement closed indirectly because of a preceeding %s() call"
+msgstr ""
+
+#: libdrizzle/local_infile.c:186 mysys/errors.c:52
+#, c-format
+msgid "File '%s' not found (Errcode: %d)"
+msgstr "找不到檔案 '%s' (錯誤碼: %d)"
+
+#: libdrizzle/local_infile.c:217 mysys/errors.c:26
+#, c-format
+msgid "Error reading file '%s' (Errcode: %d)"
+msgstr "讀取檔案'%s'時發生錯誤 (錯誤碼: %d)"
+
 #: mysys/errors.c:25
 #, c-format
 msgid "Can't create/write to file '%s' (Errcode: %d)"
 msgstr ""
 
-#: mysys/errors.c:26
-#, c-format
-msgid "Error reading file '%s' (Errcode: %d)"
-msgstr "讀取檔案'%s'時發生錯誤 (錯誤碼: %d)"
-
 #: mysys/errors.c:27
 #, c-format
 msgid "Error writing file '%s' (Errcode: %d)"
@@ -858,11 +1123,6 @@
 "file"
 msgstr ""
 
-#: mysys/errors.c:52
-#, c-format
-msgid "File '%s' not found (Errcode: %d)"
-msgstr "找不到檔案 '%s' (錯誤碼: %d)"
-
 #: mysys/errors.c:53
 #, c-format
 msgid "File '%s' (fileno: %d) was not closed"
@@ -1186,12 +1446,18 @@
 msgid "Tablespace not empty"
 msgstr ""
 
+#: drizzled/authentication.cc:48 drizzled/handler.cc:362
+#: drizzled/sql_plugin.cc:790 drizzled/sql_udf.cc:100
+#, c-format
+msgid "Plugin '%s' init function returned error."
+msgstr ""
+
 #: drizzled/drizzled.cc:551
 #, c-format
 msgid "Got error %d from pthread_cond_timedwait"
 msgstr ""
 
-#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1784
+#: drizzled/drizzled.cc:691 drizzled/drizzled.cc:1783
 msgid "Can't create thread to kill server"
 msgstr ""
 
@@ -1204,52 +1470,52 @@
 msgid "Aborting\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:991
+#: drizzled/drizzled.cc:990
 msgid "One can only use the --user switch if running as root\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:999
+#: drizzled/drizzled.cc:998
 msgid ""
 "Fatal error: Please read \"Security\" section of the manual to find out how "
 "to run mysqld as root!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1023
+#: drizzled/drizzled.cc:1022
 #, c-format
 msgid ""
 "Fatal error: Can't change to run as user '%s' ;  Please check that the user "
 "exists!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1198
+#: drizzled/drizzled.cc:1197
 #, c-format
 msgid "Retrying bind on TCP/IP port %u"
 msgstr ""
 
+#: drizzled/drizzled.cc:1203
+msgid "Can't start server: Bind on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1204
-msgid "Can't start server: Bind on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1205
 #, c-format
 msgid "Do you already have another drizzled server running on port: %d ?"
 msgstr ""
 
+#: drizzled/drizzled.cc:1210
+msgid "Can't start server: listen() on TCP/IP port"
+msgstr ""
+
 #: drizzled/drizzled.cc:1211
-msgid "Can't start server: listen() on TCP/IP port"
-msgstr ""
-
-#: drizzled/drizzled.cc:1212
 #, c-format
 msgid "listen() on TCP/IP failed with error %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1430
+#: drizzled/drizzled.cc:1429
 #, c-format
 msgid "Fatal "
 msgstr ""
 
-#: drizzled/drizzled.cc:1448
+#: drizzled/drizzled.cc:1447
 #, c-format
 msgid ""
 "We will try our best to scrape up some info that will hopefully help "
@@ -1260,7 +1526,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1459
+#: drizzled/drizzled.cc:1458
 #, c-format
 msgid ""
 "It is possible that mysqld could use up to \n"
@@ -1270,7 +1536,7 @@
 "\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1477
+#: drizzled/drizzled.cc:1476
 #, c-format
 msgid ""
 "Attempting backtrace. You can use the following information to find out\n"
@@ -1278,14 +1544,14 @@
 "terribly wrong...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1505
+#: drizzled/drizzled.cc:1504
 #, c-format
 msgid ""
 "Trying to get some variables.\n"
 "Some pointers may be invalid and cause the dump to abort...\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1517
+#: drizzled/drizzled.cc:1516
 #, c-format
 msgid ""
 "\n"
@@ -1297,7 +1563,7 @@
 "drizzled that is not statically linked.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1532
+#: drizzled/drizzled.cc:1531
 #, c-format
 msgid ""
 "\n"
@@ -1308,7 +1574,7 @@
 "the documentation for your distribution on how to do that.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1545
+#: drizzled/drizzled.cc:1544
 #, c-format
 msgid ""
 "\n"
@@ -1320,90 +1586,90 @@
 " bugs.\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1560
+#: drizzled/drizzled.cc:1559
 #, c-format
 msgid "Writing a core file\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:1607
+#: drizzled/drizzled.cc:1606
 msgid ""
 "setrlimit could not change the size of core files to 'infinity';  We may not "
 "be able to generate a core file on signals"
 msgstr ""
 
-#: drizzled/drizzled.cc:1676
+#: drizzled/drizzled.cc:1675
 #, c-format
 msgid "Can't create interrupt-thread (error %d, errno: %d)"
 msgstr ""
 
-#: drizzled/drizzled.cc:1764
+#: drizzled/drizzled.cc:1763
 #, c-format
 msgid "Got signal %d to shutdown mysqld"
 msgstr ""
 
-#: drizzled/drizzled.cc:1811
+#: drizzled/drizzled.cc:1810
 #, c-format
 msgid "Got signal: %d  error: %d"
 msgstr ""
 
-#: drizzled/drizzled.cc:1950
+#: drizzled/drizzled.cc:1949
 #, c-format
 msgid "Wrong date/time format specifier: %s\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2079
+#: drizzled/drizzled.cc:2078
 #, c-format
 msgid "gethostname failed, using '%s' as hostname"
 msgstr ""
 
-#: drizzled/drizzled.cc:2143
+#: drizzled/drizzled.cc:2142
 #, c-format
 msgid ""
 "Changed limits: max_open_files: %u  max_connections: %ld  table_cache: %ld"
 msgstr ""
 
-#: drizzled/drizzled.cc:2148
+#: drizzled/drizzled.cc:2147
 #, c-format
 msgid ""
 "Could not increase number of max_open_files to more than %u (request: %u)"
 msgstr ""
 
-#: drizzled/drizzled.cc:2230
+#: drizzled/drizzled.cc:2228
 #, c-format
 msgid "Unknown locale: '%s'"
 msgstr ""
 
-#: drizzled/drizzled.cc:2250
+#: drizzled/drizzled.cc:2248
 msgid ""
 "Although a path was specified for the --log option, log tables are used. To "
 "enable logging to files use the --log-output option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2257
+#: drizzled/drizzled.cc:2255
 msgid ""
 "Although a path was specified for the --log-slow-queries option, log tables "
 "are used. To enable logging to files use the --log-output=file option."
 msgstr ""
 
-#: drizzled/drizzled.cc:2327
+#: drizzled/drizzled.cc:2325
 msgid "Can't create thread-keys"
 msgstr ""
 
-#: drizzled/drizzled.cc:2374
+#: drizzled/drizzled.cc:2372
 msgid "Out of memory"
 msgstr ""
 
-#: drizzled/drizzled.cc:2381
+#: drizzled/drizzled.cc:2379
 msgid "You need to use --log-bin to make --binlog-format work."
 msgstr ""
 
-#: drizzled/drizzled.cc:2403
+#: drizzled/drizzled.cc:2401
 msgid ""
 "using --replicate-same-server-id in conjunction with --log-slave-updates is "
 "impossible, it would lead to infinite loops in this server."
 msgstr ""
 
-#: drizzled/drizzled.cc:2423
+#: drizzled/drizzled.cc:2421
 #, c-format
 msgid ""
 "No argument was provided to --log-bin, and --log-bin-index was not used; so "
@@ -1411,91 +1677,91 @@
 "hostname changed!! Please use '--log-bin=%s' to avoid this problem."
 msgstr ""
 
-#: drizzled/drizzled.cc:2457
+#: drizzled/drizzled.cc:2455
 msgid "Failed to initialize plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:2488
+#: drizzled/drizzled.cc:2486
 #, c-format
 msgid ""
 "%s: Too many arguments (first extra is '%s').\n"
 "Use --verbose --help to get a list of available options\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2498
+#: drizzled/drizzled.cc:2496
 msgid "Can't init databases"
 msgstr ""
 
-#: drizzled/drizzled.cc:2521
+#: drizzled/drizzled.cc:2519
 #, c-format
 msgid "Unknown/unsupported table type: %s"
 msgstr ""
 
-#: drizzled/drizzled.cc:2527
+#: drizzled/drizzled.cc:2525
 #, c-format
 msgid "Default storage engine (%s) is not available"
 msgstr ""
 
-#: drizzled/drizzled.cc:2550
+#: drizzled/drizzled.cc:2548
 msgid "Can't initialize tc_log"
 msgstr ""
 
-#: drizzled/drizzled.cc:2581
+#: drizzled/drizzled.cc:2579
 #, c-format
 msgid "Failed to lock memory. Errno: %d\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:2651
+#: drizzled/drizzled.cc:2649
 #, c-format
 msgid "Asked for %u thread stack, but got %llu"
 msgstr ""
 
-#: drizzled/drizzled.cc:2687
+#: drizzled/drizzled.cc:2685
 msgid ""
 "You have enabled the binary log, but you haven't set server-id to a non-zero "
 "value: we force server id to 1; updates will be logged to the binary log, "
 "but connections from slaves will not be accepted."
 msgstr ""
 
-#: drizzled/drizzled.cc:2745
+#: drizzled/drizzled.cc:2743
 msgid "Before Lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2752
+#: drizzled/drizzled.cc:2750
 msgid "After lock_thread_count"
 msgstr ""
 
-#: drizzled/drizzled.cc:2861
+#: drizzled/drizzled.cc:2859
 #, c-format
 msgid "drizzled: Got error %d from select"
 msgstr ""
 
-#: drizzled/drizzled.cc:3116 drizzled/drizzled.cc:3235
-#: drizzled/drizzled.cc:3409
+#: drizzled/drizzled.cc:3114 drizzled/drizzled.cc:3233
+#: drizzled/drizzled.cc:3407
 msgid "Option used by mysql-test for debugging and testing of replication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3120
+#: drizzled/drizzled.cc:3118
 msgid "Auto-increment columns are incremented by this"
 msgstr ""
 
-#: drizzled/drizzled.cc:3125
+#: drizzled/drizzled.cc:3123
 msgid ""
 "Offset added to Auto-increment columns. Used when auto-increment-increment !"
 "= 1"
 msgstr ""
 
-#: drizzled/drizzled.cc:3131
+#: drizzled/drizzled.cc:3129
 msgid ""
 "Path to installation directory. All paths are usually resolved relative to "
 "this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3135
+#: drizzled/drizzled.cc:3133
 msgid "IP address to bind to."
 msgstr ""
 
-#: drizzled/drizzled.cc:3139
+#: drizzled/drizzled.cc:3137
 msgid ""
 "Does not have any effect without '--log-bin'. Tell the master the form of "
 "binary logging to use: either 'row' for row-based binary logging, or "
@@ -1506,151 +1772,151 @@
 "used. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3149
+#: drizzled/drizzled.cc:3147
 msgid ""
 "Tells the master it should log updates for the specified database, and "
 "exclude all others not explicitly mentioned."
 msgstr ""
 
-#: drizzled/drizzled.cc:3153
+#: drizzled/drizzled.cc:3151
 msgid ""
 "Tells the master that updates to the given database should not be logged "
 "tothe binary log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3157
+#: drizzled/drizzled.cc:3155
 msgid ""
 "The maximum size of a row-based binary log event in bytes. Rows will be "
 "grouped into events smaller than this size if possible. The value has to be "
 "a multiple of 256."
 msgstr ""
 
-#: drizzled/drizzled.cc:3168
+#: drizzled/drizzled.cc:3166
 msgid "Don't ignore client side character set value sent during handshake."
 msgstr ""
 
-#: drizzled/drizzled.cc:3173
+#: drizzled/drizzled.cc:3171
 msgid "Set the filesystem character set."
 msgstr ""
 
-#: drizzled/drizzled.cc:3185
+#: drizzled/drizzled.cc:3183
 msgid "Chroot mysqld daemon during startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3189
+#: drizzled/drizzled.cc:3187
 msgid "Set the default collation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3193
+#: drizzled/drizzled.cc:3191
 msgid "Default completion type."
 msgstr ""
 
-#: drizzled/drizzled.cc:3198
+#: drizzled/drizzled.cc:3196
 msgid "Write error output on screen."
 msgstr ""
 
-#: drizzled/drizzled.cc:3202
+#: drizzled/drizzled.cc:3200
 msgid "Write core on errors."
 msgstr ""
 
-#: drizzled/drizzled.cc:3206
+#: drizzled/drizzled.cc:3204
 msgid "Path to the database root."
 msgstr ""
 
-#: drizzled/drizzled.cc:3210
+#: drizzled/drizzled.cc:3208
 msgid ""
 "Set the default character set (deprecated option, use --character-set-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3215
+#: drizzled/drizzled.cc:3213
 msgid ""
 "Set the default collation (deprecated option, use --collation-server "
 "instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3220
+#: drizzled/drizzled.cc:3218
 msgid "Set the default storage engine (table type) for tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3224
+#: drizzled/drizzled.cc:3222
 msgid "Set the default time zone."
 msgstr ""
 
-#: drizzled/drizzled.cc:3228
+#: drizzled/drizzled.cc:3226
 msgid "Type of DELAY_KEY_WRITE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3231
+#: drizzled/drizzled.cc:3229
 msgid ""
 "Don't flush key buffers between writes for any MyISAM table (Deprecated "
 "option, use --delay-key-write=all instead)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3241
+#: drizzled/drizzled.cc:3239
 msgid "Print a symbolic stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3247
+#: drizzled/drizzled.cc:3245
 msgid "Push supported query conditions to the storage engine."
 msgstr ""
 
-#: drizzled/drizzled.cc:3253
+#: drizzled/drizzled.cc:3251
 msgid "Used for debugging;  Use at your own risk!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3256
+#: drizzled/drizzled.cc:3254
 msgid "Flush tables to disk between SQL commands."
 msgstr ""
 
-#: drizzled/drizzled.cc:3261
+#: drizzled/drizzled.cc:3259
 msgid "Set up signals usable for debugging"
 msgstr ""
 
-#: drizzled/drizzled.cc:3265
+#: drizzled/drizzled.cc:3263
 msgid "Enable general query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3269
+#: drizzled/drizzled.cc:3267
 msgid "Command(s) that are executed for each new connection"
 msgstr ""
 
-#: drizzled/drizzled.cc:3273
+#: drizzled/drizzled.cc:3271
 msgid "Read SQL commands from this file at startup."
 msgstr ""
 
-#: drizzled/drizzled.cc:3277
+#: drizzled/drizzled.cc:3275
 msgid "Command(s) that are executed when a slave connects to this master"
 msgstr ""
 
-#: drizzled/drizzled.cc:3281
+#: drizzled/drizzled.cc:3279
 msgid "(IGNORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3285
+#: drizzled/drizzled.cc:3283
 msgid "Set the language used for the month names and the days of the week."
 msgstr ""
 
-#: drizzled/drizzled.cc:3290
+#: drizzled/drizzled.cc:3288
 msgid "Enable/disable LOAD DATA LOCAL INFILE (takes values 1|0)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3295
+#: drizzled/drizzled.cc:3293
 msgid "Log connections and queries to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3299
+#: drizzled/drizzled.cc:3297
 msgid ""
 "Log update queries in binary format. Optional argument is the location for "
 "the binary log files.(Strongly recommended to avoid replication problems if "
 "server's hostname changes)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3306
+#: drizzled/drizzled.cc:3304
 msgid "File that holds the names for last binary log files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3314
+#: drizzled/drizzled.cc:3312
 msgid ""
 "If equal to 0 (the default), then when --log-bin is used, creation of a "
 "stored function (or trigger) is allowed only to users having the SUPER "
@@ -1660,141 +1926,141 @@
 "cannot break, so you can safely set this to 1."
 msgstr ""
 
-#: drizzled/drizzled.cc:3323
+#: drizzled/drizzled.cc:3321
 msgid "Error log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3327
+#: drizzled/drizzled.cc:3325
 msgid "Log all MyISAM changes to file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3331
+#: drizzled/drizzled.cc:3329
 msgid ""
 "Log some extra information to update log. Please note that this option is "
 "deprecated; see --log-queries-not-using-indexes option."
 msgstr ""
 
-#: drizzled/drizzled.cc:3336
+#: drizzled/drizzled.cc:3334
 msgid ""
 "Syntax: log-output[=value[,value...]], where \"value\" could be TABLE, FILE "
 "or NONE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3342
+#: drizzled/drizzled.cc:3340
 msgid ""
 "Log queries that are executed without benefit of any index to the slow log "
 "if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3348
+#: drizzled/drizzled.cc:3346
 msgid "Don't log extra information to update and slow-query logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3352
+#: drizzled/drizzled.cc:3350
 msgid ""
 "Tells the slave to log the updates from the slave thread to the binary log. "
 "You will need to turn it on if you plan to daisy-chain the slaves."
 msgstr ""
 
-#: drizzled/drizzled.cc:3359
+#: drizzled/drizzled.cc:3357
 msgid ""
 "Log slow OPTIMIZE, ANALYZE, ALTER and other administrative statements to the "
 "slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3365
+#: drizzled/drizzled.cc:3363
 msgid ""
 "Log slow statements executed by slave thread to the slow log if it is open."
 msgstr ""
 
-#: drizzled/drizzled.cc:3371
+#: drizzled/drizzled.cc:3369
 msgid ""
 "Log slow queries to a table or log file. Defaults logging to table mysql."
 "slow_log or hostname-slow.log if --log-output=file is used. Must be enabled "
 "to activate other slow log options."
 msgstr ""
 
-#: drizzled/drizzled.cc:3377
+#: drizzled/drizzled.cc:3375
 msgid ""
 "Path to transaction coordinator log (used for transactions that affect more "
 "than one storage engine, when binary log is disabled)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3383
+#: drizzled/drizzled.cc:3381
 msgid "Size of transaction coordinator log."
 msgstr ""
 
-#: drizzled/drizzled.cc:3389
+#: drizzled/drizzled.cc:3387
 msgid "Log some not critical warnings to the log file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3394
+#: drizzled/drizzled.cc:3392
 msgid "INSERT/DELETE/UPDATE has lower priority than selects."
 msgstr ""
 
-#: drizzled/drizzled.cc:3399
+#: drizzled/drizzled.cc:3397
 msgid ""
 "The location and name of the file that remembers the master and where the I/"
 "O replication thread is in the master's binlogs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3404
+#: drizzled/drizzled.cc:3402
 msgid ""
 "The number of tries the slave will make to connect to the master before "
 "giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3413
+#: drizzled/drizzled.cc:3411
 msgid "Lock mysqld in memory."
 msgstr ""
 
-#: drizzled/drizzled.cc:3417
+#: drizzled/drizzled.cc:3415
 msgid ""
 "Syntax: myisam-recover[=option[,option...]], where option can be DEFAULT, "
 "BACKUP, FORCE or QUICK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3422
+#: drizzled/drizzled.cc:3420
 msgid "Use very new possible 'unsafe' functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3427
+#: drizzled/drizzled.cc:3425
 msgid "Use old, non-optimized alter table."
 msgstr ""
 
-#: drizzled/drizzled.cc:3432
+#: drizzled/drizzled.cc:3430
 msgid ""
 "Enable old-style user limits (before 5.0.3 user resources were counted per "
 "each user+host vs. per account)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3437
+#: drizzled/drizzled.cc:3435
 msgid "Pid file used by safe_mysqld."
 msgstr ""
 
-#: drizzled/drizzled.cc:3447
+#: drizzled/drizzled.cc:3445
 msgid ""
 "Maximum time in seconds to wait for the port to become free. (Default: no "
 "wait)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3452
+#: drizzled/drizzled.cc:3450
 msgid "The location and name to use for relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3456
+#: drizzled/drizzled.cc:3454
 msgid ""
 "The location and name to use for the file that keeps a list of the last "
 "relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3461
+#: drizzled/drizzled.cc:3459
 msgid ""
 "The location and name of the file that remembers where the SQL replication "
 "thread is in the relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:3466
+#: drizzled/drizzled.cc:3464
 msgid ""
 "Tells the slave thread to restrict replication to the specified database. To "
 "specify more than one database, use the directive multiple times, once for "
@@ -1804,7 +2070,7 @@
 "updates to work, use replicate-wild-do-table=db_name.%."
 msgstr ""
 
-#: drizzled/drizzled.cc:3475
+#: drizzled/drizzled.cc:3473
 msgid ""
 "Tells the slave thread to restrict replication to the specified table. To "
 "specify more than one table, use the directive multiple times, once for each "
@@ -1812,7 +2078,7 @@
 "do-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3481
+#: drizzled/drizzled.cc:3479
 msgid ""
 "Tells the slave thread to not replicate to the specified database. To "
 "specify more than one database to ignore, use the directive multiple times, "
@@ -1821,7 +2087,7 @@
 "ignore-table=db_name.%. "
 msgstr ""
 
-#: drizzled/drizzled.cc:3488
+#: drizzled/drizzled.cc:3486
 msgid ""
 "Tells the slave thread to not replicate to the specified table. To specify "
 "more than one table to ignore, use the directive multiple times, once for "
@@ -1829,20 +2095,20 @@
 "replicate-ignore-db."
 msgstr ""
 
-#: drizzled/drizzled.cc:3494
+#: drizzled/drizzled.cc:3492
 msgid ""
 "Updates to a database with a different name than the original. Example: "
 "replicate-rewrite-db=master_db_name->slave_db_name."
 msgstr ""
 
-#: drizzled/drizzled.cc:3498
+#: drizzled/drizzled.cc:3496
 msgid ""
 "In replication, if set to 1, do not skip events having our server id. "
 "Default value is 0 (to break infinite loops in circular replication). Can't "
 "be set to 1 if --log-slave-updates is used."
 msgstr ""
 
-#: drizzled/drizzled.cc:3505
+#: drizzled/drizzled.cc:3503
 msgid ""
 "Tells the slave thread to restrict replication to the tables that match the "
 "specified wildcard pattern. To specify more than one table, use the "
@@ -1852,7 +2118,7 @@
 "names start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3513
+#: drizzled/drizzled.cc:3511
 msgid ""
 "Tells the slave thread to not replicate to the tables that match the given "
 "wildcard pattern. To specify more than one table to ignore, use the "
@@ -1862,7 +2128,7 @@
 "start with bar."
 msgstr ""
 
-#: drizzled/drizzled.cc:3522
+#: drizzled/drizzled.cc:3520
 msgid ""
 "Hostname or IP of the slave to be reported to to the master during slave "
 "registration. Will appear in the output of SHOW SLAVE HOSTS. Leave unset if "
@@ -1872,7 +2138,7 @@
 "may not be valid for connecting to the slave from the master or other hosts."
 msgstr ""
 
-#: drizzled/drizzled.cc:3535
+#: drizzled/drizzled.cc:3533
 msgid ""
 "Port for connecting to slave reported to the master during slave "
 "registration. Set it only if the slave is listening on a non-default port or "
@@ -1880,63 +2146,63 @@
 "If not sure, leave this option unset."
 msgstr ""
 
-#: drizzled/drizzled.cc:3542
+#: drizzled/drizzled.cc:3540
 msgid "Skip some optimize stages (for testing)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3545
+#: drizzled/drizzled.cc:3543
 msgid ""
 "Limit LOAD DATA, SELECT ... OUTFILE, and LOAD_FILE() to files within "
 "specified directory"
 msgstr ""
 
-#: drizzled/drizzled.cc:3550
+#: drizzled/drizzled.cc:3548
 msgid ""
 "Uniquely identifies the server instance in the community of replication "
 "partners."
 msgstr ""
 
-#: drizzled/drizzled.cc:3555
+#: drizzled/drizzled.cc:3553
 msgid ""
 "Change the value of a variable. Please note that this option is deprecated;"
 "you can set variables directly with --variable-name=value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3559
+#: drizzled/drizzled.cc:3557
 msgid "Don't use new, possible wrong routines."
 msgstr ""
 
-#: drizzled/drizzled.cc:3562
+#: drizzled/drizzled.cc:3560
 msgid "If set, slave is not autostarted."
 msgstr ""
 
-#: drizzled/drizzled.cc:3566
+#: drizzled/drizzled.cc:3564
 msgid "Don't print a stack trace on failure."
 msgstr ""
 
-#: drizzled/drizzled.cc:3570
+#: drizzled/drizzled.cc:3568
 msgid ""
 "Don't allow symlinking of tables. Deprecated option.  Use --skip-symbolic-"
 "links instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3574
+#: drizzled/drizzled.cc:3572
 msgid "Don't give threads different priorities."
 msgstr ""
 
-#: drizzled/drizzled.cc:3578
+#: drizzled/drizzled.cc:3576
 msgid ""
 "The location where the slave should put its temporary files when replicating "
 "a LOAD DATA INFILE command."
 msgstr ""
 
-#: drizzled/drizzled.cc:3583
+#: drizzled/drizzled.cc:3581
 msgid ""
 "Tells the slave thread to continue replication when a query event returns an "
 "error from the provided list."
 msgstr ""
 
-#: drizzled/drizzled.cc:3587
+#: drizzled/drizzled.cc:3585
 msgid ""
 "Modes for how replication events should be executed.  Legal values are "
 "STRICT (default) and IDEMPOTENT. In IDEMPOTENT mode, replication will not "
@@ -1944,139 +2210,139 @@
 "stop on any unexpected difference between the master and the slave."
 msgstr ""
 
-#: drizzled/drizzled.cc:3595
+#: drizzled/drizzled.cc:3593
 msgid "Enable|disable slow query log"
 msgstr ""
 
-#: drizzled/drizzled.cc:3599
+#: drizzled/drizzled.cc:3597
 msgid "(INGORED)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3602
+#: drizzled/drizzled.cc:3600
 msgid "Enable symbolic link support."
 msgstr ""
 
-#: drizzled/drizzled.cc:3611
+#: drizzled/drizzled.cc:3609
 msgid ""
 "Non-default option to alias SYSDATE() to NOW() to make it safe-replicable."
 msgstr ""
 
-#: drizzled/drizzled.cc:3616
+#: drizzled/drizzled.cc:3614
 msgid ""
 "Decision to use in heuristic recover process. Possible values are COMMIT or "
 "ROLLBACK."
 msgstr ""
 
-#: drizzled/drizzled.cc:3621
+#: drizzled/drizzled.cc:3619
 msgid ""
 "Using this option will cause most temporary files created to use a small set "
 "of names, rather than a unique name for each new file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3626
+#: drizzled/drizzled.cc:3624
 msgid ""
 "Specify whether to time mutexes (only InnoDB mutexes are currently supported)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3631
+#: drizzled/drizzled.cc:3629
 msgid ""
 "Path for temporary files. Several paths may be specified, separated by a "
 "colon (:), in this case they are used in a round-robin fashion."
 msgstr ""
 
-#: drizzled/drizzled.cc:3637
+#: drizzled/drizzled.cc:3635
 msgid "Default transaction isolation level."
 msgstr ""
 
-#: drizzled/drizzled.cc:3641
+#: drizzled/drizzled.cc:3639
 msgid ""
 "Enable symbolic link support. Deprecated option; use --symbolic-links "
 "instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3646
+#: drizzled/drizzled.cc:3644
 msgid "Run mysqld daemon as user."
 msgstr ""
 
-#: drizzled/drizzled.cc:3654
+#: drizzled/drizzled.cc:3652
 msgid "Deprecated; use --log-warnings instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:3659
+#: drizzled/drizzled.cc:3657
 msgid ""
 "The number of outstanding connection requests MySQL can have. This comes "
 "into play when the main MySQL thread gets very many connection requests in a "
 "very short time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3665
+#: drizzled/drizzled.cc:3663
 msgid ""
 "The size of the cache to hold the SQL statements for the binary log during a "
 "transaction. If you often use big, multi-statement transactions you can "
 "increase this to get more performance."
 msgstr ""
 
-#: drizzled/drizzled.cc:3671
+#: drizzled/drizzled.cc:3669
 msgid ""
 "Size of tree cache used in bulk insert optimisation. Note that this is a "
 "limit per thread!"
 msgstr ""
 
-#: drizzled/drizzled.cc:3677
+#: drizzled/drizzled.cc:3675
 msgid ""
 "The number of seconds the mysqld server is waiting for a connect packet "
 "before responding with 'Bad handshake'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3682
+#: drizzled/drizzled.cc:3680
 msgid "The DATE format (For future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3687
+#: drizzled/drizzled.cc:3685
 msgid "The DATETIME/TIMESTAMP format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3692
+#: drizzled/drizzled.cc:3690
 msgid "The default week format used by WEEK() functions."
 msgstr ""
 
-#: drizzled/drizzled.cc:3697
+#: drizzled/drizzled.cc:3695
 msgid ""
 "Precision of the result of '/' operator will be increased on that value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3703
+#: drizzled/drizzled.cc:3701
 msgid ""
 "If non-zero, binary logs will be purged after expire_logs_days days; "
 "possible purges happen at startup and at binary log rotation."
 msgstr ""
 
-#: drizzled/drizzled.cc:3709
+#: drizzled/drizzled.cc:3707
 msgid "The maximum length of the result of function  group_concat."
 msgstr ""
 
-#: drizzled/drizzled.cc:3714
+#: drizzled/drizzled.cc:3712
 msgid ""
 "The number of seconds the server waits for activity on an interactive "
 "connection before closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:3720
+#: drizzled/drizzled.cc:3718
 msgid "The size of the buffer that is used for full joins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3726
+#: drizzled/drizzled.cc:3724
 msgid "Don't overwrite stale .MYD and .MYI even if no directory is specified."
 msgstr ""
 
-#: drizzled/drizzled.cc:3731
+#: drizzled/drizzled.cc:3729
 msgid ""
 "The size of the buffer used for index blocks for MyISAM tables. Increase "
 "this to get better index handling (for all reads and multiple writes) to as "
 "much as you can afford;"
 msgstr ""
 
-#: drizzled/drizzled.cc:3740
+#: drizzled/drizzled.cc:3738
 msgid ""
 "This characterizes the number of hits a hot block has to be untouched until "
 "it is considered aged enough to be downgraded to a warm block. This "
@@ -2084,161 +2350,161 @@
 "blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3749
+#: drizzled/drizzled.cc:3747
 msgid "The default size of key cache blocks"
 msgstr ""
 
-#: drizzled/drizzled.cc:3755
+#: drizzled/drizzled.cc:3753
 msgid "The minimum percentage of warm blocks in key cache"
 msgstr ""
 
-#: drizzled/drizzled.cc:3761
+#: drizzled/drizzled.cc:3759
 msgid ""
 "Log all queries that have taken more than long_query_time seconds to execute "
 "to file. The argument will be treated as a decimal value with microsecond "
 "precission."
 msgstr ""
 
-#: drizzled/drizzled.cc:3767
+#: drizzled/drizzled.cc:3765
 msgid "Max packetlength to send/receive from to server."
 msgstr ""
 
-#: drizzled/drizzled.cc:3772
+#: drizzled/drizzled.cc:3770
 msgid ""
 "Can be used to restrict the total size used to cache a multi-transaction "
 "query."
 msgstr ""
 
-#: drizzled/drizzled.cc:3777
+#: drizzled/drizzled.cc:3775
 msgid ""
 "Binary log will be rotated automatically when the size exceeds this value. "
 "Will also apply to relay logs if max_relay_log_size is 0. The minimum value "
 "for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3783
+#: drizzled/drizzled.cc:3781
 msgid ""
 "If there is more than this number of interrupted connections from a host "
 "this host will be blocked from further connections."
 msgstr ""
 
-#: drizzled/drizzled.cc:3790
+#: drizzled/drizzled.cc:3788
 msgid "The number of simultaneous clients allowed."
 msgstr ""
 
-#: drizzled/drizzled.cc:3795
+#: drizzled/drizzled.cc:3793
 msgid "Max number of errors/warnings to store for a statement."
 msgstr ""
 
-#: drizzled/drizzled.cc:3800
+#: drizzled/drizzled.cc:3798
 msgid "Don't allow creation of heap tables bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3806
+#: drizzled/drizzled.cc:3804
 msgid ""
 "Joins that are probably going to read more than max_join_size records return "
 "an error."
 msgstr ""
 
-#: drizzled/drizzled.cc:3812
+#: drizzled/drizzled.cc:3810
 msgid "Max number of bytes in sorted records."
 msgstr ""
 
-#: drizzled/drizzled.cc:3817
+#: drizzled/drizzled.cc:3815
 msgid ""
 "If non-zero: relay log will be rotated automatically when the size exceeds "
 "this value; if zero (the default): when the size exceeds max_binlog_size. 0 "
 "excepted, the minimum value for this variable is 4096."
 msgstr ""
 
-#: drizzled/drizzled.cc:3824
+#: drizzled/drizzled.cc:3822
 msgid "Limit assumed max number of seeks when looking up rows based on a key"
 msgstr ""
 
-#: drizzled/drizzled.cc:3829
+#: drizzled/drizzled.cc:3827
 msgid ""
 "The number of bytes to use when sorting BLOB or TEXT values (only the first "
 "max_sort_length bytes of each value are used; the rest are ignored)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3836
+#: drizzled/drizzled.cc:3834
 msgid "Maximum number of temporary tables a client can keep open at a time."
 msgstr ""
 
-#: drizzled/drizzled.cc:3841
+#: drizzled/drizzled.cc:3839
 msgid "After this many write locks, allow some read locks to run in between."
 msgstr ""
 
-#: drizzled/drizzled.cc:3845
+#: drizzled/drizzled.cc:3843
 msgid ""
 "Don't log queries which examine less than min_examined_row_limit rows to "
 "file."
 msgstr ""
 
-#: drizzled/drizzled.cc:3851
+#: drizzled/drizzled.cc:3849
 msgid "Block size to be used for MyISAM index pages."
 msgstr ""
 
-#: drizzled/drizzled.cc:3857
+#: drizzled/drizzled.cc:3855
 msgid "Default pointer size to be used for MyISAM tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:3862
+#: drizzled/drizzled.cc:3860
 msgid "(Deprecated option)"
 msgstr ""
 
-#: drizzled/drizzled.cc:3868
+#: drizzled/drizzled.cc:3866
 msgid ""
 "Don't use the fast sort index method to created index if the temporary file "
 "would get bigger than this."
 msgstr ""
 
-#: drizzled/drizzled.cc:3875
+#: drizzled/drizzled.cc:3873
 msgid ""
 "Number of threads to use when repairing MyISAM tables. The value of 1 "
 "disables parallel repair."
 msgstr ""
 
-#: drizzled/drizzled.cc:3881
+#: drizzled/drizzled.cc:3879
 msgid ""
 "The buffer that is allocated when sorting the index when doing a REPAIR or "
 "when creating indexes with CREATE INDEX or ALTER TABLE."
 msgstr ""
 
-#: drizzled/drizzled.cc:3887
+#: drizzled/drizzled.cc:3885
 msgid ""
 "Specifies how MyISAM index statistics collection code should threat NULLs. "
 "Possible values of name are 'nulls_unequal' (default behavior), "
 "'nulls_equal' (emulate MySQL 4.0 behavior), and 'nulls_ignored'."
 msgstr ""
 
-#: drizzled/drizzled.cc:3894
+#: drizzled/drizzled.cc:3892
 msgid "Buffer length for TCP/IP and socket communication."
 msgstr ""
 
-#: drizzled/drizzled.cc:3899
+#: drizzled/drizzled.cc:3897
 msgid ""
 "Number of seconds to wait for more data from a connection before aborting "
 "the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:3905
+#: drizzled/drizzled.cc:3903
 msgid ""
 "If a read on a communication port is interrupted, retry this many times "
 "before giving up."
 msgstr ""
 
-#: drizzled/drizzled.cc:3911
+#: drizzled/drizzled.cc:3909
 msgid ""
 "Number of seconds to wait for a block to be written to a connection before "
 "aborting the write."
 msgstr ""
 
-#: drizzled/drizzled.cc:3917
+#: drizzled/drizzled.cc:3915
 msgid "Use compatible behavior."
 msgstr ""
 
-#: drizzled/drizzled.cc:3922
+#: drizzled/drizzled.cc:3920
 msgid ""
 "If this is not 0, then mysqld will use this value to reserve file "
 "descriptors to use with setrlimit(). If this value is 0 then mysqld will "
@@ -2246,7 +2512,7 @@
 "larger) number of files."
 msgstr ""
 
-#: drizzled/drizzled.cc:3929
+#: drizzled/drizzled.cc:3927
 msgid ""
 "Controls the heuristic(s) applied during query optimization to prune less-"
 "promising partial plans from the optimizer search space. Meaning: 0 - do not "
@@ -2254,7 +2520,7 @@
 "on number of retrieved rows."
 msgstr ""
 
-#: drizzled/drizzled.cc:3937
+#: drizzled/drizzled.cc:3935
 msgid ""
 "Maximum depth of search performed by the query optimizer. Values larger than "
 "the number of relations in a query result in better query plans, but take "
@@ -2265,162 +2531,162 @@
 "(used for testing/comparison)."
 msgstr ""
 
-#: drizzled/drizzled.cc:3949
+#: drizzled/drizzled.cc:3947
 msgid "Directory for plugins."
 msgstr ""
 
-#: drizzled/drizzled.cc:3953
+#: drizzled/drizzled.cc:3951
 msgid ""
 "Optional comma separated list of plugins to load, where each plugin is "
 "identified by the name of the shared library. [for example: --"
 "plugin_load=libmd5udf.so]"
 msgstr ""
 
-#: drizzled/drizzled.cc:3959
+#: drizzled/drizzled.cc:3957
 msgid "The size of the buffer that is allocated when preloading indexes"
 msgstr ""
 
-#: drizzled/drizzled.cc:3964
+#: drizzled/drizzled.cc:3962
 msgid "Allocation block size for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3969
+#: drizzled/drizzled.cc:3967
 msgid "Persistent buffer for query parsing and execution"
 msgstr ""
 
-#: drizzled/drizzled.cc:3975
+#: drizzled/drizzled.cc:3973
 msgid "Allocation block size for storing ranges during optimization"
 msgstr ""
 
-#: drizzled/drizzled.cc:3981
+#: drizzled/drizzled.cc:3979
 msgid ""
 "Each thread that does a sequential scan allocates a buffer of this size for "
 "each table it scans. If you do many sequential scans, you may want to "
 "increase this value."
 msgstr ""
 
-#: drizzled/drizzled.cc:3989
+#: drizzled/drizzled.cc:3987
 msgid ""
 "Make all non-temporary tables read-only, with the exception for replication "
 "(slave) threads and users with the SUPER privilege"
 msgstr ""
 
-#: drizzled/drizzled.cc:3995
+#: drizzled/drizzled.cc:3993
 msgid ""
 "When reading rows in sorted order after a sort, the rows are read through "
 "this buffer to avoid a disk seeks. If not set, then it's set to the value of "
 "record_buffer."
 msgstr ""
 
-#: drizzled/drizzled.cc:4009
+#: drizzled/drizzled.cc:4007
 msgid ""
 "0 = do not purge relay logs. 1 = purge them as soon as they are no more "
 "needed."
 msgstr ""
 
-#: drizzled/drizzled.cc:4015
+#: drizzled/drizzled.cc:4013
 msgid "Maximum space to use for all relay logs."
 msgstr ""
 
-#: drizzled/drizzled.cc:4020
+#: drizzled/drizzled.cc:4018
 #, fuzzy
 msgid "Use compression on master/slave protocol."
 msgstr "在伺服器及客戶端之間的協定使用壓縮"
 
-#: drizzled/drizzled.cc:4025
+#: drizzled/drizzled.cc:4023
 msgid ""
 "Number of seconds to wait for more data from a master/slave connection "
 "before aborting the read."
 msgstr ""
 
-#: drizzled/drizzled.cc:4030
+#: drizzled/drizzled.cc:4028
 msgid ""
 "Number of times the slave SQL thread will retry a transaction in case it "
 "failed with a deadlock or elapsed lock wait timeout, before giving up and "
 "stopping."
 msgstr ""
 
-#: drizzled/drizzled.cc:4036
+#: drizzled/drizzled.cc:4034
 msgid "Allow slave to batch requests."
 msgstr ""
 
-#: drizzled/drizzled.cc:4040
+#: drizzled/drizzled.cc:4038
 msgid ""
 "If creating the thread takes longer than this value (in seconds), the "
 "Slow_launch_threads counter will be incremented."
 msgstr ""
 
-#: drizzled/drizzled.cc:4045
+#: drizzled/drizzled.cc:4043
 msgid "Each thread that needs to do a sort allocates a buffer of this size."
 msgstr ""
 
-#: drizzled/drizzled.cc:4051
+#: drizzled/drizzled.cc:4049
 msgid ""
 "Synchronously flush binary log to disk after every #th event. Use 0 "
 "(default) to disable synchronous flushing."
 msgstr ""
 
-#: drizzled/drizzled.cc:4056
+#: drizzled/drizzled.cc:4054
 msgid "Sync .frm to disk on create. Enabled by default."
 msgstr ""
 
-#: drizzled/drizzled.cc:4060
+#: drizzled/drizzled.cc:4058
 msgid "Deprecated; use --table_open_cache instead."
 msgstr ""
 
-#: drizzled/drizzled.cc:4064
+#: drizzled/drizzled.cc:4062
 msgid "The number of cached table definitions."
 msgstr ""
 
-#: drizzled/drizzled.cc:4068
+#: drizzled/drizzled.cc:4066
 msgid "The number of cached open tables."
 msgstr ""
 
-#: drizzled/drizzled.cc:4072
+#: drizzled/drizzled.cc:4070
 msgid ""
 "Timeout in seconds to wait for a table level lock before returning an error. "
 "Used only if the connection has active cursors."
 msgstr ""
 
-#: drizzled/drizzled.cc:4077
+#: drizzled/drizzled.cc:4075
 msgid "How many threads we should keep in a cache for reuse."
 msgstr ""
 
-#: drizzled/drizzled.cc:4081
+#: drizzled/drizzled.cc:4079
 msgid ""
 "How many threads we should create to handle query requests in case of "
 "'thread_handling=pool-of-threads'"
 msgstr ""
 
-#: drizzled/drizzled.cc:4086
+#: drizzled/drizzled.cc:4084
 msgid "The stack size for each thread."
 msgstr ""
 
-#: drizzled/drizzled.cc:4092
+#: drizzled/drizzled.cc:4090
 msgid "The TIME format (for future)."
 msgstr ""
 
-#: drizzled/drizzled.cc:4097
+#: drizzled/drizzled.cc:4095
 msgid ""
 "If an internal in-memory temporary table exceeds this size, MySQL will "
 "automatically convert it to an on-disk MyISAM table."
 msgstr ""
 
-#: drizzled/drizzled.cc:4103
+#: drizzled/drizzled.cc:4101
 msgid "Allocation block size for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4108
+#: drizzled/drizzled.cc:4106
 msgid "Persistent buffer for transactions to be stored in binary log"
 msgstr ""
 
-#: drizzled/drizzled.cc:4113
+#: drizzled/drizzled.cc:4111
 msgid ""
 "The number of seconds the server waits for activity on a connection before "
 "closing it."
 msgstr ""
 
-#: drizzled/drizzled.cc:4361
+#: drizzled/drizzled.cc:4359
 msgid ""
 "Copyright (C) 2000 MySQL AB, by Monty and others\n"
 "This software comes with ABSOLUTELY NO WARRANTY. This is free software,\n"
@@ -2429,76 +2695,76 @@
 "Starts the Drizzle database server\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4368
+#: drizzled/drizzled.cc:4366
 #, c-format
 msgid "Usage: %s [OPTIONS]\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4379
+#: drizzled/drizzled.cc:4377
 msgid ""
 "\n"
 "To see what values a running Drizzle server is using, type\n"
 "'drizzleadmin variables' instead of 'drizzled --help'."
 msgstr ""
 
-#: drizzled/drizzled.cc:4564
+#: drizzled/drizzled.cc:4562
 #, c-format
 msgid ""
 "Ignoring user change to '%s' because the user was set to '%s' earlier on the "
 "command line\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4616
+#: drizzled/drizzled.cc:4614
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - missing '->'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4625
+#: drizzled/drizzled.cc:4623
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty FROM db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4635
+#: drizzled/drizzled.cc:4633
 #, c-format
 msgid "Bad syntax in replicate-rewrite-db - empty TO db!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4664 drizzled/drizzled.cc:4673
+#: drizzled/drizzled.cc:4662 drizzled/drizzled.cc:4671
 #, c-format
 msgid "Could not add do table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4682 drizzled/drizzled.cc:4691
+#: drizzled/drizzled.cc:4680 drizzled/drizzled.cc:4689
 #, c-format
 msgid "Could not add ignore table rule '%s'!\n"
 msgstr ""
 
-#: drizzled/drizzled.cc:4738
+#: drizzled/drizzled.cc:4736
 msgid "Can't start server: cannot resolve hostname!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4744
+#: drizzled/drizzled.cc:4742
 msgid "Can't start server: bind-address refers to multiple interfaces!"
 msgstr ""
 
-#: drizzled/drizzled.cc:4919
+#: drizzled/drizzled.cc:4917
 msgid ""
 "options --log-slow-admin-statements, --log-queries-not-using-indexes and --"
 "log-slow-slave-statements have no effect if --log-slow-queries is not set"
 msgstr ""
 
+#: drizzled/drizzled.cc:5105
+#, c-format
+msgid "No option given to %s\n"
+msgstr ""
+
 #: drizzled/drizzled.cc:5107
 #, c-format
-msgid "No option given to %s\n"
+msgid "Wrong option to %s. Option(s) given: %s\n"
 msgstr ""
 
 #: drizzled/drizzled.cc:5109
 #, c-format
-msgid "Wrong option to %s. Option(s) given: %s\n"
-msgstr ""
-
-#: drizzled/drizzled.cc:5111
-#, c-format
 msgid "Alternatives are: '%s'"
 msgstr ""
 
@@ -5817,6 +6083,157 @@
 "while the same tablespace is defined on the server as '%-.256s'"
 msgstr ""
 
+#: drizzled/handler.cc:390
+#, fuzzy
+msgid "Too many storage engines!"
+msgstr "連接中"
+
+#: drizzled/handler.cc:394
+#, c-format
+msgid "Storage engine '%s' has conflicting typecode. Assigning value %d."
+msgstr ""
+
+#: drizzled/handler.cc:1278
+#, c-format
+msgid "Found %d prepared transaction(s) in %s"
+msgstr ""
+
+#: drizzled/handler.cc:1330
+msgid "Starting crash recovery..."
+msgstr ""
+
+#: drizzled/handler.cc:1362
+#, c-format
+msgid "Found %d prepared XA transactions"
+msgstr ""
+
+#: drizzled/handler.cc:1366
+#, c-format
+msgid ""
+"Found %d prepared transactions! It means that drizzled was not shut down "
+"properly last time and critical recovery information (last binlog or %s "
+"file) was manually deleted after a crash. You have to start drizzled with "
+"the --tc-heuristic-recover switch to commit or rollback pending transactions."
+msgstr ""
+
+#: drizzled/handler.cc:1376
+msgid "Crash recovery finished."
+msgstr ""
+
+#: drizzled/log.cc:1072
+msgid "I/O error reading the header from the binary log"
+msgstr ""
+
+#: drizzled/log.cc:1079
+msgid ""
+"Binlog has bad magic number;  It's not a binary log file that can be used by "
+"this version of Drizzle"
+msgstr ""
+
+#: drizzled/log.cc:1094
+#, fuzzy, c-format
+msgid "Failed to open log (file '%s', errno %d)"
+msgstr "不能鎖定檔案(錯誤碼: %d)"
+
+#: drizzled/log.cc:1096 drizzled/log.cc:1104
+msgid "Could not open log file"
+msgstr ""
+
+#: drizzled/log.cc:1102
+#, c-format
+msgid "Failed to create a cache on log (file '%s')"
+msgstr ""
+
+#: drizzled/log.cc:1256 drizzled/log.cc:1906
+#, c-format
+msgid ""
+"Could not use %s for logging (error %d). Turning logging off for the whole "
+"duration of the Drizzle server process. To turn it on again: fix the cause, "
+"shutdown the Drizzle server and restart it."
+msgstr ""
+
+#: drizzled/log.cc:2175 drizzled/log.cc:2206 drizzled/log.cc:2458
+#: drizzled/log.cc:2582
+#, c-format
+msgid "Failed to delete file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2184 drizzled/log.cc:2466 drizzled/log.cc:2590
+#, c-format
+msgid ""
+"a problem with deleting %s; consider examining correspondence of your binlog "
+"index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:2312
+#, c-format
+msgid "next log error: %d  offset: %s  log: %s included: %d"
+msgstr ""
+
+#: drizzled/log.cc:2424 drizzled/log.cc:2550
+#, c-format
+msgid "Failed to execute stat() on file '%s'"
+msgstr ""
+
+#: drizzled/log.cc:2435 drizzled/log.cc:2561
+#, c-format
+msgid ""
+"a problem with getting info on being purged %s; consider examining "
+"correspondence of your binlog index file to the actual binlog files"
+msgstr ""
+
+#: drizzled/log.cc:4057 drizzled/log.cc:4550
+#, c-format
+msgid "Recovering after a crash using %s"
+msgstr ""
+
+#: drizzled/log.cc:4060
+msgid ""
+"Cannot perform automatic crash recovery when --tc-heuristic-recover is used"
+msgstr ""
+
+#: drizzled/log.cc:4397
+msgid "Bad magic header in tc log"
+msgstr ""
+
+#: drizzled/log.cc:4407
+#, c-format
+msgid ""
+"Recovery failed! You must enable exactly %d storage engines that support two-"
+"phase commit protocol"
+msgstr ""
+
+#: drizzled/log.cc:4435
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete tc log and start drizzled with --tc-"
+"heuristic-recover={commit|rollback}"
+msgstr ""
+
+#: drizzled/log.cc:4465
+msgid "Heuristic crash recovery mode"
+msgstr ""
+
+#: drizzled/log.cc:4467
+msgid "Heuristic crash recovery failed"
+msgstr ""
+
+#: drizzled/log.cc:4468
+msgid "Please restart mysqld without --tc-heuristic-recover"
+msgstr ""
+
+#: drizzled/log.cc:4512 drizzled/log.cc:4536
+#, fuzzy, c-format
+msgid "find_log_pos() failed (error: %d)"
+msgstr "不能鎖定檔案(錯誤碼: %d)"
+
+#: drizzled/log.cc:4649
+msgid ""
+"Crash recovery failed. Either correct the problem (if it's, for example, out "
+"of memory error) and restart, or delete (or rename) binary log and start "
+"mysqld with --tc-heuristic-recover={commit|rollback}"
+msgstr ""
+
 #: drizzled/rpl_mi.cc:148
 #, c-format
 msgid "Failed to create a new master info file (file '%s', errno %d)"
@@ -5852,18 +6269,55 @@
 msgid "Slave %s: %s%s Error_code: %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:123
+#: drizzled/rpl_utility.cc:122
 #, c-format
 msgid "Column %d type mismatch - received type %d, %s.%s has type %d"
 msgstr ""
 
-#: drizzled/rpl_utility.cc:138
+#: drizzled/rpl_utility.cc:137
 #, c-format
 msgid ""
 "Column %d size mismatch - master has size %d, %s.%s on slave has size %d. "
 "Master's column size should be <= the slave's column size."
 msgstr ""
 
+#: drizzled/scheduler.cc:121
+msgid "Memory allocation error in thd_scheduler::init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:212
+msgid "init_pipe(thd_add_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:218
+msgid "init_pipe(thd_kill_pipe) error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:230
+msgid "thd_add_event event_add error in libevent_init\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:246
+#, fuzzy, c-format
+msgid "Can't create completion port thread (error %d)"
+msgstr "不能建立資料夾'%s' (錯誤碼: %d)"
+
+#: drizzled/scheduler.cc:359
+msgid "event_add error in libevent_add_thd_callback\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:385
+msgid "Scheduler init error in libevent_add_new_connection\n"
+msgstr ""
+
+#: drizzled/scheduler.cc:467
+msgid "libevent_thread_proc: my_thread_init() failed\n"
+msgstr ""
+
+#: drizzled/set_var.cc:905
+msgid "Ambiguous slave modes combination. STRICT will be used"
+msgstr ""
+
 #: drizzled/slave.cc:89
 msgid "Waiting to reconnect after a failed registration on master"
 msgstr ""
@@ -6284,6 +6738,119 @@
 "Then replication can be restarted."
 msgstr ""
 
+#: drizzled/sql_base.cc:2544
+#, c-format
+msgid "Table %s had a open data handler in reopen_table"
+msgstr ""
+
+#: drizzled/sql_base.cc:3203
+#, c-format
+msgid "Couldn't repair table: %s.%s"
+msgstr ""
+
+#: drizzled/sql_base.cc:3246
+#, c-format
+msgid ""
+"When opening HEAP table, could not allocate memory to write 'DELETE FROM `%"
+"s`.`%s`' to the binary log"
+msgstr ""
+
+#: drizzled/sql_base.cc:3983
+#, fuzzy, c-format
+msgid "Could not remove temporary table: '%s', error: %d"
+msgstr "不能建立資料夾'%s' (錯誤碼: %d)"
+
+#: drizzled/sql_db.cc:396 drizzled/sql_db.cc:404
+#, c-format
+msgid "Error while loading database options: '%s':"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:647
+#, c-format
+msgid "Plugin '%s' of type %s failed deinitialization"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:661
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after deinitialization."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:781
+#, c-format
+msgid "Plugin '%s' registration as a %s failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1035
+msgid "plugin-load parameter too long"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1095
+#, c-format
+msgid "Couldn't load plugin named '%s' with soname '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1146
+#, c-format
+msgid "Forcing shutdown of %d plugins"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1168
+#, c-format
+msgid "Plugin '%s' will be forced to shutdown"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:1184
+#, c-format
+msgid "Plugin '%s' has ref_count=%d after shutdown."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2433 drizzled/sql_plugin.cc:2496
+#, fuzzy, c-format
+msgid "Unknown variable type code 0x%x in plugin '%s'."
+msgstr "不明白的指令: '%-.60s'"
+
+#: drizzled/sql_plugin.cc:2476
+#, c-format
+msgid ""
+"Server variable %s of plugin %s was forced to be read-only: string variable "
+"without update_func and PLUGIN_VAR_MEMALLOC flag"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2507
+#, c-format
+msgid "Missing variable name in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2524
+#, c-format
+msgid "Thread local variable '%s' not allocated in plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2643
+#, c-format
+msgid "Out of memory for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2650
+#, c-format
+msgid "Bad options for plugin '%s'."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2659
+#, c-format
+msgid "Parsing options for plugin '%s' failed."
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2702
+#, c-format
+msgid "Plugin '%s' has conflicting system variables"
+msgstr ""
+
+#: drizzled/sql_plugin.cc:2712
+#, c-format
+msgid "Plugin '%s' disabled by command line option"
+msgstr ""
+
 #: drizzled/sql_repl.cc:101
 msgid "Failed in send_file() while reading file name"
 msgstr ""
@@ -6300,6 +6867,37 @@
 msgid "Failed in send_file() while negotiating file transfer close"
 msgstr ""
 
+#: drizzled/sql_select.cc:13156
+#, c-format
+msgid "Got error %d when reading table '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:81
+#, c-format
+msgid "Invalid (old?) table or database name '%s'"
+msgstr ""
+
+#: drizzled/sql_table.cc:2717
+#, fuzzy, c-format
+msgid "Unknown - internal error %d during operation"
+msgstr "不明的錯誤 %d"
+
+#: drizzled/sql_table.cc:4999
+#, c-format
+msgid "Could not open table %s.%s after rename\n"
+msgstr ""
+
+#: drizzled/sql_table.cc:5175
+#, c-format
+msgid ""
+"ORDER BY ignored because there is a user-defined clustered index in the "
+"table '%-.192s'"
+msgstr ""
+
+#: drizzled/sql_udf.cc:39
+msgid "Can't allocate memory for udf structures"
+msgstr ""
+
 #: drizzled/table.cc:494
 #, c-format
 msgid ""

